Summary: The Linux kernel (the core of the Linux operating system)

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows and
# no contrary --with/--without arguments are given on the command line.
%define buildup 1
%define buildsmp 1
%define buildBOOT 1
%define buildenterprise 1
%define buildsummit 0
%define builddebug 0
%define buildjensen 0
%define buildtape 0
%define buildBOOTtape 0

# Versions of various parts
%define release e.25.101ml
%define sublevel 9
%define kversion 2.4.%{sublevel}
# /usr/src/%{kslnk} -> /usr/src/linux-%{KVERREL}
%define kslnk linux-2.4
# first XFree86 ver that requires the drm in this kernel
%define drmver 4.1.0

# groups of related archs
%define all_ppc ppc ppciseries ppcpseries ppc64
#define all_x86 i386 i686
%define all_x86 i686 i386 athlon

# features
%define tux 1
# note: do not enable both debugging and ikd, as ikd includes debugging already
%define debugging 0
%define ikd 0
%define ibcs 1
%define iorl 1
%define aio 1
%define lowlat 1
%define netdump 0

# disk space requirements to test before build, in megabytes
# ~30M per kernel + ~100M for source plus fudge factor
%define RPM_BUILD_ROOT_space 200
# ~200M for build kernel source tree plus fudge factor
%define RPM_BUILD_DIR_space 200

# disable build root strip policy
%define __spec_install_post /usr/lib/rpm/brp-compress || :

# now we need a %{_mystrip} macro to allow cross-compiling
%{expand: %%define go_for_%{_target_cpu}_%{_arch} yadda}
%{expand: %%define _mystrip %{?go_for_ia64_i386:ia64-linux-strip}%{!?go_for_ia64_i386:strip}}


# Override generic defaults with per-arch defaults (which can
# themselves be overridden with --with/--without).  These must
# ONLY be "0", never "1"

# First, architecture-specific kernels off on all other archs (ifnarch)
%ifnarch i686
%define buildenterprise 0
%define builddebug 0
%define buildsummit 0
%endif
%ifnarch s390 s390x
%define buildBOOTtape 0
%define buildtape 0
%endif
%ifnarch alpha
# jensen kernel, only for alpha.  Old, broken broken alpha.
%define buildjensen 0
%endif
%ifnarch i386 i686 s390 s390x alpha ppcpseries
%define buildBOOT 0
%endif

# Second, per-architecture exclusions (ifarch)
%ifarch i386
%define buildsmp 0
%endif
%ifarch i586 i386
%define buildup 0
%endif
%ifarch s390 s390x
%define buildsmp 0
%endif
%ifarch ia64
%define buildBOOT 0
%endif
%ifarch ppc
%define buildBOOT 0
%define buildsmp 0
%endif


# allow --with[out] <feature|kernel> at rpm command line build
# e.g. --with smp --without smp --without BOOT --without enterprise --with ibcs
# --with overrides --without
%{?_without_up: %{expand: %%define buildup 0}}
%{?_without_smp: %{expand: %%define buildsmp 0}}
%{?_without_BOOT: %{expand: %%define buildBOOT 0}}
%{?_without_enterprise: %{expand: %%define buildenterprise 0}}
%{?_without_summit: %{expand: %%define buildsummit 0}}
%{?_without_debug: %{expand: %%define builddebug 0}}
%{?_without_jensen: %{expand: %%define buildjensen 0}}
%{?_without_tape: %{expand: %%define buildtape 0}}
%{?_without_BOOTtape: %{expand: %%define buildBOOTtape 0}}
%{?_without_tux: %{expand: %%define tux 0}}
%{?_without_debugging: %{expand: %%define debugging 0}}
%{?_without_ikd: %{expand: %%define ikd 0}}
%{?_without_ibcs: %{expand: %%define ibcs 0}}
%{?_without_netdump: %{expand: %%define netdump 0}}
%{?_with_up: %{expand: %%define buildup 1}}
%{?_with_smp: %{expand: %%define buildsmp 1}}
%{?_with_BOOT: %{expand: %%define buildBOOT 1}}
%{?_with_enterprise: %{expand: %%define buildenterprise 1}}
%{?_with_summit: %{expand: %%define buildsummit 1}}
%{?_with_debug: %{expand: %%define builddebug 1}}
%{?_with_jensen: %{expand: %%define buildjensen 1}}
%{?_with_tape: %{expand: %%define buildtape 1}}
%{?_with_BOOTtape: %{expand: %%define buildBOOTtape 1}}
%{?_with_tux: %{expand: %%define tux 1}}
%{?_with_debugging: %{expand: %%define debugging 1}}
%{?_with_ikd: %{expand: %%define ikd 1}}
%{?_with_ibcs: %{expand: %%define ibcs 1}}
%{?_with_netdump: %{expand: %%define netdump 1}}

# we can't test values inline, only whether a macro exists
%{expand: %%define buildup_%{buildup} yadda}
%{expand: %%define buildsmp_%{buildsmp} yadda}
%{expand: %%define buildBOOT_%{buildBOOT} yadda}
%{expand: %%define buildenterprise_%{buildenterprise} yadda}
%{expand: %%define buildsummit_%{buildsummit} yadda}
%{expand: %%define builddebug_%{builddebug} yadda}
%{expand: %%define buildjensen_%{buildjensen} yadda}
%{expand: %%define buildtape_%{buildtape} yadda}
%{expand: %%define buildBOOTtape_%{buildBOOTtape} yadda}
%{expand: %%define tux_%{tux} yadda}
%{expand: %%define ikd_%{ikd} yadda}
%{expand: %%define ibcs_%{ibcs} yadda}
%{expand: %%define debuglevel_%{debugging} yadda}
%{expand: %%define netdump_%{netdump} yadda}

%{expand: %%define kernel_conflicts  ppp <= 2.3.15, pcmcia-cs <= 3.1.20, isdn4k-utils <= 3.0, mount < 2.10r-5, nfs-utils < 0.3.1, cipe < 1.4.5, tux < 2.1.1-10, kudzu <= 0.92, e2fsprogs < 1.22}

%define BOOT_kernel_prereq fileutils, modutils >= 2.4.14
%define kernel_prereq %{BOOT_kernel_prereq}, initscripts >= 5.83, mkinitrd
%ifarch ia64
%define initrd_dir /boot/efi
%else
%define initrd_dir /boot
%endif

%define KVERREL %{PACKAGE_VERSION}-%{PACKAGE_RELEASE}

%ifarch %{all_x86}
%define kernel_glob vmlinu?-%{KVERREL}
%define debug_kernel_glob vmlinu?-%{KVERREL}
%endif
%ifarch %{all_ppc}
%define kernel_glob vmlinu?-%{KVERREL}
%define debug_kernel_glob vmlinu?-%{KVERREL}
%endif
%ifarch ia64
# <sigh>, no GLOB_BRACE for filelists, efi needs to be done separately
%define kernel_glob vmlinuz-%{KVERREL}
%define debug_kernel_glob vmlinu?-%{KVERREL}
%endif
%ifarch alpha
%define kernel_glob vmlinu?-%{KVERREL}
%define debug_kernel_glob vmlinu?-%{KVERREL}
%endif
%ifarch s390 s390x
%define kernel_glob vmlinu?-%{KVERREL}
%define debug_kernel_glob vmlinu?-%{KVERREL}
%endif

Name: kernel
Version: %{kversion}
Release: %{release}%{?debuglevel_1:.dbg}
License: GPL
Group: System Environment/Kernel
ExclusiveArch: %{all_x86} %{all_ppc}
ExclusiveOS: Linux
Obsoletes: kernel-modules, kernel-sparc
Provides: module-info, kernel = %{version}, kernel-drm = %{drmver}
Autoreqprov: no
Prereq: %{kernel_prereq}
Conflicts: %{kernel_conflicts}

BuildPreReq: modutils >= 2.4.14, patch >= 2.5.4, bash >= 2.03, sh-utils
BuildRequires: gcc >= 2.95.3

Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.4/linux-%{kversion}.tar.bz2
Source4: README.kernel-sources

Source10: linux-SetupKernelSource.sh
Source11: module-info
Source14: kernel-2.4-BuildASM.sh
Source15: linux-rhconfig.h
Source16: linux-merge-config.awk
Source17: linux-merge-modules.awk

Source20: kernel-%{kversion}-i386.config
Source21: kernel-%{kversion}-i386-smp.config
Source22: kernel-%{kversion}-i386-BOOT.config
Source23: kernel-%{kversion}-alpha.config
Source24: kernel-%{kversion}-alpha-smp.config
Source25: kernel-%{kversion}-sparc.config
Source26: kernel-%{kversion}-sparc-smp.config
Source27: kernel-%{kversion}-sparc64.config
Source28: kernel-%{kversion}-sparc64-smp.config
Source29: kernel-%{kversion}-i686.config
Source30: kernel-%{kversion}-i686-smp.config
Source31: kernel-%{kversion}-alpha-BOOT.config
Source32: kernel-%{kversion}-sparc-BOOT.config
Source33: kernel-%{kversion}-sparc64-BOOT.config
Source34: kernel-%{kversion}-i586.config
Source35: kernel-%{kversion}-i586-smp.config
# since there are no space issues, a -BOOT is rather pointless
Source36: kernel-%{kversion}-ia64.config
Source37: kernel-%{kversion}-ia64-smp.config
Source38: kernel-%{kversion}-i686-enterprise.config
Source39: kernel-%{kversion}-i686-debug.config
Source40: kernel-%{kversion}-athlon.config
Source41: kernel-%{kversion}-athlon-smp.config
Source42: kernel-%{kversion}-alpha-jensen.config
Source43: kernel-%{kversion}-s390-BOOTtape.config
Source44: kernel-%{kversion}-s390-BOOT.config
Source45: kernel-%{kversion}-s390-tape.config
Source46: kernel-%{kversion}-s390-debug.config
Source46: kernel-%{kversion}-s390.config
Source47: kernel-%{kversion}-ia64-BOOT.config
Source48: kernel-%{kversion}-i686-summit.config
Source49: kernel-%{kversion}-i686-BOOT.config

Source50: installkernel.iSeries
Source51: installcmdline.iSeries
Source52: kernel-%{kversion}-ppc.config
Source53: kernel-%{kversion}-ppcpseries.config
Source54: kernel-%{kversion}-ppcpseries-smp.config
Source55: kernel-%{kversion}-ppcpseries-BOOT.config
Source56: kernel-%{kversion}-s390x-BOOTtape.config
Source57: kernel-%{kversion}-s390x-BOOT.config
Source58: kernel-%{kversion}-s390x-tape.config
Source59: kernel-%{kversion}-s390x.config
Source60: kernel-%{kversion}-ppc64-smp.config
Source61: kernel-%{kversion}-ppc64-BOOT.config

Source80: linux-2.4.9-ikd.patch

Source90: install-proprietary.sh
Source91: clean-proprietary.sh

Source100: megaide_lib.bin

#
# Patches 0 through 100 are meant for core subsystem upgrades
#
Patch1: ftp://ftp.kernel.org/pub/linux/kernel/people/alan/2.4/patch-2.4.9-ac10.bz2
Patch10: linux-2.4.9-proc-vmalloc.patch
Patch11: linux-2.4.9-vsnprintf-fix.patch
Patch12: linux-2.4.9-ac10-sysrq.patch


# 
# Patches 100 through 400 are architecture specific patches
# Each architecture has 20 slots reserved.
#

# IA64
Patch100: linux-2.4.9-ia64-core.patch
Patch101: linux-2.4.9-ia64-junk.patch
Patch102: linux-2.4.9-ia64-cs4281.patch
Patch103: linux-2.4.9-ia64-timer.patch
Patch104: linux-2.4.10-ia64-drm.patch
Patch105: linux-2.4.9-ia64-compile.patch
Patch106: linux-2.4.1-ia64-swiotlb.patch
Patch107: linux-2.4.5-ia64-unaligned.patch
Patch108: linux-2.4.9-ia64-eepro100.patch
Patch109: linux-2.4.9-ia64-unwind.patch
Patch110: linux-2.4.9-ia64-trapinfo.patch
Patch111: linux-2.4.3-ia64-ppp.patch
Patch112: linux-2.4.9-ia64-updates.patch
Patch113: linux-2.4.10-gpt-20010928.patch
Patch114: linux-2.4.9-ia64-fancyswiommu.patch


# Alpha
Patch120: linux-2.3.99-alpha.patch
Patch121: linux-2.4.1-alphaksyms.patch
Patch122: linux-2.4.0-alpha.patch
Patch123: linux-2.4.3-alphaksyms.patch
Patch124: linux-2.4.3-nautilus.patch
Patch125: linux-2.4.5-alphaexports.patch
Patch126: linux-2.4.9-compaq-100_pci_iommu-rh2.4.9-19-200112211039.patch
Patch127: linux-2.4.14-compaq-100_agpgart-2.4.14-200111200804.patch
Patch128: linux-2.4.14-compaq-100_drm-2.4.14-200111201306.patch
Patch129: linux-2.4.14-compaq-100_errors-2.4.14-200111151300.patch
Patch130: linux-2.4.14-compaq-100_pci_init-2.4.6-200107091056.patch
Patch131: linux-2.4.9-compaq-100_vgacon-rh2.4.9-19-200112210831.patch
Patch132: linux-2.4.9-compaq-110_titan-rh2.4.9-19-200112210837.patch
Patch133: linux-2.4.9-compaq-page_to_phys.patch
Patch134: linux-2.4.9-alpha-misc-fixes.patch

# Sparc / Sparc64
Patch140: linux-2.3.99p3p6-sparc.patch

# x86
Patch160: linux-2.4.1-brokenmptable.patch
Patch161: linux-2.4.9-stackcheck.patch
Patch162: linux-2.4.9-ioapicwarn.patch
Patch163: linux-2.4.9-dmatruncated.patch
Patch164: linux-2.4.9-rebootbios.patch
Patch165: linux-2.4.9-xorbug.patch
Patch166: linux-2.4.9-screamingsindy.patch

# ppc
Patch181: linux-2.4.6-ppc-compile.patch
Patch183: linux-2.4.6-ppc-pcnet32.patch
Patch184: linux-2.4.9-ppc-ac10.patch
Patch185: linux-2.4.9-ppc64-ac10.patch
Patch186: linux-2.4.9-ppc64-rh.patch

# s390 / s390x
Patch200: linux-2.4.9-s390-ac14.patch
Patch205: linux-2.4.9-s390-rh.patch
Patch206: linux-2.4.9-s390-dasd.patch
Patch207: linux-2.4.9-s390-rh2.patch
Patch208: linux-2.4.9-s390-54390.patch
Patch209: linux-2.4.9-s390-dasdmsg.patch
Patch210: linux-2.4.13-s390-ac7.patch
#Patch211: linux-2.4.9-s390-realrootdev.patch is now 925
Patch212: linux-2.4.9-s390-fs.patch
Patch213: linux-2.4.7-s390-3.patch
Patch214: linux-2.4.9-s390-fsm.patch
Patch215: linux-2.4.9-s390-raid.patch
Patch216: linux-2.4.7-unblank.patch
Patch217: linux-2.4.7-sysinfo.patch
Patch218: linux-2.4.7-s390-4.patch
#Patch219: linux-2.4.10-s390-procfs.patch is now 2330
Patch220: linux-2.4.9-s390-ramdisk.patch
Patch221: linux-2.4.9-s390-kerntypes.patch
Patch222: linux-2.4.9-s390-mathemu.patch
#Patch223: linux-2.4.9-cramfs.patch is now 2340
Patch224: linux-2.4.9-s390-cpint.patch


#
# Patches 400 through 599 are the TUX patches
#

Patch400: linux-2.4.2-byteprofiling.patch
Patch410: linux-2.4.2-pid-profiling.patch
Patch420: linux-2.4.2-smptimers.patch
Patch425: linux-2.4.9-f_atomic.diff
Patch430: linux-2.4.9-pagecache.patch
Patch440: linux-2.4.2-atomic-lookup.patch
Patch450: linux-2.4.2-iput-free.patch
Patch460: linux-2.4.2-exports-cleanup.patch
Patch470: linux-2.4.2-tux-vfs.patch
Patch480: linux-2.4.2-atomicalloc.patch
Patch490: linux-2.4.2-per-cpu-pages.patch
Patch500: linux-2.4.2-tux-process.patch
Patch510: linux-2.4.2-vm-1-2-3-gbyte.patch
Patch530: linux-2.4.2-tux-sysctl.patch
Patch540: linux-2.4.2-tux-kstat.patch
Patch550: linux-2.4.2-net-exports.patch
Patch560: linux-2.4.2-tux-syscall.patch
Patch570: linux-2.4.3-bustspinlocks.patch
Patch580: linux-2.4.9-tux2.patch
Patch581: linux-2.4.9-tux2-fixes.patch

#
# Patches 600 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#

Patch600: linux-2.4.0-nonintconfig.patch
Patch610: linux-2.4.3-maxsectors.patch
Patch620: linux-2.4.1-quiet.patch
Patch630: linux-2.4.7-quotareturn.patch
Patch640: linux-2.2.16-rhconfig.patch
Patch650: linux-2.4.2-changeloop.patch
Patch660: linux-2.4.1-printkbuffer.patch
Patch670: linux-2.4.5-config-small.patch
Patch680: linux-2.4.9-scsilun0.patch
Patch690: linux-2.4.6-multipath.patch
Patch700: linux-2.4.2-blkioctl-sector.patch
Patch710: linux-2.4.5-hotplug.patch
Patch711: linux-2.4.9-hotplug.patch
Patch720: linux-2.4.5-i386i586.patch
Patch730: linux-2.4.1-scsi-reset.patch
Patch740: linux-2.4.2-pge.patch
Patch750: linux-2.4.3-irixnfs.patch
Patch760: linux-2.4.2-scsi_scan.patch
Patch770: linux-2.4.0-cipe-1.4.5.patch
Patch771: linux-2.4.2-cipe.patch
Patch772: linux-2.4.9-cipenat.patch
Patch780: linux-2.4.2-bootmem_oom.patch
Patch790: linux-2.4.9-lm_sensors.patch
Patch791: linux-2.4.9-i2c.patch
Patch800: linux-2.4.5-cadpid.patch
Patch810: linux-2.4.3-smp_call_function.patch
Patch820: linux-2.4.5-swapinfo.patch
Patch830: linux-2.4.6-nohighmem.patch
Patch841: linux-2.4.6-parportpnp.patch
Patch850: linux-2.4.6-moreswap.patch
Patch860: linux-2.4.6-oom-moderate.patch
Patch870: linux-2.4.9-blockhighmem.patch
Patch880: linux-2.4.6-triplelock.patch
Patch890: linux-2.4.6-oomavoidance.patch
Patch900: linux-2.4.9-gendiskbackout.patch
Patch910: linux-2.4.9-kksymoops.patch
Patch911: linux-2.4.9-kallsyms.patch
Patch920: linux-2.4.7-ioqueue.patch
Patch925: linux-2.4.9-s390-realrootdev.patch
Patch930: linux-2.4.9-tainted.patch
Patch940: linux-2.4.7-vmtuning.patch
Patch950: linux-2.4.9-aging.patch
Patch951: linux-2.4.9-vmtweaks.patch
Patch960: linux-2.4.7-highmemspeed.patch
Patch970: linux-2.4.9-rss.patch
Patch980: linux-2.4.9-o1-scheduler.patch
Patch990: linux-2.4.9-bh_async.patch
Patch991: linux-2.4.9-slabinfo.patch
Patch995: linux-2.4.9-procfs-memleak.patch
Patch997: linux-2.4.9-quirks.patch
Patch998: linux-2.4.9-bh-keepflags.patch

#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#

Patch1000: kernel-2.4-string.patch
Patch1010: linux-2.4.6-cramfs.patch
Patch1020: linux-2.4.2-req_finished_io.patch
Patch1030: linux-2.4.9-qladrivers.patch
Patch1040: linux-2.4.0-sym53-64bit.patch
Patch1060: linux-2.4.18-pge.patch 
Patch1080: linux-2.4.0-test11-vidfail.patch
Patch1090: linux-2.4.0-e820.patch
Patch1100: linux-2.4.0-raid5xor.patch
Patch1110: linux-2.4.2-mem-setup-fix.patch
Patch1120: linux-2.4.2-page_bitmap.patch
Patch1130: linux-2.4.0-apic-quiet.patch
Patch1140: linux-2.4.1-setup_delay.patch
Patch1150: linux-2.4.1-uhci-slab.patch
Patch1160: linux-2.4.7-i810.patch
Patch1180: linux-2.4.3-i82365.patch
Patch1200: linux-2.4.3-dellmptable.patch
Patch1210: linux-2.4.9-moreunnamed.patch
Patch1220: linux-2.4.1-netdebug.patch
Patch1230: linux-2.4.3-450gx.patch
Patch1250: linux-2.4.2-eepro100-alpha.patch
Patch1260: linux-2.4.3-pcipenalty.patch
Patch1270: linux-2.4.3-wakeupspeed.patch
Patch1280: linux-2.4.3-ecn.patch
Patch1290: linux-2.4.2-ideblacklist.patch
Patch1310: linux-2.4.7-usb-bug51142.patch
Patch1320: linux-2.4.7-usb-bug50218.patch
Patch1330: linux-2.4.2-usb-scsiglue.patch
Patch1340: linux-2.4.2-keyboardsilence.patch
Patch1350: linux-2.4.3-upapic.patch
Patch1360: linux-2.4.2-viadma66.patch
Patch1370: linux-2.4.3-pcnet32.patch
Patch1390: linux-2.4.2-usbthrottle.patch
Patch1391: linux-2.4.9-ac10-usb-tmp.patch
Patch1395: linux-2.4.9-usb-bug57531.patch
Patch1400: linux-2.4.3-sb.patch
Patch1410: linux-2.4.2-ohci-irq.patch
Patch1440: linux-2.4.3-sysrqT-cpu.patch
Patch1450: linux-2.4.5-xircom-cb.patch
Patch1470: linux-2.4.6-sb_id.patch
Patch1480: linux-2.4.7-dellreboot.patch
Patch1660: linux-2.4.18-netupdates.patch
Patch1680: linux-2.4.7-scsitimeout.patch
Patch1750: linux-2.4.7-pdcraid.patch
Patch1870: linux-2.4.7-noathlon.patch
Patch1880: linux-2.4.9-ataraid.patch
Patch1900: linux-2.4.9-rodent.patch
Patch1910: linux-2.4.7-nfsoops.patch
Patch1920: linux-2.4.9-freevxfs.patch
Patch1930: linux-2.4.9-ide-lba48.patch
Patch1940: linux-2.4.9-maxsectors.patch
Patch1950: linux-2.4.7-natsemi-old.patch
Patch1951: linux-2.4.21-natsemi.patch
Patch1952: linux-2.4.21-natsemi-backport.patch
Patch1960: linux-2.4.9-ips.patch
Patch1970: linux-2.4.7-aic7xxx.patch
Patch1980: linux-2.4.7-ewrk3.patch
Patch1990: linux-2.4.7-diskdma.patch
Patch2010: linux-2.4.9-module_gpl.patch
Patch2020: linux-2.4.9-qla1280.patch
Patch2030: linux-2.4.9-apm.patch
Patch2040: linux-2.4.9-nicupdates.patch
Patch2050: linux-2.4.9-elfbug.patch
Patch2060: linux-2.4.9-ipc.patch
Patch2070: linux-2.4.9-loopfix.patch
Patch2080: linux-2.4.9-radeon.patch
Patch2090: linux-2.4.9-emu10k.patch
Patch2110: linux-2.4.9-ptrace.patch
Patch2120: linux-2.4.9-nfs.patch
Patch2130: linux-2.4.9-quota.patch
Patch2140: linux-2.4.9-ide-tape.patch
Patch2160: linux-2.4.9-440gx-apic.patch
Patch2180: linux-2.4.9-mce.patch
Patch2200: linux-2.4.9-tty.patch
Patch2210: linux-2.4.9-devlock.patch
Patch2220: linux-2.4.9-tid.patch
Patch2230: linux-2.4.9-procmounts.patch
Patch2240: linux-2.4.9-cpumelting.patch
Patch2250: linux-2.4.9-athlonbug.patch
Patch2270: linux-2.4.9-hyperthreading.patch
Patch2280: linux-2.4.9-pcmcia-voltage.patch
Patch2290: linux-2.4.9-acpi.patch
Patch2300: linux-2.4.9-idefloppy.patch
Patch2310: linux-2.4.9-udf.patch
Patch2330: linux-2.4.9-topdeadlock.patch
Patch2340: linux-2.4.9-cramfs.patch
Patch2350: linux-2.4.9-scsifixes.patch
Patch2360: linux-2.4.9-nfs_svc_quiet.patch
Patch2370: linux-2.4.9-i810.patch
Patch2371: linux-2.4.9-i810-2.patch
Patch2372: linux-2.4.9-i810-3.patch
Patch2373: linux-2.4.9-i810-4.patch
Patch2380: linux-2.4.9-watchdog-nowayout.patch
Patch2390: linux-2.4.9-scsimask.patch
Patch2400: linux-2.4.9-rawio.patch
Patch2410: linux-2.4.9-netdump.patch
Patch2420: linux-2.4.9-raid1.patch
Patch2421: linux-2.4.9-raid-fixes.patch
Patch2430: linux-2.4.9-mps14.patch
Patch2440: linux-2.4.9-viaaudio.patch
Patch2450: linux-2.4.9-nfs-failover.patch
Patch2460: linux-2.4.9-ipchainsmodcount.patch
Patch2470: linux-2.4.9-si_swapinfo.patch
Patch2480: linux-2.4.11-stateful-sysrq.patch
Patch2490: linux-2.4.9-blockdrivers.patch
Patch2491: linux-2.4.9-cciss-cpqarray.patch
Patch2500: linux-2.4.9-scsidrivers.patch
Patch2510: linux-2.4.9-nmiprofiling.patch
Patch2520: linux-2.4.9-per-cpu-keventd.patch
Patch2530: linux-2.4.2-swapreclaim.patch
Patch2540: linux-2.4.9-task-map-base.patch
Patch2550: linux-2.4.9-cenatek.patch
Patch2560: linux-2.4.9-fstat.patch
Patch2570: linux-2.4.9-scsierrorfix.patch
Patch2580: linux-2.4.9-signallock.patch
Patch2590: linux-2.4.9-highmem_bounce_debug.patch
Patch2600: linux-2.4.9-scsi-manintrv-fix.patch
Patch2610: linux-2.4.9-gdthoops.patch
Patch2620: linux-2.4.9-megaraid-v1.18-update.patch
Patch2630: linux-2.4.9-3ware-update.patch
Patch2640: linux-2.4.18-ext2-htree.patch
Patch2650: linux-2.4.9-fusion.patch
Patch2660: linux-2.4.9-sis900_new-update.patch
Patch2670: linux-2.4.9-nfs_fattr.patch
Patch2680: linux-2.4.9-nfs_read_eof.patch
Patch2690: linux-2.4.9-nfs_rpc_tcp.patch
Patch2700: linux-2.4.18-it8857.patch
Patch2710: linux-2.5-stack-random.patch
Patch2720: linux-2.4.9-cpqfc-update.patch
Patch2730: linux-2.4.9-usb-bug85211.patch
Patch2732: linux-2.4.9-usb-infoleak-fix.patch
Patch2740: linux-2.4.9-sysrq-trigger.patch
Patch2750: linux-2.4.20-nethashfix.patch
Patch2770: linux-2.4.9-do_brk.patch
Patch3100: linux-2.4.9-smbfs-overflow-fix.patch
Patch3900: linux-2.4.9-smallfixes.patch

#
# Patches 4000 to 5000 are reserved for bugfixes to core system,
#       drivers and filesystems for MIRACLE LINUX
#
Patch4000: linux-2.4.9-nmihook.patch
Patch4010: linux-2.4.9-ioreq.patch
Patch4020: linux-2.4.9-noskip-apic.patch
Patch4030: linux-2.4.9-idecddma-off.patch
Patch4040: linux-2.4.9-p4apic.patch
Patch4050: linux-2.4.9-rawdd.patch
Patch4060: linux-2.4.9-i60uscsi.patch
Patch4070: linux-2.4.9-reiserfs.patch
Patch4080: linux-2.4.9-ich4.patch
Patch4090: linux-2.4.9-inropen.patch
Patch4100: linux-2.4.9-steeleye_nbd.patch
Patch4110: linux-2.4.9-steeleye_nfsd.patch
Patch4111: linux-2.4.9-steeleye_nfsd-obese-stack.patch
Patch4112: linux-2.4.9-nbd_null_sock_shutdown_steeleye22.patch
Patch4120: linux-2.4.9-scsi_write_retries3.patch
Patch4130: linux-2.4.9-tty-oops.patch
Patch4140: linux-2.4.9-fddlockfix.patch
Patch4150: linux-2.4.9-procfs-errorcheck.patch
Patch4180: linux-2.4.9-panic-overflow.patch
Patch4190: linux-2.4.9-ich5-hr-ich6.patch
Patch4191: linux-2.4.9-ich6r-sata-modes.patch
Patch4192: linux-2.4.9-ich7.patch
Patch4200: linux-2.4.9-DAC960-disable-superbh.patch
Patch4220: linux-2.4.9-cdrom.patch
Patch4230: linux-2.4.9-procfs-fix-race.patch
Patch4240: linux-2.4.9-unix_dgram_recvmsg.patch
Patch4250: linux-2.4.9-incorrect-clear_LDT.patch
Patch4260: linux-2.4.9-SysRq-crrection.patch
Patch4270: linux-2.4.2-smptimers-update.patch
Patch4280: linux-2.4.9-kcore-fix.patch
Patch4290: linux-2.4.9-cve-2007-0958.patch
Patch4300: linux-2.4.9-cve-2007-1217.patch
#
# Patches 5000 to 5800 are reserved for new drivers
#
Patch5000: linux-2.4.9-addon.patch
Patch5010: linux-2.4.16-aacraid.patch
Patch5011: linux-2.4.16-aacraid_0.9.9_to_1.1.5-2339.patch
Patch5012: linux-2.4.16-aacraid_2339_to_2340.patch
Patch5020: linux-2.4.9-bcm5700.patch  
Patch5115: linux-2.4.9-aacraid-addon-00909.patch
Patch5021: linux-2.4.9-bcm5700-28.patch
Patch5030: linux-2.4.0-wvlan-cs.patch
Patch5031: linux-2.4.7-wvlan_cs.patch
Patch5040: linux-2.4.1-netfilter-addons.patch
Patch5041: linux-2.4.11-netfilter-iptmac.patch
Patch5042: linux-2.4-netfilter-listdel.patch 
Patch5050: linux-2.4.3-ecc.patch
Patch5060: linux-2.4.9-ext3-0.9.11.patch
Patch5061: linux-2.4.9-ext3-updates.patch
Patch5062: linux-2.4.9-write-efault.patch
Patch5070: linux-2.4.2-alternateairo.patch
Patch5080: linux-2.4.5-mxt.patch	
Patch5081: linux-2.4.6-mxtfix.patch
Patch5082: linux-2.4.6-mxtbios.patch
Patch5090: linux-2.4.6-bcm5820.patch
Patch5091: linux-2.4.6-bcm5820-2.patch
Patch5092: linux-2.4.7-bcm5820-16.patch
Patch5093: linux-2.4.7-bcm5820-17.patch
Patch5094: linux-2.4.9-bcm5820_bzero.patch
Patch5100: linux-2.4.21-e100e1000.patch
Patch5101: linux-2.4.21-e100e1000-netdump.patch
Patch5102: linux-2.4.21-e100e1000-backport.patch
Patch5120: linux-2.4.6-iscsi.patch
Patch5121: linux-2.4.7-iscsi-update.patch
Patch5122: linux-2.4.9-iscsi.patch
Patch5130: linux-2.4.7-ethtool.patch
Patch5150: linux-2.4.7-axnet-cs.patch
Patch5160: linux-2.4.7-suspend.patch
Patch5170: linux-2.4.7-avm_cs.patch
Patch5180: linux-2.4.7-tulip.patch
Patch5190: linux-2.4.9-pppoatm.patch
Patch5200: linux-2.4.9-aep.patch
Patch5210: linux-2.4.9-qla2200.patch
Patch5220: linux-2.4.9-emu10k1_new.patch
Patch5230: linux-2.4.18-tg3.patch
Patch5235: linux-2.4.18-tg3-updates.patch
Patch5236: linux-2.4.18-tg3-upd-12.patch
Patch5237: linux-2.4.18-tg3-12e1.patch
Patch5238: linux-2.4.20-tg3.patch
Patch5240: linux-2.4.9-netdump-fixes.patch
Patch5250: linux-2.4.9-feral-qlogic-isp.patch
Patch5260: linux-2.4.9-feral-qlogic-isp-config.patch
Patch5270: linux-2.4.9-qla2200-devidfix.patch
Patch5280: linux-2.4.9-qla2200-sparselun.patch
Patch5296: linux-2.4.9-qla2xxx-v6.patch
Patch5300: linux-2.4.9-megaraid-v2.00.patch
Patch5305: linux-2.4.9-megaraid2.patch
Patch5307: linux-2.4.9-megaraid2_2101.patch
Patch5308: linux-2.4.9-megaraid2_2106.patch
Patch5310: linux-2.4.20-e100e1000.patch
Patch5320: linux-2.4.9-ips-addon.patch
Patch5330: linux-2.4.9-i810-rev024.patch
Patch5340: linux-2.4.9-hangcheck.patch
Patch5350: linux-2.4.20-pcnet32-1.27b.patch
Patch5360: linux-2.4.20-ext3-updates.patch
Patch5362: linux-2.4.21-ext3-assert-failure.patch
Patch5364: linux-2.4.21-ext3-throttle-enomem.patch
Patch5366: linux-2.4.21-ext3-uptodate-warning.patch
Patch5368: linux-2.4.21-ext3-balloc.patch
Patch5370: linux-2.4.21-ext3-updates.patch
Patch5372: linux-2.4.21-ext3-uninline.patch
Patch5373: linux-2.4.21-ext3-handle-baddata.patch
Patch5374: linux-2.4.9-ext3-sync.patch
Patch5375: linux-2.4.9-ext3-abort-fix.patch
Patch5376: linux-2.4.9-fork-thread-file-descriptor-race-fix.patch

#
# Patches 5500 to 5800 are New drivers for MIRACLE LINUX
#
Patch5500: linux-2.4.9-aic7xxx-update.patch
Patch5501: linux-2.4.9-aic7xxx-rhtemplate.patch
Patch5502: linux-2.4.9-aic7xxx-makefile.patch
Patch5503: linux-2.4.9-varyio-driver_ML.patch
Patch5504: linux-2.4.9-aacraid-1.1.4.patch
Patch5510: linux-2.4.9-e100-2.3.13.patch
Patch5520: linux-2.4.9-megaraid_default.patch
Patch5521: linux-2.4.9-addon_ML.patch
Patch5522: linux-2.4.9-scsidrv-default_ML.patch
Patch5530: linux-2.4.9-bcm5700-6.2.11.patch
Patch5531: linux-2.4.9-bcm5700-7.1.9.patch
Patch5532: linux-2.4.9-bcm5700-7.3.5a.patch
Patch5540: linux-2.4.9-qla2xxx-v6-ML.patch
Patch5541: linux-2.4.9-qla2xxx-varyio.patch
Patch5542: linux-2.4.9-qla2xxx-memfree.patch
Patch5543: linux-2.4.9-qla2200_5.31S.patch
Patch5544: linux-2.4.9-qla2xxx-CAN-2004-0587.patch
Patch5550: linux-2.4.9-emulex.patch
Patch5551: linux-2.4.9-emulex-makefile.patch
Patch5552: linux-2.4.9-emulex-modversions.patch
Patch5560: linux-2.4.9-lvm-1.0.7.patch
Patch5561: linux-2.4.9-lvm-VFSlock.patch
Patch5562: linux-2.4.9-lvm-fixML.patch
Patch5570: linux-2.4.9-tulip_old.patch
Patch5580: linux-2.4.9-qikdata-1.1.patch
Patch5581: linux-2.4.9-qikdata-build.patch
Patch5590: linux-2.4.9-e1000-5.2.16.patch
Patch5591: linux-2.4.9-e1000-5.2.30.1.patch
Patch5592: linux-2.4.9-e1000-CAN-2004-0535.patch
Patch5595: linux-2.4.9-megaide.patch
Patch5596: linux-2.4.9-megaraid-nec-vid.patch

# LKCD/LKST Patch for MIRACLE LINUX
Patch5600: linux-2.4.9-lkcd-4.1-1.patch
Patch5601: linux-2.4.9-lkcd-die.patch
Patch5602: linux-2.4.9-lkcd-zlib.patch
Patch5603: linux-2.4.9-lkcd-clear-ktype.patch
Patch5604: linux-2.4.9-lkcd-reboot.patch
Patch5605: linux-2.4.9-lkcd-smpwait-fix.patch
Patch5606: linux-2.4.9-lkcd-debug-highmem.patch
Patch5607: linux-2.4.9-lkcd-nmidump.patch
Patch5608: linux-2.4.9-lkcd-sysrq-issuenmi.patch
Patch5609: linux-2.4.9-lkcd-icmpdown.patch

Patch5610: linux-2.4.9-lkst-1.3.patch
Patch5611: linux-2.4.9-lkst-conflict.patch
Patch5612: linux-2.4.9-lkst-addon.patch
Patch5613: linux-2.4.9-lkst-1.3-bugfix.patch
Patch5614: linux-2.4.9-lkst-1.3-o1schd_safe.patch

# Unisys ES7000 patch for MIRACLE LINUX
Patch5620: linux-2.4.9-es7000.patch
Patch5621: linux-2.4.9-es7000-fix.patch
Patch5622: linux-2.4.9-es7000-cpu-online.patch
Patch5623: linux-2.4.9-es7000-lkcd-ipi.patch
Patch5624: linux-2.4.9-es7000-lkcd-interrupt.patch
Patch5625: linux-2.4.9-es7000-ide.patch
Patch5626: linux-2.4.9-es7000-bootkernel.patch

Patch5630: linux-2.4.9-3w-9xxx.patch
Patch5631: linux-2.4.9-3w-9xxx-fix.patch

#
# Patches 5800 to 6000 are the HA/IPVS patches
#
Patch5800: linux-2.4.2-ipvs.patch
Patch5810: linux-2.4.5-ipvsfix.patch
Patch5820: linux-2.4.5-ipvs-0.8.1.patch
Patch5830: linux-2.4.9-arpnetfilter.patch

#
# Patches 6000 and later are reserved for %if {something} patches
#
Patch6000: linux-2.4.9-linux-abi.patch
Patch6010: iorl-2.4.9.patch
Patch6020: oracle-phase2.patch
Patch6030: linux-2.4.9-lowlat.patch

# 6100-6400: aio
#Patch6100: linux-2.4.9-vsyscall_i386.diff
Patch6200: linux-2.4.9-aio-00_fput.diff
Patch6210: linux-2.4.9-aio-00_kvec.diff
Patch6215: linux-2.4.9-aio-00_kvec_ops.diff
Patch6225: linux-2.4.9-aio-00_waitqueue_func.diff
Patch6230: linux-2.4.9-aio-00_waitqueue_lifo.diff
Patch6235: linux-2.4.9-aio-00_worktodo.diff
Patch6240: linux-2.4.9-aio-05_brw_kvec_async.diff
Patch6245: linux-2.4.9-aio-05_ext2.diff
Patch6250: linux-2.4.9-aio-05_fput_cleanup.diff
Patch6255: linux-2.4.9-aio-05_generic_kvec_rw.diff
Patch6260: linux-2.4.9-aio-05_new_rw.diff
Patch6265: linux-2.4.9-aio-05_raw_kvec.diff
Patch6270: linux-2.4.9-aio-10_aio-core.diff
Patch6275: linux-2.4.9-aio-10_aio-fops.diff
Patch6280: linux-2.4.9-aio-10_aio_maint.diff
Patch6285: linux-2.4.9-aio-10_ext2_aio.diff
Patch6286: linux-2.4.9-aio-10_other_fs.diff
Patch6290: linux-2.4.9-aio-10_raw_aio.diff
Patch6292: linux-2.4.9-aio-15-tuxify.diff
Patch6295: linux-2.4.9-aio-20_aio_poll.diff
Patch6300: linux-2.4.9-aio-50_aio_syscall.diff
Patch6310: linux-2.4.9-aio-60-ring.patch
Patch6400: linux-2.4.9-syscall-by-name.diff
Patch6401: linux-2.4.9-aio-61-fastsyscall.patch
Patch6402: linux-2.4.9-syscall-by-name-vma.diff
Patch6403: linux-2.4.9-aio-62-limits.diff
Patch6405: linux-2.4.9-aio-race.patch



# debugging
Patch7000: linux-2.4.2-aviro-buffer.c.patch
Patch7010: linux-2.4.0-nohighmemdebug.patch
Patch7020: linux-2.4.2-hexblocknumbers.patch
Patch7030: linux-2.4.2-vmpoison.patch
Patch7040: linux-2.4.1-debugging.patch
Patch7050: linux-2.4.2-smbdebug.patch


# etc. for MIRACLE LINUX
Patch8000: linux-2.4.9-compile.h.patch
Patch8010: linux-2.4.9-pciids.patch
Patch8020: linux-2.4.9-ksymnumber.patch
Patch8021: linux-2.4.9-ksymnumber2.patch
Patch8030: linux-2.4.9-export-gendisk_head.patch
Patch8040: linux-2.4.26-updates-fix-ksyms.patch

#
# Patches 9000 to 9900 are reserved for MIRACLE LINUX update drivers
#
Patch9000: linux-2.4.9-ips-addon-61107.patch
Patch9001: linux-2.4.9-ips-addon-71018.patch
Patch9010: linux-2.4.9-dpt_i2o.patch
Patch9011: linux-2.4.9-dpt_i2o-varyio.patch
Patch9012: linux-2.4.9-dpt_i2o-backup.patch
Patch9020: linux-2.4.9-aic79xx-2.0.12.patch
Patch9021: linux-2.4.9-aic79xx-2.0.12-fix.patch
Patch9022: linux-2.4.9-aic79xx-default.patch
Patch9030: linux-2.4.9-e1000-5.5.4.patch
Patch9031: linux-2.4.9-e1000-5.2.30.1-backup.patch
Patch9040: linux-2.4.9-e100-3.3.6.patch

#
# 10000 and later is for stuff that has to come last due to the
# amount of drivers they touch
#
Patch10000: linux-2.4.0-sard.patch
Patch10001: linux-2.4.9-sard-gendisk.patch
Patch10002: linux-2.4.9-scsi-bug67555.patch
# fix a lot of warnings in the plain kernel and previous patches
Patch10010: linux-2.4.1-compilefailure.patch
Patch10020: linux-2.4.9-module_license.patch
Patch10021: linux-2.4.9-module_license_i386.patch
Patch10030: linux-2.4.9-ns83820-0.15.patch
Patch10040: linux-2.4.9-uvirt-to-kva.patch
Patch10041: linux-2.4.9-highpte.patch
Patch10042: linux-2.4.9-setup-highmem.patch
Patch10043: linux-2.4.9-quicklists.patch
Patch10045: linux-2.4.9-vma.patch
Patch10050: linux-2.4.9-mmap-merge.patch
Patch10055: linux-2.4.9-statm-B1.diff
Patch10060: linux-2.4.9-bigpages.patch
Patch10061: linux-2.4.9-bigpages-fix.patch
Patch10062: linux-2.4.9-bigpages-again.patch
Patch10070: linux-2.4.9-greedy-swap.patch
Patch10080: linux-2.4.9-exports.patch
Patch10090: linux-2.4.9-close-unmount.patch
Patch10091: linux-2.4.9-veritasexports.patch
Patch10100: linux-2.4.9-slabdebug.patch
Patch10110: linux-2.4.9-proc-stat-fix.patch
Patch10120: linux-2.4.9-fs-locks-update.patch
Patch10121: linux-2.4.9-flock.patch
Patch10130: linux-2.4.9-scsi-whitelist.patch
Patch10140: linux-2.4.9-aic79xx.patch
Patch10141: linux-2.4.9-aic-update.patch
Patch10145: linux-2.4.9-aic-makefile.patch
Patch10147: linux-2.4.9-aic-backup.patch
Patch10148: linux-2.4.9-aic79xx-20040522.patch
Patch10150: linux-2.4.9-corename-sysctl.patch
Patch10160: linux-2.4.9-updates.patch
Patch10170: linux-2.4.9-scsi-128devs.patch
Patch10200: linux-2.4.9-lsb.patch
Patch10210: linux-2.4.9-noht.patch
Patch10230: linux-2.4.9-superbh.patch
Patch10231: linux-2.4.9-superbh-updates.patch
Patch10240: linux-2.4.9-varyio.patch
Patch10241: linux-2.4.9-superbh-mergewithvaryio.patch
Patch10242: linux-2.4.9-varyio-updates.patch
Patch10243: linux-2.4.9-superbh-fix-abi.patch
Patch10244: linux-2.4.9-superbh-fix-bounce.patch
Patch10245: linux-2.4.9-varyio-abi.patch
Patch10250: linux-2.4.9-ptrace-harden.patch
Patch10260: linux-2.4.9e12_summit-2003-03-14.patch
Patch10261: linux-2.4.9e12_686-notsc_A0.patch
Patch10262: linux-2.4.9e12_cyclone-timer_B2.patch
Patch10263: linux-2.4.9e12_lost-tick_A0.patch
Patch10264: linux-2.4.9e12_get_irq_list.patch
Patch10265: linux-2.4.9-summit-notsc-soft.patch
Patch10266: linux-2.4.9-varyio-driver.patch
Patch10270: linux-2.4.20-end-request.patch
Patch10280: linux-2.4.9-posix_race.patch
Patch10286: linux-2.4.23-updates.patch
Patch10288: linux-2.4.26-updates.patch
Patch10290: linux-2.4.22-floppy-locking-fix.patch
Patch10295: linux-2.4.29-floppy-boot-time-detection-fix.patch

# vm performance fixes
Patch12000: linux-2.4.9-vmfixes9.patch
Patch12010: linux-2.4.9-refill.patch
Patch12020: linux-2.4.9-prune_icache.patch
Patch12030: linux-2.4.9-swapout.patch
Patch12040: linux-2.4.9-pagecache_steal.patch
Patch12050: linux-2.4.9-io_throttle.patch
Patch12060: linux-2.4.9-swapmap.patch
Patch12070: linux-2.4.9-vmfixes_tuning.patch
Patch12080: linux-2.4.9-showmem.patch
Patch12090:linux-2.4.9-more-vmfixes.patch

# addition to PCI subsystem: MWI support
Patch21020: linux-2.4.21-pci-mwi.patch

BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

%package source
Summary: The source code for the Linux kernel.
Group: Development/System
Prereq: fileutils
Requires: gawk
Requires: gcc >= 2.95.3

%package headers
Summary: Header files for the Linux kernel.
Group: Development/System
Prereq: fileutils, initscripts >= 5.83, sh-utils
Requires: gawk

%package doc
Summary: Various documentation bits found in the kernel source.
Group: Documentation

%description 
The kernel package contains the Linux kernel (vmlinuz), the core of your
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

%description source
The kernel-source package contains the source code files for the Linux
kernel. These source files are needed to build most C programs, since
they depend on the constants defined in the source code. The source
files can also be used to build a custom kernel that is better tuned
to your particular hardware, if you are so inclined (and you know what
you're doing).

%description headers
Kernel-headers includes the C header files for the Linux kernel.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
kernel.

%description doc
This package contains documentation files form the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files. 

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.

%package smp
Summary: The Linux kernel compiled for SMP machines.
Group: System Environment/Kernel
Provides: module-info, kernel = %{version}, kernel-drm = %{drmver}
Prereq: %{kernel_prereq}
Conflicts: %{kernel_conflicts}

%description smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs, although it should
work fine on single-CPU boxes.

Install the kernel-smp package if your machine uses two or more CPUs.

%package enterprise
Summary: The Linux Kernel compiled with options for machines with more than 4 Gigabyte of memory.
Group: System Environment/Kernel
Provides: module-info, kernel = %{version}, kernel-drm = %{drmver}
Prereq: %{kernel_prereq}
Conflicts: %{kernel_conflicts}


%description enterprise
This package includes a kernel that has appropriate configuration options
enabled for Pentium III machines with 4 Gigabyte of memory or more.

%package summit
Summary: The Linux Kernel compiled with options for IBM Summit architecture
Group: System Environment/Kernel
Provides: module-info, kernel = %{version}, kernel-drm = %{drmver}
Prereq: %{kernel_prereq}
Conflicts: %{kernel_conflicts}


%description summit
This package includes a kernel that has appropriate configuration options
enabled for the IBM Summit machines, which are not PC compatible.
Do not use this package if you do not have such a machine.

%package debug
Summary: The Linux Kernel compiled with options for kernel debugging
Group: System Environment/Kernel
Provides: module-info, kernel = %{version}, kernel-drm = %{drmver}
Prereq: %{kernel_prereq}
Conflicts: %{kernel_conflicts}


%description debug 
This package includes a kernel that has the IKD
kernel patch built in and has several other kernel debugging
settings enabled.

%package BOOT
Summary: The version of the Linux kernel used on installation boot disks.
Group: System Environment/Kernel
Provides: kernel = %{version}
Prereq: %{BOOT_kernel_prereq}
Conflicts: %{kernel_conflicts}

%description BOOT
This package includes a trimmed down version of the Linux kernel.
This kernel is used on the installation boot disks only and should not
be used for an installed system, as many features in this kernel are
turned off because of the size constraints.

%package BOOTsmp
Summary: The Linux kernel used on installation boot disks for SMP machines.
Group: System Environment/Kernel
Provides: kernel = %{version}
Prereq: %{BOOT_kernel_prereq}
Conflicts: %{kernel_conflicts}

%description BOOTsmp
This package includes a trimmed down version of the Linux kernel. This
kernel is used on the installation boot disks only and should not be used
for an installed system, as many features in this kernel are turned off
because of the size constraints. This kernel is used when booting SMP
machines that have trouble coming up to life with the uniprocessor kernel.

%package jensen
Summary: The Linux Kernel compiled for the Alpha Jensen platform.
Group: System Environment/Kernel
Provides: kernel = %{version}
Prereq: %{kernel_prereq}
Conflicts: %{kernel_conflicts}

%description jensen
This package includes a kernel that has appropriate configuration
options enabled for use on the Alpha Jensen platform.  The Jensen
platform is not supported in the normal generic alpha kernel support.

%package tape
Summary: The Linux Kernel compiled for booting from tape
Group: System Environment/Kernel
Provides: kernel = %{version}
Prereq: %{kernel_prereq}
Conflicts: %{kernel_conflicts}

%description tape
This package includes a kernel that has appropriate configuration
options enabled for booting from tape.

%package BOOTtape
Summary: The version of the Linux kernel used on installation boot tapes.
Group: System Environment/Kernel
Provides: kernel = %{version}
Prereq: %{BOOT_kernel_prereq}
Conflicts: %{kernel_conflicts}

%description BOOTtape
This package includes a kernel that has appropriate configuration
options enabled for booting from tape.


%prep

%setup -q -n %{name}-%{version} -c
cd linux

#
# Patches 0 through 100 are meant for core subsystem upgrades
# 

# -acX patch
%patch1 -p1

# use vmalloc for /proc to get a guard page
%patch10 -p1

# make vsnprintf return the correct length
%patch11 -p1

# kill duplicate stacks in sysrq-t
#%patch12 -p1

# 
# Patches 100 through 400 are architecture specific patches
# Each architecture has 20 slots reserved.
#

# IA64
%ifarch ia64
# base ia64 patch from David Mosberger
%patch100 -p1
%patch101 -p1
%patch102 -p1
%patch104 -p1
%patch105 -p1
%patch106 -p1
%patch107 -p1
%patch108 -p1
%patch109 -p1
%patch110 -p1
%patch111 -p1
%patch112 -p1
%patch113 -p1
%endif

# Alpha

# fix some include files
%patch120 -p1
%patch121 -p1
%patch122 -p1
# Missing smp_call_function EXPORT for alpha
%patch123 -p1
# Alpha Nautilus patch
%patch124 -p1
# exports revisted
%patch125 -p1


# Sparc / Sparc64

%patch140 -p1

# x86
# work around broken MP tables from bioses
%patch160 -p1

# check for stack overflows
%patch161 -p1

# Fix IOAPIC warnings
%patch162 -p1

# Fix DMA address truncation over 4GB
%patch163 -p1

# Fix hang when specifying reboot=bios option.
%patch164 -p1

# Fix potential RAID5 data curruption.
%patch165 -p1

# Fix leaking XMM registers to other processes.
%patch166 -p1

# ppc
# make the ppc tree build
%patch181 -p1
# fix pcnet32 problem seen on pSeries
%patch183 -p1
# make the 2.4.9-ac10 patch build
%patch184 -p1
%ifarch %{all_ppc}
%patch185 -p1
# make the ppc64 patch build with Red Hat Linux specific mods
%patch186 -p1
%endif

# s390
#
%ifarch s390 s390x
# modifications backported from 2.4.9ac14
%patch200 -p1
# modifications that are Red Hat Linux specific or from s390-1
%patch205 -p1
# non-working patch
#%patch206 -p1
%patch207 -p1
# integrated in official IBM-3
# %patch208 -p1
%patch209 -p1
%patch210 -p1
#%patch211 -p1 is now 925
%patch212 -p1
%patch213 -p1
%patch214 -p1
# there is isdn/fsm.c already
[ -f drivers/s390/net/fsm.c ] && mv drivers/s390/net/fsm.c drivers/s390/net/fsm-s390.c
%patch215 -p1
%patch216 -p1
# 217 is in 218
#%patch217 -p1
%patch218 -p1
# %patch219 -p1  is now 2330 
%patch220 -p1 -b .ram
%patch221 -p1 -b .kerntypes
[ -f include/asm-s390/dump.h ] || echo '/* dummy */' > include/asm-s390/dump.h
%patch222 -p1 -b .memu
# %patch223 -p1 -b .cramfs is now 2340
%patch224 -p1 -b .cpint 
%endif

#
# Patches 400 through 500 are the TUX patches
#

%patch400 -p1
%patch410 -p1
%patch420 -p1
%patch570 -p1
%patch425 -p1
%if %{tux}
%patch430 -p1
%patch440 -p1
%patch450 -p1
%patch460 -p1
%patch470 -p1
%patch480 -p1
%patch490 -p1
%patch500 -p1
%patch510 -p1
%patch530 -p1
%patch540 -p1
%patch550 -p1
%patch560 -p1
%patch580 -p1
%patch581 -p1
%endif



#
# Patches 600 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#


# This patch adds a "make oldconfig_nonint" which is non-interactive and
# also gives a list of missing options at the end. Useful for automated
# builds.
%patch600 -p1
# This patch makes all scsi adapters default to 64 sectors max unless
# overriden by the adapter itself
%patch610 -p1
# prevent the cdrom subsystem from printk'ing caused by broken autorun programs
%patch620 -p1
# tty_write_message needs \r\n -- makes quota messages look nicer
%patch630 -p1
# smarten make oldconfig to use the current kernel as default
%patch640 -p1
# Al Viro's loopback patch 
%patch650 -p1
# Increase prink buffer size (drivers are getting noisier at startup)
%patch660 -p1
# CONFIG_SMALL
%patch670 -p1
# SCSI LUN 0 scanning patch
%patch680 -p1
# multipath RAID
%patch690 -p1
# Add an ioctl to the block layer so we can be EFI compliant
%patch700 -p1
# Add Hotplug PCI support
%patch710 -p1
%patch711 -p1
# Make i386 use -mcpu=586 for optimizing
# %patch720 -p1
# SCSI Reset patch for clustering stuff
%patch730 -p2
# make PGE an option so Cyrix chips work on our 686 kernels
%patch740 -p1
# fix NFS to IRIX servers
%patch750 -p1
# fix lun probing on multilun RAID chassis
%patch760 -p1
# cipe 1.4.5
%patch770 -p1
%patch771 -p1
%patch772 -p1
# if OOM during early boot, print a helpful message
%patch780 -p1
# LM-Sensors
%patch791 -p1
%patch790 -p1
# add sysctl for the pid to notify on cad
%patch800 -p1
# Fix races in smp_call_function if we get duplicate IPIs
%patch810 -p1
# show info about swap allocated and swap used in /proc
##%patch820 -p1
# don't allocate highmem pages on non-highmem machines
%patch830 -p1
# parport pnp missing ifdef
%patch841 -p1
# change from 8 to 32 available swap areas
%patch850 -p1
# workaround triggerhappy OOM killer
#%patch860 -p1
# Jens Axboes highmem IO patch
%ifarch %{all_x86} ia64 alpha %{all_ppc}
%patch870 -p1
%endif
# patch to triple_down
%patch880 -p1
# make oom killer less trigger happy (hack)
%patch890 -p1
# backout the -ac10 gendisk changes; they just don't work right
%patch900 -p1
# kksymoops 
%patch910 -p1
%ifarch %{all_x86}
%patch911 -p1
%endif
# fix elevator hang
%patch920 -p1
# real-root-dev for initrd (not s390 anymore)
%patch925 -p1
# Add /proc/sys/kernel/tainted (Keith Owens)
%patch930 -p1
# fix some of the 2.4.7 VM up
%patch940 -p1
# Rik's VM tuning
%patch950 -p1
# improve IO performance on highmem machines
%patch960 -p1
# fix rss accounting
%patch970 -p1
# Fix end_buffer_io_async on md devices
%patch990 -p1
# fix for /proc/slabinfo
%patch991 -p1
# fix proc mem leak
%patch995 -p1
# add AMD 762 chipset support
%patch997 -p1
# keep bh flags for off disk accesses 
%patch998 -p1

#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#
# add #ifdef __KERNEL__ around includefiles for dietlibc
%patch1000 -p1
# add spinlocks to cramfs decompression for SMP operation
%patch1010 -p1
# add missing symbol export
%patch1020 -p1 
# qla1280 update to 3.23Beta
%patch1030 -p1
# symbios 53c7xxx 64-bit patch
# obsoleted by Jens patch
##%patch1040 -p1
#pge patch
%patch1060 -p1
# add vidfail capability
%patch1080 -p1
# add e820 reporting
%patch1090 -p1
# raid5 xor fix for PIII/P4, should go away shortly
%patch1100 -p1
# mem= command-line adapts itself to existing e820 values.
# Previous version failed on compaqs with broken bioses, needs testing now
%patch1110 -p1
# conservative zone bitmaps to prevent memory corruption
%patch1120 -p1
# Silence the APIC errors a bit
%patch1130 -p1
# Longer setup_delay for cardbus
%patch1140 -p1
# USB uhci slab fix
%patch1150 -p1
# lots of fixes to the i810_audio driver
#%patch1160 -p1
# fix i82364 delay
%patch1180 -p1
# force MPTABLE parsing on defective Intel bioses
%patch1200 -p1
# allow more unnamed mounts by borrowing old, unused major devices
%patch1210 -p1
# disable some networking printk's
%patch1220 -p1
# fix for non-atomic bit clear in eepro100 driver on alpha
%patch1250 -p1
# change IRQ penalty for IRQ 12
%patch1260 -p1
# improve wake_up() performance
%patch1270 -p1
# Make ECN default to off
%patch1280 -p1
# add known broken drives to the DMA blacklist
##%patch1290 -p1
# Bug 51142 - Japanese USB keyboard.
%patch1310 -p1
# Bug 50218 - USB printer probing for HP-1200.
%patch1320 -p1
# Enhancement for the usb scsiglue for oot's installer magic
%patch1330 -p1
# Silence the PS/2 code for USB keyboards
%patch1340 -p1
# fix broken 440GX chipset boards/bioses
%patch1350 -p1
# disable udma66 for via chipsets
%patch1360 -p1
# fix pcnet32 networkdriver load vs ifconfig races
%patch1370 -p1
# Bug 33668
%patch1390 -p1
# Prevent oops in ISO URBs
%patch1391 -p1
# One more Pegasus. 57531.
%patch1395 -p1
# extra PnP id for sb32awe
%patch1400 -p1
# OHCI IRQ sanity check
%patch1410 -p1
# add CPU number to sysrq
%patch1440 -p1
# revert xircom_cb to old driver
%patch1450 -p1
# another sb16 pnp id
%patch1470 -p1
# more DMI entries for rebooting
%patch1480 -p1
# Assorted networking bugfixes
%patch1660 -p1
# make the scsi timeout longer 
%patch1680 -p1
# be more strict about the pdcraid signature
%patch1750 -p1
# add noathlon flag to boot on broken athlon machines
%patch1870 -p1
# update ataraid to latest version
%patch1880 -p1
# fix mousetype reporting to userspace (Vojtech Pavlik)
%patch1900 -p1
# fix oops in nfs
%patch1910 -p1
# make freevxfs autoload
%patch1920 -p1
# 48bit IDE LBA addressing for > 136Gb IDE disks
#%patch1930 -p1
# allow scsi to do large requests
%patch1940 -p1
# provide the 7.1 natsemi net driver as natsemi_old
%patch1950 -p1
# update natsemi net driver to 2.4.<recent>
%patch1951 -p1
%patch1952 -p1
# update ServerRAID to version 4.80 (IBM)
%patch1960 -p1
# fix aic7xxx CONFIG name bugs
%patch1970 -p1
# back out ewrk3 driver to the 2.4.2 versin
%patch1980 -p1
# disable DMA on everything not-a-disk
%patch1990 -p1
# add EXPORT_SYMBOL_GPL (2.4.9-ac16)
%patch2010 -p1
# update qla1280 driver
%patch2020 -p1
# fix APM typo
%patch2030 -p1
# some networkdriver updates from 2.4.10-ac2
%patch2040 -p1
# this prevents executing vmlinux from rebooting the machine
%patch2050 -p1
# ipc code updates from 2.4.9-ac18
%patch2060 -p1
# loop isem bugfix from 2.4.9-ac18
%patch2070 -p1
# fix weird radeon hang (from 2.4.9-ac18)
%patch2080 -p1
# back out to old emu10k driver; new one has too many problems
%patch2090 -p1
# make ptrace work again (2.4.10-ac7)
%patch2110 -p1
# updated NFS code (2.4.10-ac7)
%patch2120 -p1
# quota's on quota files are bad voodoo (2.4.19-ac8)
%patch2130 -p1
# 36628 I/O error reading HP Colorado 5GB tape drive
%patch2140 -p1
# 440GX apic kernel bug fixed
%patch2160 -p1
# disable mce on pentium class machines (2.4.12-ac)
%patch2180 -p1
# fix race in tty switching code
%patch2200 -p1
# fix device locking (2.4.12)
%patch2210 -p1
# export Tid to userspace
%patch2220 -p1
# fix /proc/mounts overflow for lots of mounts
#%patch2230 -p1
# don't melt Pentium IV cpu's with busy waiting loops
%ifarch %{all_x86}
%patch2240 -p1
%endif
# fix up after buggy athlon bioses that make the athlon kernel crash
%patch2250 -p1
# patches for Intel's Hyperthreading technology
%patch2270 -p1
# power down the pcmcia socket on remove
%patch2280 -p1
# acpi table reader
%patch2290 -p1
# ide floppy fix for via (#56613)
%patch2300 -p1
# UDF update to 0.9.5 
##%patch2310 -p1
# fix deadlock in "top"
%patch2330 -p1
# fix cramfs to be SMP safe
%patch2340 -p1
# fix oopses in the scsi code
%patch2350 -p1
# shut nfs up about svc unknown version (0) == nfs ping.
%patch2360 -p1
# fix i810 sound oopses
%patch2370 -p1
%patch2371 -p1
%patch2372 -p1
%patch2373 -p1
# watchdog nowayout made runtime-configurable
%patch2380 -p1
# fix signedness mask problem
%ifarch %{all_x86} ia64 %{all_ppc}
%patch2390 -p1
%endif
# improve raw io performance
%patch2400 -p1
# add netconsole/netdump
%if %{netdump}
%patch2410 -p1
%endif
# fix rare raid1 resync fault
%patch2420 -p1
# misc RAID fixes:
%patch2421 -p1
# comply to the MPS 1.4 spec better 
%patch2430 -p1
# update via audio driver
%patch2440 -p1
# NFS failover support
%patch2450 -p1
# fix rmmod hang of ipchains.o
%patch2460 -p1
# improve si_swapinfo by caching results for a second
#%patch2470 -p1 
# make sysrq usable over ssh
%patch2480 -p1
# updated compaq and dac960 drivers
%patch2490 -p1
# update cciss and cpqarray
%patch2491 -p1
# updated megraid and compaq drivers
%patch2500 -p1
# use the nmi clock for profiling
%patch2510 -p1
# per cpu keventd
%patch2520 -p1
# more agressive swap reclaim
%patch2530 -p1
# make TASK_MAPPED_BASE a runtime tunable
%patch2540 -p1
# extra pci ide
%patch2550 -p1
# make fstat "work" on pipes again, even though this is
# posix unspecified
%patch2560 -p1
# bring sanity into the scsi error handling code
%patch2570 -p1
# missing spinlock for signal access
%patch2580 -p1
# highmem bounce debugging patch
%patch2590 -p1
# don't start LUNs that require manual intervention
%patch2600 -p1
# fix scsi.c to avoid gdth oops
%patch2610 -p1
# megaraid v1.18 updates
%patch2620 -p1
# 3ware update from 1.02.00.008 to 1.02.00.027
%patch2630 -p1
# compatibility for ext2 and htree
%patch2640 -p1
# update mpt fusion driver
%patch2650 -p1
# update sis900_new
%patch2660 -p1

# Added nfs fattr patch
%patch2670 -p1
# Added nfs reading passed EOF patch
%patch2680 -p1
# Added nfs over tcp patches  <---THIS PATCH BREAKS THE ABI !!!
#%patch2690 -p1

# Broken Ring - it#8857
%patch2700 -p1

# reduce stack usaing in random.c
%patch2710 -p1

# update cpqfc driver(v2.1.2)
%patch2720 -p1

# Fix Bladecenter USB, bz#85211.
%patch2730 -p1

# Fix potential kernel->user info leaks in USB drivers
%patch2732 -p1

# /proc/sysrq-trigger support
%patch2740 -p1

# tcp/ip hash table fixes
%patch2750 -p1

# do_brk range check
%patch2770 -p1

# Fix for potential buffer overflows in smbfs
%patch3100 -p1

# Small fixes that can't be categorized elsewhere
%patch3900 -p1

#
# Patch for MIRACLE LINUX
#
# nmihook for NEC ESMPRO
%patch4000 -p1
# the process for both io requests and elevator is improved
%patch4010 -p1
# set 0 to skip_apic_setup for ICH2 interupt trouble
%patch4020 -p1
# set 0 to support-dma for ide_cddrom_driver
%patch4030 -p1
# detect_init_APIC() succeed on P4 UP machine
%patch4040 -p1
# fix error message writing to raw device by dd
%patch4050 -p1
# fix a bug in initio driver
%patch4060 -p1
# fix a bug for reiserfs
%patch4070 -p1
# for intel ich4
%patch4080 -p1
# expand INR_OPEN
%patch4090 -p1
# fix nbd(Network block device) for Lifekeeper
%patch4100 -p1
# support HA-NFS for LifeKeeper
%patch4110 -p1
# fix stack-wasting
%patch4111 -p1
# fix oops when the nbd-clients is killed
%patch4112 -p1
# to avoid data crash when the disk is very busy by HITACHI, Inc
%patch4120 -p1

# tty oops fix
%patch4130 -p1

# fix FDD locking
#patch4140 -p1

# check return from copy_to_user in proc_info_read()
%patch4150 -p1

# fix for the buffer overflow in panic()
%patch4180 -p1

# fix cdrom driver
%patch4220 -p1

# fix race condition, selected from 2.4.27pre
%patch4230 -p1

# fix missing serialazation in unix_dgram_recvmsg
%patch4240 -p1

# fix incorrect clearing of %gs when releasing mm
%patch4250 -p1

# fix memory corruption when /proc/kcore is accessed
%patch4280 -p1

# CVE-2007-0958
%patch4290 -p1

# CVE-2007-1217
%patch4300 -p1

#
# Patches 5000 to 6000 are reserved for new drivers
#
# generic drivers/addon infrastructure
%patch5000 -p1
# aacraid driver
%patch5010 -p1
# aacraid update to 0.9.9 to 1.1.5-2339
%patch5011 -p1
# aacraid 2339-2440
%patch5012 -p1
# aacraid 0.9.9 backup
%patch5115 -p1
# Broadcom BCM5700/5701 Gigabit driver 
%patch5020 -p1
%patch5021 -p1
# wvlan_cs driver
%patch5030 -p1
%patch5031 -p1
# IRC-DCC nat and other netfilter addons
%patch5040 -p1
# netfilter-MAC filter rules
%patch5041 -p1
# netfilter-dos fix
%patch5042 -p1
# ECC reporting module
%patch5050 -p1
# ext3 update
%patch5060 -p1
%patch5061 -p1
%patch5062 -p1
# airo_cs
%patch5070 -p1
# IBM MXT memory compression support
%patch5080 -p1
# fixes / updates to the MXT driver
%patch5081 -p1
%patch5082 -p1
# Broadcom 5820 driver
%patch5090 -p1
%patch5091 -p1
%patch5092 -p1
%patch5093 -p1
%patch5094 -p1
# Intel e100, e1000 drivers
%patch5100 -p1
%if %{netdump}
%patch5101 -p1
%endif
%patch5102 -p1
# iSCSI driver
%patch5120 -p1
%patch5121 -p1
%patch5122 -p1
# add ethtool support to a bunch of the NEW drivers
%patch5130 -p1
# axnet_cs from pcmcia-cs 3.1.27
%patch5150 -p1
# PCI bridge driver for suspend
%patch5160 -p1
# add missing avma1_cs driver
%patch5170 -p1
# add tulip_old driver (2.4.3 version)
%patch5180 -p1
# PPP over ATM (DSL) from Jens Axboe
%patch5190 -p1
# AEP SSL accelerator driver
%patch5200 -p1
# QLA2200/2300 driver
%patch5210 -p1
# Updated but experimental emu10k1 driver
%patch5220 -p1
# tg3 driver
# %patch5230 -p1
# tg3 driver updates
# %patch5235 -p1
# %patch5236 -p1
# tg3 addon 12e1
# %patch5237 -p1
%patch5238 -p1
# netdump fixes
%if %{netdump}
%patch5240 -p1
%endif
# feral qlogic driver
%patch5250 -p1
%patch5260 -p1
# qla2200 dev id fix
%patch5270 -p1
# qla2200 sparse lun fix
%patch5280 -p1
# qla2xxx v6 driver
%patch5296 -p1
# megaraid2 preserve v2.00.2
%patch5300 -p1
# megaraid2 v2.10.6
%patch5305 -p1
# preserve the megaraid2 v.2.10.1
%patch5307 -p1
# preserve the megaraid2 v.2.10.6-RH1
%patch5308 -p1
# add e100 and e1000 backports from 2.4.20 
%patch5310 -p1
# ServRAID ips v5 driver 
%patch5320 -p1
# Update i810_audio and ac97_codec
%patch5330 -p1
# hangcheck patch
%patch5340 -p1
# pcnet32 v1.27b alternate drv
%patch5350 -p1
# ext3 updates
%patch5360 -p1
# ext3 assert failures
%patch5362 -p1
# ext3 throttle enomem
%patch5364 -p1
# change uptodate assertions to printks
%patch5366 -p1
# ext3 make balloc allocate over non-critical memory
%patch5368 -p1
# ext3 updates
%patch5370 -p1
# ext3 uninline
%patch5372 -p1
# ext3 bad data error recovery fix
%patch5373 -p1
# ext3 unsync error when I/O path failed
%patch5374 -p1
# remove patch 5374
%patch5375 -p1
# open() and fork() have raced on file descriptor
%patch5376 -p1

#
# Patches 5800 to 6000 are the HA/IPVS patches
#
%patch5800 -p1
%patch5810 -p1
%patch5820 -p1
# arp netfilter
%patch5830 -p0

#
# Patches 6000 and later are reserved for %if {something} patches
#


# ibcs
# NOTE: IBCS is not supported, might not work at all 
# and might go away at any time.
%if %{ibcs}
%ifarch %{all_x86}
%patch6000 -p1
%endif
%endif

%if %{iorl}
%patch6010 -p1
%patch6020 -p1
%endif

%patch6030 -p1

# Alpha patches from Compaq
%ifarch alpha
%patch126 -p1
%patch127 -p1
%patch128 -p1
%patch129 -p1
%patch130 -p1
%patch131 -p1
%patch132 -p1
%patch133 -p1
%patch134 -p1
%endif


# debugging patches
# extra sanitychecks in bufferhandling
%if %{debugging}
%patch7000 -p1
%patch7020 -p1
%patch7030 -p1
%patch7040 -p1
# Disable an smb debugging check which conflicts with slab poisoning
%patch7050 -p1
%else
%patch7010 -p1
%endif

# MIRACLE LINUX patch
# fix /proc/version
%patch8000 -p1
# modify pci.ids
%patch8010 -p1
# to be same value as RH ksymnumber
%patch8020 -p1

#
# final stuff
#
# SARD patches (needs to be late because it touches lots of drivers)
%patch10000 -p1
%patch10001 -p1
# Fix weird iostat values. This one is a correction for #10000 above.
# We keep it separate to make it easier to experiment with it.
%patch10002 -p1

# lots of small fixes to warnings and other silly bugs
%patch10010 -p1

# GRRRR
%ifarch ia64
%patch103 -p1
%patch114 -p1
%endif


# add MODULE_LICENSE to all modules
%patch10020 -p1
%ifarch %{all_x86}
%patch10021 -p1
%endif

# update dpt_i2o driver to 2.5.0-2331
%patch9010 -p1
# enable varyio of dpt_i2o
%patch9011 -p1
# backup dpt_i2o of 2.4 Build5 into addon
%patch9012 -p1

# ns83820 0.15 update
%patch10030 -p1

# O(1) scheduler
%patch980 -p1

# aio
%if %{aio}
%patch6200 -p1
%patch6210 -p1
%patch6215 -p1
%patch6225 -p1
%patch6230 -p1
%patch6235 -p1
%patch6240 -p1
%patch6245 -p1
%patch6250 -p1
%patch6255 -p1
%patch6260 -p1
%patch6265 -p1
%patch6270 -p1
%patch6275 -p1
%patch6280 -p1
%patch6285 -p1
%patch6286 -p1
%patch6290 -p1
%patch6292 -p1
%patch6295 -p1
#%patch6300 -p1		# no syscalls numbers now.
%patch6310 -p1
%patch6400 -p1
%patch6401 -p1
%patch6402 -p1
%patch6405 -p1
%endif

%patch951 -p1

# pagetables in highmem. Loosly based on the idea by Andrea Arcangeli but
# implemented from scratch to fit 2.4.9
%patch10040 -p1
%patch10041 -p1
%patch10042 -p1
%patch10043 -p1

# add vma parameter to several vm operations
%patch10045 -p1

# merge VMA's for file-backed areas as well
%patch10050 -p1

# make statm accounting fast
%patch10055 -p1

# bigpages
%patch10060 -p1
%patch10061 -p1
%patch10062 -p1

# greedy swap reclaim
%patch10070 -p1

# some exports
%patch10080 -p1

# this little bit of aio went to market all alone
%if %{aio}
%patch6403 -p1
%endif


# Patches required to allow the Veritas volume manager
# (VxVM) to link into the kernel as a module.
%patch10090 -p1
%patch10091 -p1

# debug stuff
%patch10100 -p1

# fix /proc/stat overrun
%patch10110 -p1
# fix for fs/locks.c (bug #64233)
%patch10120 -p1
# fix for out of flock locks (bug #63879)
%patch10121 -p1 
# additions to the list of SCSI devices that get special treatment
%patch10130 -p1
# aic79xx driver, plus an update to aic7xxx
%patch10140 -p1
# Update aic7xxx to 6.2.30 and aic79xx to 1.3.4
%patch10141 -p1
# change the aic7xxx module name to aic7xxx_mod
%patch10145 -p1
# backup aic7xxx and aic79xx
%patch10147 -p1
# Update aic79xx to v2.0.12 and aic7xxx to v6.3.9
#%patch10148 -p1
# add systcl to set core file name
%patch10150 -p1
# security patches
%patch10160 -p1
# lsb compliance
%patch10200 -p1
# noht
%patch10210 -p1

# "superbh" for large atomic IOs
%patch10230 -p1
%patch10231 -p1
# varying blocksize IO for approved drivers
%patch10240 -p1
%patch10241 -p1
%patch10242 -p1
# Fix superbh ABI compatibility
%patch10243 -p1
# Fix superbh bounce buffering
%patch10244 -p1

# fix sd so it can handle up to 128 disks (must patch after varyIO)
%patch10170 -p1

# Make varyio patch ABI compliant
%patch10245 -p1

# harden ptrace
%patch10250 -p1

# Turn on varyio for selected drivers
%patch10266 -p1

# end request
%patch10270 -p1

# fix an Oops in the locking code
%patch10280 -p1

# 2.4.23 updates
%patch10286 -p1
# 2.4.26 updates
%patch10288 -p1

#floppy locking fix
%patch10290 -p1
#floppy boot-time detection
%patch10295 -p1

# vm fixes - Comment out following 8 patches to disable.
%patch12000 -p1
%patch12010 -p1
%patch12020 -p1
%patch12030 -p1
%patch12040 -p1
%patch12050 -p1
#%patch12060 -p1	Dont apply the swap_map indexing patch
%patch12070 -p1
%patch12080 -p1
%patch12090 -p1

# PCI subsystem addition:  MWI API functions
# (backport from 2.4.21-pre)
%patch21020 -p1

# Patches for MIRACLE LINUX
# fix Sysrq deadlock
%patch4260 -p1

# Update driver for MIRACLE LINUX
# update aic7xxx(v 6.2.33) and aic79xx(v1.3.8)
# %patch5500 -p1
# %patch5501 -p1
# %patch5502 -p1
# turn on VARYIO aic7xxx,aic79xx
# %patch5503 -p1
# update e100(v2.3.13) for iANS
%patch5510 -p1
# change default megaraid(v2.00.2)
# %patch5520 -p1
# update broadcom gigabit ethernet driver bcm5700(v6.2.11)
# addons for ML
%patch5521 -p1
# change default scsi drivers
%patch5522 -p1
%patch5530 -p1
# update broadcom gigabit ethernet driver bcm5700(v7.1.9)
%patch5531 -p1
# update broadcom gigabit ethernet driver bcm5700(v7.3.5a)
%patch5532 -p1
# update qlogic driver (v6.04.02)
%patch5540 -p1
%patch5541 -p1
%patch5542 -p1
# update qlogic driver for lifekeeper (v5.31.RH1S)
%patch5543 -p1
# fix CAN-2004-0587
#%patch5544 -p1

# add emulex driver (v1.21g)
%patch5550 -p1
%patch5551 -p1
%patch5552 -p1
# change default tulip driver
%patch5570 -p1
# add QikData driver(v1.1.D585)
%patch5580 -p1
%patch5581 -p1
# update e1000(v5.2.16)
%patch5590 -p1
# update e1000(v5.2.30.1)
%patch5591 -p1
# e1000 memory initialization error
#%patch5592 -p1
# update e1000 to v5.5.4
%patch9030 -p1
# backup e1000 of v5.2.30.1
%patch9031 -p1
# update e100 to v3.3.6
%patch9040 -p1
# add megaide
%patch5595 -p1
mkdir -p drivers/scsi/megaide/lib
cp -f %{SOURCE100} drivers/scsi/megaide/lib/
%patch5596 -p1
# for ICH5, 6300ESB(aka HR), and ICH6
%patch4190 -p1
# for ICH6R SATA in RAID mode or AHCI mode
%patch4191 -p1
# for ICH7
%patch4192 -p1
# add aic7xxx v6.3.9 and aic79xx v2.0.12
%patch9020 -p1
# change ahd_attach_to_HostRAID_controllers from 1 to 0 for aic79xx v2.0.12
%patch9021 -p1
# change default of aic79xx from v1.3.10 to v2.0.12
%patch9022 -p1
# add 3w-9xxx driver v.2.24.01.011fw
%patch5630 -p1
%patch5631 -p1

# disable superbh in DAC960
%patch4200 -p1

# LKCD support for MIRACLE LINUX
%patch5600 -p1
%patch5601 -p1
%patch5602 -p1
%patch5603 -p1
%patch5604 -p1
%patch5605 -p1

# LKCD via NMI for MIRACLE LINUX
%patch5606 -p1
%patch5607 -p1
%patch5608 -p1

# LKCD + LifeKeeper for MIRACLE LINUX
%patch5609 -p1

# LKST support for MIRACLE LINUX
%patch5610 -p1
%patch5611 -p1
%patch5612 -p1
%patch5613 -p1
%patch5614 -p1

# Supoot Unisys ES7000 for MIRACLE LINUX
%patch5620 -p1
%patch5621 -p1
%patch5622 -p1
%patch5623 -p1
%patch5624 -p1
%patch5625 -p1
%patch5626 -p1

# LVM v1.0.7 for MIRACLE LINUX
%patch5560 -p1
%patch5561 -p1
%patch5562 -p1

# to be same value as RH ksymnumber
%patch8021 -p1

# Export gendisk_head
%patch8030 -p1

# fix KMI/ABI ksyms incompatibility
%patch8040 -p1

# update ips to version 6.11.07
%patch9000 -p1

# update ips to version 7.10.18
%patch9001 -p1

# Fix outstanding timer issues from 2.4.9-e.34 (Patch421)
%patch4270 -p1

chmod +x arch/sparc*/kernel/check_asm.sh

mkdir configs
%ifarch %{all_x86}
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-i686*.config configs
rm configs/kernel*summit.config
%else
%ifarch sparc sparc64
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-sparc*.config configs
%else
%ifarch %{all_ppc}
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-ppc*.config configs
%else
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-%{_target_cpu}*.config configs
%endif
%endif
%endif

# make sure the kernel has the sublevel we know it has...
perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile

# get rid of unwanted files
find . -name "*.orig" -exec rm -fv {} \;
find . -name "*~" -exec rm -fv {} \;

chmod 755 arch/*/kernel/check_asm.sh

###
### build
###
%build

# df has a few peculiarities we have to deal with here:
#  o  If it can't find the partition, it calls it "-"
#  o  If the device name is too long (e.g. loopback file)
#     it puts it on a separate line from the data
partitionof ()
{
    # find the directory that exists
    if [ -d "$1" ] ; then
	df "$1" | awk '/^\// {print $1}'
    else
	partitionof $(dirname /$1)
    fi
}
spaceof ()
{
    echo $(($(df $(partitionof $1) | awk '/^\// {if ($4) {print $4}}
              /^[ \t]/ {print $3}') / 1024))
}
# If df exists and df understands the current root directory, check
# space guestimates.  (df may not grok / for some chrooted build envs)
if [ -x /bin/df ] && [ $(partitionof /) != - ] ; then
    if [ "$(partitionof $RPM_BUILD_ROOT)" = "$(partitionof $RPM_BUILD_DIR)" ] ; then
	# The build root and build dir are on one partition; need to check
	# them together
	[ "$(($(spaceof $RPM_BUILD_ROOT)))" -lt \
	  "$((%{RPM_BUILD_ROOT_space} + %{RPM_BUILD_DIR_space}))" ] && {
	    echo "insufficient free disk space to build" >&2 ;
	    exit 1 ;
	}
    else
	# The build root and build dir are on separate partitions; need to
	# check them separately
	[ "$(spaceof $RPM_BUILD_ROOT)" -lt "%{RPM_BUILD_ROOT_space}" ] && {
	    echo "build root $RPM_BUILD_ROOT has insufficient free disk space" >&2 ;
	    exit 1 ;
	}
	[ "$(spaceof $RPM_BUILD_DIR)" -lt "%{RPM_BUILD_DIR_space}" ] && {
	    echo "build dir $RPM_BUILD_DIR has insufficient free disk space" >&2 ;
	    exit 1 ;
	}
    fi
fi

# if RPM_BUILD_NCPUS unset, set it
if [ -z "$RPM_BUILD_NCPUS" ] ; then
    RPM_BUILD_NCPUS=`egrep -c "^cpu[0-9]+" /proc/stat || :` 
    if [ $RPM_BUILD_NCPUS -eq 0 ] ; then
	RPM_BUILD_NCPUS=1
    fi
    if [ $RPM_BUILD_NCPUS -gt 4 ] ; then
	RPM_BUILD_NCPUS=8
    fi
fi


cd linux

AddPatches () {
    # $1 is BOOT/enterprise/debug/foo
    case "$1" in
    debug) patch -p1 < $RPM_SOURCE_DIR/linux-2.4.9-ikd.patch ;;
    summit) patch -p1 < $RPM_SOURCE_DIR/linux-2.4.9e12_summit-2003-03-14.patch
	   patch -p1 < $RPM_SOURCE_DIR/linux-2.4.9e12_686-notsc_A0.patch
	   patch -p1 < $RPM_SOURCE_DIR/linux-2.4.9e12_cyclone-timer_B2.patch
	   patch -p1 < $RPM_SOURCE_DIR/linux-2.4.9e12_lost-tick_A0.patch
           patch -p1 < $RPM_SOURCE_DIR/linux-2.4.9e12_get_irq_list.patch
	   patch -p1 < $RPM_SOURCE_DIR/linux-2.4.9-summit-notsc-soft.patch ;;
    esac
    # remove any backup files that were created
    find . -name "*.orig" -exec rm -fv {} \;
    find . -name "*~" -exec rm -fv {} \;
}

RemovePatches () {
    # $1 is BOOT/enterprise/debug/foo
    case "$1" in
    debug) patch -p1 -R < $RPM_SOURCE_DIR/linux-2.4.9-ikd.patch ;;
    summit) patch -p1 -R < $RPM_SOURCE_DIR/linux-2.4.9-summit-notsc-soft.patch
	   patch -p1 -R < $RPM_SOURCE_DIR/linux-2.4.9e12_get_irq_list.patch
           patch -p1 -R < $RPM_SOURCE_DIR/linux-2.4.9e12_lost-tick_A0.patch
           patch -p1 -R < $RPM_SOURCE_DIR/linux-2.4.9e12_cyclone-timer_B2.patch
           patch -p1 -R < $RPM_SOURCE_DIR/linux-2.4.9e12_686-notsc_A0.patch
           patch -p1 -R < $RPM_SOURCE_DIR/linux-2.4.9e12_summit-2003-03-14.patch ;;
    esac
    # remove any backup files that were created
    find . -name "*.orig" -exec rm -fv {} \;
    find . -name "*~" -exec rm -fv {} \;
}

DependKernel() {
    # is this a special kernel we want to build?
    if [ -n "$2" ] ; then
	Config=$1-$2
	KernelVer=%{version}-%{release}$2
	echo MAKE DEPEND FOR $2 $1 KERNEL...
    else
	Config=$1
	KernelVer=%{version}-%{release}
	echo MAKE DEPEND FOR up $1 KERNEL...
    fi
    make -s mrproper
# We used to copy the config file to arch/.../defconfig, but for some time now
# the Configure script has been smart enough to override this with the
# config file found in configs/kernel-%{kversion}-${config}.config when it
# finds a valid /boot/kernel.h file.  As a result, making an RPM on a
# machine that has a valid kernel.h file will result in scripts/Configure
# overriding our config entries with whatever it thinks is appropriate
# (aka, if you try an i386 build on a machine with an i686 smp kernel.h file
# then you will get an i686 smp kernel in an i386 package).  So, instead we
# put our config file in .config, which is considered the ultimate source
# of default config information by make oldconfig.  Also, copy the config
# files out of the configs directory instead of the RPM_SOURCE_DIR.  It
# doesn't make any sense to put them in there and then not use them,
# especially when we could have a patch that modifies the config files
# as part of the enterprise patch set (or any other patch, it just makes
# us more flexible to use the configs from the configs directory).  Finally,
# since make mrproper wants to wipe out .config files, we move our mrproper
# up before we copy the config files around.
%ifarch %{all_x86}
    cp configs/kernel-%{kversion}-$Config.config .config
%else
%ifarch sparc sparc64
    cp configs/kernel-%{kversion}-$Config.config .config
%else
    cp configs/kernel-%{kversion}-$Config.config .config
%endif
%endif
    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}$2/" Makefile
%ifarch sparc sparc64     
    make -s ARCH=$1 oldconfig_nonint
    make -s ARCH=$1 dep
    make -s ARCH=$1 include/linux/version.h 
%else
    make -s oldconfig_nonint
    make -s dep
    make -s include/linux/version.h 
%endif
}

BuildKernel() {
    if [ -n "$1" ] ; then
	Config=%{_target_cpu}-$1
	KernelVer=%{version}-%{release}$1
	DependKernel %{_target_cpu} $1
	echo BUILDING A KERNEL FOR $1 %{_target_cpu}...
    else
	Config=%{_target_cpu}
	KernelVer=%{version}-%{release}
	DependKernel %{_target_cpu}
	echo BUILDING THE NORMAL KERNEL for %{_target_cpu}...
    fi

%ifarch %{all_x86}
    make -s -j $RPM_BUILD_NCPUS bzImage 
%else
%ifarch %{all_ppc}
    make -s -j $RPM_BUILD_NCPUS vmlinux
%else
%ifarch s390 s390x
    [ "$1" = "debug" ] && export EXTRA_CFLAGS="-gstabs"
    make -s CFLAGS_KERNEL="$EXTRA_CFLAGS" -j $RPM_BUILD_NCPUS image    
%else
    make -s -j $RPM_BUILD_NCPUS boot 
%endif
%endif
%endif
    make -s CFLAGS_KERNEL="$EXTRA_CFLAGS" -j $RPM_BUILD_NCPUS modules
    # first make sure we are not loosing any .ver files to make mrporper's
    # removal of zero sized files.
    find include/linux/modules -size 0 | while read file ; do \
	echo > $file
    done
    # Start installing stuff
    mkdir -p $RPM_BUILD_ROOT/boot
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    install -m 644 Kerntypes $RPM_BUILD_ROOT/boot/Kerntypes-$KernelVer
    install -m 644 $RPM_SOURCE_DIR/module-info $RPM_BUILD_ROOT/boot/module-info-$KernelVer
    mkdir -p $RPM_BUILD_ROOT/dev/shm
%ifarch ia64
    %{_mystrip} --strip-debug vmlinux
%endif
%ifarch %{all_x86}
    cp arch/i386/boot/bzImage $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
    cp vmlinux $RPM_BUILD_ROOT/boot/vmlinux-$KernelVer
%else
%ifarch ia64
    gzip -cfv vmlinux > vmlinuz
    mkdir -p $RPM_BUILD_ROOT/boot/efi
    install -m 755 vmlinux $RPM_BUILD_ROOT/boot/efi/vmlinux-$KernelVer
    install -m 755 vmlinuz $RPM_BUILD_ROOT/boot/efi/vmlinuz-$KernelVer
    ln -s efi/vmlinux-$KernelVer $RPM_BUILD_ROOT/boot/vmlinux-$KernelVer
    ln -s efi/vmlinuz-$KernelVer $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
%else
%ifarch s390 s390x
    install -m 755 Kerntypes $RPM_BUILD_ROOT/boot/Kerntypes-$KernelVer
    install -m 755 arch/%{_target_cpu}/boot/image $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
    install -m 755 arch/%{_target_cpu}/boot/*.boot $RPM_BUILD_ROOT/boot/
%else
%ifnarch %{all_ppc}
    gzip -cfv vmlinux > vmlinuz
    install -m 644 vmlinuz $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
%endif
%endif
    install -m 755 vmlinux $RPM_BUILD_ROOT/boot/vmlinux-$KernelVer
%endif
%endif
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    mkdir -p $RPM_BUILD_ROOT/lib/kernel/$KernelVer
    make -s INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.*
%if %{aio}
    install -m 755 ulib/libredhat-kernel.so.1.0.1 $RPM_BUILD_ROOT/lib/kernel/$KernelVer/
%endif

%ifnarch alpha s390 s390x %{all_ppc}
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/kernel/drivers/addon/qla2xxx/qla2100.o $RPM_BUILD_ROOT/lib/modules/$KernelVer/kernel/drivers/addon/qla2xxx/qla2x00.o
%endif

%ifarch ia64 alpha
    %{_mystrip} --strip-debug `find $RPM_BUILD_ROOT/lib/modules/$KernelVer -type f` || :
%endif

}

SaveHeaders() {
    echo "SAVING HEADERS for $1 $2"
    # deal with the kernel headers that are version specific
    mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1
    install -m 644 include/linux/autoconf.h \
	$RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1/autoconf.h
    install -m 644 include/linux/version.h \
	$RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1/version.h
    mv include/linux/modules \
	$RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1/
    echo $2 $1 ../../savedheaders/$2/$1/ >> $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/list
}

###
# DO it...
###

rm -rf $RPM_BUILD_ROOT

%if %{buildjensen}
BuildKernel jensen
%endif

%if %{buildtape}
BuildKernel tape
SaveHeaders tape %{_target_cpu}
%endif

%if %{buildBOOTtape}
BuildKernel BOOTtape
SaveHeaders BOOTtape %{_target_cpu}
%endif

%if %{builddebug}
%ifarch s390 s390x
BuildKernel debug
SaveHeaders debug %{_target_cpu}
%else
AddPatches debug
BuildKernel debug
SaveHeaders debug %{_target_cpu}
RemovePatches debug
%endif
%endif

%if %{buildsummit}
AddPatches summit
BuildKernel summit
SaveHeaders summit %{_target_cpu}
RemovePatches summit
%endif

%if %{buildenterprise}
BuildKernel enterprise
SaveHeaders enterprise %{_target_cpu}
%endif


%if %{buildsmp}
BuildKernel smp
SaveHeaders smp %{_target_cpu}
%endif

%if %{buildBOOT}
BuildKernel BOOT
SaveHeaders BOOT %{_target_cpu}
%endif

%ifarch i386
DependKernel i586
SaveHeaders up i586
DependKernel i686
SaveHeaders up i686
DependKernel athlon
SaveHeaders up athlon
%endif
%ifarch sparc
DependKernel sparc64
SaveHeaders up sparc64
%endif

%ifarch i386 
DependKernel i586 smp
SaveHeaders smp i586
DependKernel i686 smp
SaveHeaders smp i686
DependKernel i686 enterprise
SaveHeaders enterprise i686
AddPatches summit
DependKernel i686 summit
RemovePatches summit
SaveHeaders summit i686
#AddPatches debug
#DependKernel i686 debug
#SaveHeaders debug i686
#RemovePatches debug
DependKernel athlon smp
SaveHeaders smp athlon
%endif
%ifarch sparc
DependKernel sparc64 smp
SaveHeaders smp sparc64
%endif

# UNIPROCESSOR KERNEL
%if %{buildup}
BuildKernel
%ifarch i386 i686 athlon alpha sparc ia64 s390 s390x %{all_ppc}
SaveHeaders up %{_target_cpu}
%endif
%endif


###
### install
###

%install

cd linux
mkdir -p $RPM_BUILD_ROOT/{boot,sbin}
%ifarch ppciseries
install -m 755 $RPM_SOURCE_DIR/installkernel.iSeries $RPM_BUILD_ROOT/sbin/installkernel
install -m 755 $RPM_SOURCE_DIR/installcmdline.iSeries $RPM_BUILD_ROOT/sbin/installcmdline
%endif

for i in $RPM_BUILD_ROOT/lib/modules/* ; do
  rm -f $i/build 
  ln -sf ../../../usr/src/linux-%{KVERREL} $i/build
done

%ifarch i586 sparc64
# these don't need much
exit 0
%endif

mkdir -p $RPM_BUILD_ROOT/usr/include
ln -sf ../src/linux/include/linux $RPM_BUILD_ROOT/usr/include/linux

mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
tar cf - . | tar xf - -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}custom/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/Makefile
ln -sf linux-%{KVERREL} $RPM_BUILD_ROOT/usr/src/linux
install -m 644 %{SOURCE4}  $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

%ifarch sparc
ln -s ../src/linux/include/asm-sparc $RPM_BUILD_ROOT/usr/include/asm-sparc
ln -s ../src/linux/include/asm-sparc64 $RPM_BUILD_ROOT/usr/include/asm-sparc64
mkdir $RPM_BUILD_ROOT/usr/include/asm
cp -a $RPM_SOURCE_DIR/kernel-2.4-BuildASM.sh $RPM_BUILD_ROOT/usr/src/linux/include/asm-sparc/BuildASM
$RPM_BUILD_ROOT/usr/include/asm-sparc/BuildASM $RPM_BUILD_ROOT/usr/include
%else
ln -sf ../src/linux/include/asm $RPM_BUILD_ROOT/usr/include/asm
%endif

#clean up the destination
make -s mrproper -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
cp configs/kernel-%{kversion}-%{_target_cpu}.config $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/.config
make -s oldconfig_nonint -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
make -s symlinks -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
make -s include/linux/version.h -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

#this generates modversions info which we want to include and we may as
#well include the depends stuff as well, after we fix the paths
make -s depend -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
find $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL} -name ".*depend" | \
while read file ; do
    mv $file $file.old
    sed -e "s|[^ ]*\(/usr/src/linux\)|\1|g" < $file.old > $file
    rm -f $file.old
done

# Try to put some smarter autoconf.h and version.h files in place
pushd $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/include/linux ; {
rm -rf modules modversions.h autoconf.h version.h
cat > modversions.h <<EOF
#ifndef _LINUX_MODVERSIONS_H
#define _LINUX_MODVERSIONS_H
#include <linux/rhconfig.h>
#include <linux/modsetver.h>
EOF
echo '#include <linux/rhconfig.h>' > autoconf.h
list=`find ../../savedheaders/*/*/modules/*.ver -exec basename '{}' \; | sort -u`
mkdir modules
for l in $list; do
    sed 's,$,modules/'$l, ../../savedheaders/list | awk -f %{SOURCE17} > modules/$l
    touch -r modules/$l modules/`basename $l .ver`.stamp
    echo '#include <linux/modules/'$l'>' >> modversions.h
done
echo '#endif' >> modversions.h
sed 's,$,autoconf.h,' ../../savedheaders/list | awk -f %{SOURCE16} >> autoconf.h
install -m 644 %{SOURCE15} rhconfig.h
echo "#include <linux/rhconfig.h>" >> version.h
keyword=if
for i in smp BOOT BOOTsmp enterprise summit debug tape BOOTtape up ; do
# When we build in an i386, we don't have an enterprise header directory
# in savedheaders/i386/enterprise.  We also don't have a BOOT directory
# anywhere except in savedheaders/i386.  So, we need to use this method
# of determining if a kernel version string needs to be included in the
# version.h file
    verh=`echo ../../savedheaders/*/$i/version.h | awk ' { print $1 } '`
    if [ -n "$verh" -a -f "$verh" ]; then
	if [ "$i" = up ]; then
	    if [ "$keyword" = if ]; then
		echo "#if 0" >> version.h
	    fi
  	    echo "#else" >> version.h
	else
	    echo "#$keyword defined(__module__$i)" >> version.h
	    keyword=elif
	fi
	grep UTS_RELEASE $verh >> version.h
    fi
done
echo "#endif" >> version.h
if [ -f ../../savedheaders/%{_target_cpu}/up/version.h ] ; then
    # keep to a standard normally
    HEADER_FILE=../../savedheaders/%{_target_cpu}/up/version.h
else
    # test build not including uniprocessor, must get info from somewhere
    HEADER_FILE=$(ls ../../savedheaders/%{_target_cpu}/*/version.h | head -1)
fi
grep -v UTS_RELEASE $HEADER_FILE >> version.h
rm -rf ../../savedheaders
} ; popd
touch $RPM_BUILD_ROOT/boot/kernel.h-%{kversion}

rm -f $RPM_BUILD_ROOT/usr/include/linux
mkdir -p $RPM_BUILD_ROOT/usr/include/linux
cp -a $RPM_BUILD_ROOT/usr/src/linux/include/linux/* $RPM_BUILD_ROOT/usr/include/linux/
rm -rf $RPM_BUILD_ROOT/usr/include/linux/modules
echo "#error Modules should never use kernel-headers system headers," > $RPM_BUILD_ROOT/usr/include/linux/modversions.h
echo "#error but rather headers from an appropriate kernel-source package." >> $RPM_BUILD_ROOT/usr/include/linux/modversions.h
echo "#error Change -I/usr/src/linux/include (or similar) to" >> $RPM_BUILD_ROOT/usr/include/linux/modversions.h
echo "#error -I/lib/modules/\$(uname -r)/build/include" >> $RPM_BUILD_ROOT/usr/include/linux/modversions.h
echo "#error to build against the currently-running kernel." >> $RPM_BUILD_ROOT/usr/include/linux/modversions.h
%ifarch sparc
rm -f $RPM_BUILD_ROOT/usr/include/asm-sparc
mkdir -p $RPM_BUILD_ROOT/usr/include/asm-sparc
cp -a $RPM_BUILD_ROOT/usr/src/linux/include/asm-sparc/* $RPM_BUILD_ROOT/usr/include/asm-sparc/
rm -f $RPM_BUILD_ROOT/usr/include/asm-sparc64
mkdir -p $RPM_BUILD_ROOT/usr/include/asm-sparc64
cp -a $RPM_BUILD_ROOT/usr/src/linux/include/asm-sparc64/* $RPM_BUILD_ROOT/usr/include/asm-sparc64/
%else
rm -f $RPM_BUILD_ROOT/usr/include/asm
mkdir -p $RPM_BUILD_ROOT/usr/include/asm
cp -a $RPM_BUILD_ROOT/usr/src/linux/include/asm/* $RPM_BUILD_ROOT/usr/include/asm/
%endif

%ifarch i386 i686
install -m755 %{SOURCE10} $RPM_BUILD_ROOT/usr/src/linux/SetupKernelSource.sh
perl -p -i -e "s/\@release\@/%{release}/" \
	$RPM_BUILD_ROOT/usr/src/linux/SetupKernelSource.sh
%endif

for i in $RPM_BUILD_ROOT/lib/modules/*; do
  rm -f $i/modules.*
done

for i in $RPM_BUILD_ROOT/lib/kernel/*; do
  install -m755 %{SOURCE90} %{SOURCE91} $i/
done

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

# do this for upgrades...in case the old modules get removed we have
# loopback in the kernel so that mkinitrd will work.
%pre 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre enterprise
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre summit
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre debug
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre tape
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%post 
cd /boot
%ifnarch ia64 %{all_ppc}
ln -sf vmlinuz-%{KVERREL} vmlinuz
%endif
%ifarch %{all_ppc}
ln -sf vmlinux-%{KVERREL} vmlinux
%endif
ln -sf System.map-%{KVERREL} System.map
ln -sf Kerntypes-%{KVERREL} Kerntypes.map
ln -sf module-info-%{KVERREL} module-info
/bin/sh /lib/kernel/%{KVERREL}/install-proprietary.sh %{KVERREL} up
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
   /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}
else
   depmod -ae -F /boot/System.map-%{KVERREL} %{KVERREL}
   if [ ! -f /boot/initrd-%{KVERREL}.img ] ; then
      /sbin/mkinitrd --ifneeded %{initrd_dir}/initrd-%{KVERREL}.img %{KVERREL}
   fi
fi

%post smp
/bin/sh /lib/kernel/%{KVERREL}smp/install-proprietary.sh %{KVERREL} smp
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
   /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}smp
else
    depmod -ae -F /boot/System.map-%{KVERREL}smp %{KVERREL}smp
    if [ ! -f /boot/initrd-%{KVERREL}smp.img ] ; then
        /sbin/mkinitrd --ifneeded %{initrd_dir}/initrd-%{KVERREL}smp.img %{KVERREL}smp
    fi
fi

%post enterprise
/bin/sh /lib/kernel/%{KVERREL}enterprise/install-proprietary.sh %{KVERREL} enterprise
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
   /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}enterprise
else
    depmod -ae -F /boot/System.map-%{KVERREL}enterprise %{KVERREL}enterprise
    if [ ! -f /boot/initrd-%{KVERREL}enterprise.img ] ; then
        /sbin/mkinitrd --ifneeded %{initrd_dir}/initrd-%{KVERREL}enterprise.img %{KVERREL}enterprise
    fi
fi

%post summit
/bin/sh /lib/kernel/%{KVERREL}summit/install-proprietary.sh %{KVERREL} summit
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
   /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}summit
else
    if [ ! -f /boot/initrd-%{KVERREL}summit.img ] ; then
        /sbin/mkinitrd --ifneeded %{initrd_dir}/initrd-%{KVERREL}summit.img %{KVERREL}summit
    fi
fi

%post debug
/bin/sh /lib/kernel/%{KVERREL}debug/install-proprietary.sh %{KVERREL} debug
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
   /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}debug
else
    if [ ! -f /boot/initrd-%{KVERREL}debug.img ] ; then
        /sbin/mkinitrd --ifneeded %{initrd_dir}/initrd-%{KVERREL}debug.img %{KVERREL}debug
    fi
fi

%post jensen
/bin/sh /lib/kernel/%{KVERREL}jensen/install-proprietary.sh %{KVERREL} jensen
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
   /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}jensen
else
    depmod -ae -i -m /boot/System.map-%{KVERREL}jensen %{KVERREL}jensen
    if [ ! -f /boot/initrd-%{KVERREL}jensen.img ] ; then
        /sbin/mkinitrd --ifneeded %{initrd_dir}/initrd-%{KVERREL}jensen.img %{KVERREL}jensen
    fi
fi

%post tape
/bin/sh /lib/kernel/%{KVERREL}tape/install-proprietary.sh %{KVERREL} tape
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
   /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}tape
else
    depmod -ae -i -m /boot/System.map-%{KVERREL}tape %{KVERREL}tape
    if [ ! -f /boot/initrd-%{KVERREL}tape.img ] ; then
        /sbin/mkinitrd --ifneeded %{initrd_dir}/initrd-%{KVERREL}tape.img %{KVERREL}tape
    fi
fi

%ifnarch ia64
%post BOOT
/bin/sh /lib/kernel/%{KVERREL}BOOT/install-proprietary.sh %{KVERREL} BOOT
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
   /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}BOOT
else
    depmod -ae -F /boot/System.map-%{KVERREL}BOOT %{KVERREL}BOOT
    if [ ! -f /boot/initrd-%{KVERREL}BOOT.img ] ; then
        /sbin/mkinitrd --ifneeded %{initrd_dir}/initrd-%{KVERREL}BOOT.img %{KVERREL}BOOT
    fi
fi

%endif

# Allow clean removal of modules directory
%preun 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
rm -f /lib/modules/%{KVERREL}/modules.*
if [ -x /sbin/new-kernel-pkg ] ; then
    cp -f /etc/lilo.conf /etc/lilo.conf.old
    /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}
else
    :
%ifarch i386 i586 i686 athlon
    rm -f /boot/initrd-%{KVERREL}.img
%endif
fi
/bin/sh /lib/kernel/%{KVERREL}/clean-proprietary.sh %{KVERREL} up


%preun smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
rm -f /lib/modules/%{KVERREL}smp/modules.*
if [ -x /sbin/new-kernel-pkg ] ; then
    cp -f /etc/lilo.conf /etc/lilo.conf.old
    /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}smp
else
    :
%ifarch i386 i586 i686 athlon
rm -f /boot/initrd-%{KVERREL}smp.img
%endif
fi
/bin/sh /lib/kernel/%{KVERREL}smp/clean-proprietary.sh %{KVERREL} smp


%preun enterprise
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
rm -f /lib/modules/%{KVERREL}enterprise/modules.*
if [ -x /sbin/new-kernel-pkg ] ; then
    cp -f /etc/lilo.conf /etc/lilo.conf.old
    /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}enterprise
else
    :
%ifarch i386 i586 i686 athlon
    rm -f /boot/initrd-%{KVERREL}enterprise.img
%endif
fi
/bin/sh /lib/kernel/%{KVERREL}enterprise/clean-proprietary.sh %{KVERREL} enterprise


%preun summit
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
rm -f /lib/modules/%{KVERREL}summit/modules.*
if [ -x /sbin/new-kernel-pkg ] ; then
    /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}summit
else
    :
%ifarch i386 i586 i686 athlon
    rm -f /boot/initrd-%{KVERREL}summit.img
%endif
fi
/bin/sh /lib/kernel/%{KVERREL}summit/clean-proprietary.sh %{KVERREL} summit


%preun debug
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
rm -f /lib/modules/%{KVERREL}debug/modules.*
if [ -x /sbin/new-kernel-pkg ] ; then
    /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}debug
else
    :
%ifarch i386 i586 i686 athlon
    rm -f /boot/initrd-%{KVERREL}debug.img
%endif
fi
/bin/sh /lib/kernel/%{KVERREL}debug/clean-proprietary.sh %{KVERREL} debug

%preun BOOT
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
rm -f /lib/modules/%{KVERREL}BOOT/modules.*
if [ -x /sbin/new-kernel-pkg ] ; then
    cp -f /etc/lilo.conf /etc/lilo.conf.old
    /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}BOOT
else
    :
%ifarch i386 i586 i686 athlon
    rm -f /boot/initrd-%{KVERREL}BOOT.img
%endif
fi
/bin/sh /lib/kernel/%{KVERREL}BOOT/clean-proprietary.sh %{KVERREL} BOOT


%preun jensen
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
rm -f /lib/modules/%{KVERREL}jensen/modules.*
%ifarch i386 i586 i686 athlon
rm -f /boot/initrd-%{KVERREL}jensen.img
%endif
/bin/sh /lib/kernel/%{KVERREL}jensen/clean-proprietary.sh %{KVERREL} jensen


%preun tape
/sbin/modprobe loop 2> /dev/null > /dev/null   || :
rm -f /lib/modules/%{KVERREL}tape/modules.*
if [ -x /sbin/new-kernel-pkg ] ; then
    /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}tape
else
    :
%ifarch i386 i586 i686 athlon
    rm -f /boot/initrd-%{KVERREL}tape.img
%endif
fi
/bin/sh /lib/kernel/%{KVERREL}tape/clean-proprietary.sh %{KVERREL} tape


%preun BOOTtape
/sbin/modprobe loop 2> /dev/null > /dev/null || :
rm -f /lib/modules/%{KVERREL}BOOTtape/modules.*
%ifarch i386 i586 i686 athlon
rm -f /boot/initrd-%{KVERREL}BOOTtape.img
%endif
/bin/sh /lib/kernel/%{KVERREL}BOOTtape/clean-proprietary.sh %{KVERREL} BOOTtape



%pre headers
[ -L /usr/include/linux ] && rm -f /usr/include/linux || :
[ -L /usr/include/asm ] && rm -f /usr/include/asm || :
%ifarch sparc
[ -L /usr/include/asm-sparc ] && rm -f /usr/include/asm-sparc
[ -L /usr/include/asm-sparc64 ] && rm -f /usr/include/asm-sparc64
%endif
exit 0

%post headers
cd /boot
rm -f kernel.h
ln -snf kernel.h-%{kversion} kernel.h
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
exit 0


# We need this here because we don't prereq kudzu; it could be
# installed after the kernel
%triggerin -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin smp -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin enterprise -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin summit -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin BOOT -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin tape -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin jensen -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :


# Old kernel-headers packages owned include symlinks; new
# ones just make them so that we can have multiple kernel-headers
# packages installed.
%triggerpostun headers -- kernel-headers < 2.2.16
cd /boot
rm -f kernel.h
ln -snf kernel.h-%{kversion} kernel.h
exit 0

%triggerpostun source -- kernel-headers < 2.2.16
cd /usr/src
rm -f %{kslnk}
rm -f linux
ln -snf linux-%{KVERREL} %{kslnk}
ln -snf linux-%{KVERREL} linux
exit 0

%post source
cd /usr/src
rm -f %{kslnk}
rm -f linux
ln -snf linux-%{KVERREL} %{kslnk}
ln -snf linux-%{KVERREL} linux

%postun headers
if [ $1 = 0 ]; then
    if [ -L /boot/kernel.h -a `ls -l /boot/kernel.h 2>/dev/null| awk '{ print $11 }'` = "kernel.h-%{kversion}" ]; then
	rm -f /boot/kernel.h
    fi
fi
exit 0

%postun source
if [ $1 = 0 ]; then
    if [ -L /usr/src/%{kslnk} -a `ls -l /usr/src/%{kslnk} 2>/dev/null| awk '{ print $11 }'` = "linux-%{KVERREL}" ]; then
            rm -f /usr/src/%{kslnk}
    fi
    if [ -L /usr/src/linux -a `ls -l /usr/src/linux 2> /dev/null| awk '{ print $11 }'` = "linux-%{KVERREL}" ]; then
            rm -f /usr/src/linux
    fi
fi
exit 0

###
### file lists
###

%if %{buildup}
%files 
%defattr(-,root,root)
/boot/%{kernel_glob}
%ifarch ia64
/boot/efi/%{kernel_glob}
%endif
%ifarch s390 s390x
/boot/*.boot
%endif
/boot/Kerntypes-%{KVERREL}
/boot/module-info-%{KVERREL}
/boot/System.map-%{KVERREL}
%ifarch ppciseries
%config /sbin/installcmdline
%endif
%dir /dev/shm
/lib/modules/%{KVERREL}
/lib/kernel/%{KVERREL}
%endif

%if %{buildsmp}
%ifnarch i386 s390 s390x
%files smp
%defattr(-,root,root)
/boot/%{kernel_glob}smp
%ifarch ia64
/boot/efi/%{kernel_glob}smp
%endif
/boot/module-info-%{KVERREL}smp
/boot/System.map-%{KVERREL}smp
/boot/Kerntypes-%{KVERREL}smp
%ifarch ppciseries
%config /sbin/installcmdline
%endif
%dir /dev/shm
/lib/modules/%{KVERREL}smp
/lib/kernel/%{KVERREL}smp
%endif
%endif

%if %{buildenterprise}
%files enterprise
%defattr(-,root,root)
/boot/%{kernel_glob}enterprise
/boot/module-info-%{KVERREL}enterprise
/boot/System.map-%{KVERREL}enterprise
/boot/Kerntypes-%{KVERREL}enterprise
%dir /dev/shm
/lib/modules/%{KVERREL}enterprise
/lib/kernel/%{KVERREL}enterprise
%endif

%if %{buildsummit}
%files summit
%defattr(-,root,root)
/boot/%{kernel_glob}summit
/boot/module-info-%{KVERREL}summit
/boot/System.map-%{KVERREL}summit
/boot/Kerntypes-%{KVERREL}summit
%dir /dev/shm
/lib/modules/%{KVERREL}summit
/lib/kernel/%{KVERREL}summit
%endif

%if %{builddebug}
%files debug
%defattr(-,root,root)
/boot/%{debug_kernel_glob}debug
/boot/module-info-%{KVERREL}debug
/boot/System.map-%{KVERREL}debug
/boot/Kerntypes-%{KVERREL}debug
%dir /dev/shm
/lib/modules/%{KVERREL}debug
/lib/kernel/%{KVERREL}debug
%endif

%if %{buildjensen}
%files jensen
%defattr(-,root,root)
/boot/%{kernel_glob}jensen
/boot/System.map-%{KVERREL}jensen
/boot/Kerntypes-%{KVERREL}jensen
%dir /dev/shm
/lib/modules/%{KVERREL}jensen
/lib/kernel/%{KVERREL}jensen
%endif

%if %{buildtape}
%files tape
%defattr(-,root,root)
/boot/%{kernel_glob}tape
/boot/Kerntypes-%{KVERREL}
/boot/module-info-%{KVERREL}tape
/boot/System.map-%{KVERREL}tape
%ifarch s390 s390x
/boot/*.boot
%endif
%dir /dev/shm
/lib/modules/%{KVERREL}tape
/lib/kernel/%{KVERREL}tape
%endif

%if %{buildBOOTtape}
%files BOOTtape
%defattr(-,root,root)
/boot/%{kernel_glob}BOOTtape
/boot/Kerntypes-%{KVERREL}
/boot/System.map-%{KVERREL}BOOTtape
%dir /dev/shm
/lib/modules/%{KVERREL}BOOTtape
/lib/kernel/%{KVERREL}BOOTtape
%endif

%if %{buildBOOT}
%files BOOT
%defattr(-,root,root)
/boot/%{kernel_glob}BOOT
/boot/System.map-%{KVERREL}BOOT
%dir /dev/shm
/lib/modules/%{KVERREL}BOOT
/lib/kernel/%{KVERREL}BOOT
%endif

%ifnarch i586 sparc64 athlon
# START BASE ARCHES ONLY
%ifarch i386 i686 alpha sparc ia64 s390 s390x %{all_ppc}

%files source
%defattr(-,root,root)
%dir /usr/src/linux-%{KVERREL}
/usr/src/linux-%{KVERREL}/COPYING
/usr/src/linux-%{KVERREL}/CREDITS
/usr/src/linux-%{KVERREL}/Documentation
/usr/src/linux-%{KVERREL}/MAINTAINERS
/usr/src/linux-%{KVERREL}/Makefile
/usr/src/linux-%{KVERREL}/README
/usr/src/linux-%{KVERREL}/REPORTING-BUGS
/usr/src/linux-%{KVERREL}/Rules.make
%ifarch %{all_x86}
/usr/src/linux-%{KVERREL}/arch/i386
/usr/src/linux-%{KVERREL}/SetupKernelSource.sh
%else
%ifarch %{all_ppc}
/usr/src/linux-%{KVERREL}/arch/ppc
%else
/usr/src/linux-%{KVERREL}/arch/%{_target_cpu}
%endif
%endif
%ifarch sparc
/usr/src/linux-%{KVERREL}/arch/sparc64
%endif
/usr/src/linux-%{KVERREL}/drivers
/usr/src/linux-%{KVERREL}/fs
/usr/src/linux-%{KVERREL}/init
/usr/src/linux-%{KVERREL}/ipc
/usr/src/linux-%{KVERREL}/kernel
/usr/src/linux-%{KVERREL}/lib
/usr/src/linux-%{KVERREL}/mm
/usr/src/linux-%{KVERREL}/net
/usr/src/linux-%{KVERREL}/scripts
/usr/src/linux-%{KVERREL}/ulib
%ifarch %{all_x86}
%{?ibcs_1:/usr/src/linux-%{KVERREL}/abi}
%endif
/usr/src/linux-%{KVERREL}/configs
%ifarch sparc
/usr/src/linux-%{KVERREL}/include/asm-sparc
/usr/src/linux-%{KVERREL}/include/asm-sparc64
%else
%ifarch %{all_x86}
/usr/src/linux-%{KVERREL}/include/asm-i386
%else
%ifarch %{all_ppc}
/usr/src/linux-%{KVERREL}/include/asm-ppc
%else
/usr/src/linux-%{KVERREL}/include/asm-%{_target_cpu}
%endif
%endif
%endif
%ifarch %{all_ppc}
# because some ppc Amiga stuff references some 68000 Amiga stuff
/usr/src/linux-%{KVERREL}/include/asm-m68k
%endif
/usr/src/linux-%{KVERREL}/include/asm
/usr/src/linux-%{KVERREL}/include/asm-generic
%ifarch %{all_x86}
%{?ibcs_1:/usr/src/linux-%{KVERREL}/include/abi}
%endif
/usr/src/linux-%{KVERREL}/include/linux
/usr/src/linux-%{KVERREL}/include/net
/usr/src/linux-%{KVERREL}/include/pcmcia
/usr/src/linux-%{KVERREL}/include/scsi
/usr/src/linux-%{KVERREL}/include/video
%dir /usr/src/linux-%{KVERREL}/include
%dir /usr/src/linux-%{KVERREL}/arch
%ifarch alpha sparc s390 s390x
/usr/src/linux-%{KVERREL}/include/math-emu
%endif  

%files headers
%defattr(-,root,root)
/usr/include/linux
/usr/include/asm
%ifarch sparc
/usr/include/asm-sparc
/usr/include/asm-sparc64
%endif
/boot/kernel.h-%{kversion}

%files doc
%defattr(-,root,root)
%doc linux/Documentation/*

%endif
# END BASE ARCHES ONLY
%endif

%changelog
* Thu Jan 22 2008 Yoshihiro KIKUCHI <ykikuchi@miraclelinux.com> 101ml
- Remove suid/sgid bits on ftruncate()          : CVE-2008-4210 (#3900)
- Add missing capability checks in sbni_ioctl() : CVE-2008-3525 (#10160)
- Fix lookup on deleted directory               : CVE-2008-3275 (#3900)
- Fix memory leak in ipv6/sit                   : CVE-2008-2136 (#3900)
- Fix potential DoS with mremap                 : CVE-2008-0007 (#10045)
- Fix coredump ownership issue                  : CVE-2007-6206 (#12000)
- Fix potential memory overrun in isdn ioctl code : CVE-2007-6151 (#10160)
- Fix potential buffer overflow in isdn           : CVE-2007-6063 (#10160)
- Add missing ioctl() permission checks in aacraid driver : CVE-2007-4308 (#5115)
- Reset PDEATHSIG upon execution of SUID binaries : CVE-2007-3848 (#12000)
- Add missing bounds checking in fib_semantics.c  : CVE-2007-2172 (#3900)
- Fix race condition with mincore()               : CVE-2006-4814 (#12000)

* Fri Oct 12 2007 Robert Lin <robert@miraclelinux.com> 100ml
- fix vulnerabilities : CVE-2007-0958 (#4290), CVE-2007-1217(#4300) 

* Tue Apr 20 2007 Robert Lin <robert@miraclelinux.com> 99ml
- add subsystem vender id of Megaraid for NEC.

* Mon Nov 22 2006 Robert Lin <robert@miraclelinux.com> 98ml
- fix changelog in this spec file. no other changes.

* Mon Nov 22 2006 Robert Lin <robert@miraclelinux.com> 97ml
- add patch (#5375) to remove patch (#5374)

* Fri Jun 23 2006 Robert Lin <robert@miraclelinux.com> 96ml
- fix race condition in calling open() and fork() system calls
  in a multi thread program. bug 1446 (#5376)

* Wed May 17 2006 Yasuma Takeda <yasuma@miraclelinux.com> 95ml
- CAN-2005-0001, fix race condition in expand_stack(), bug 144407 (#10045)

* Fri Nov 11 2005 Robert Lin <robert@miraclelinux.com> 94ml
- modified #5374 patch file to keep compatibility for KABI.
-  
* Tue Oct 18 2005 Robert Lin <robert@miraclelinux.com> 93ml
- bugfix on error handlings in Ext3 under I/O failure condition(#5374)

* Wed Oct 12 2005 Robert Lin <robert@miraclelinux.com> 92ml
- bugfix for kernel panic in __free_pages_ok when (#10062)
  1) assign a bigpages parameter before booting kernel.
  2) set /proc/sys/kernel/shm-use-bigpages to 1 after booting kernel.

* Thu Aug  4 2005 Seiichi Ikarashi <ikarashi@miraclelinux.com> 91ml
- disable piix driver for ICH6R SATA controller in RAID mode or in
  AHCI mode (#4191).
- add ICH7 family support (#4192).

* Tue Jun 28 2005 Akinobu Mita <mita@miraclelinux.com> 90ml
- fix possible mem corruption from /proc/kcore access(#4280)

* Tue Jun 21 2005 Akinobu Mita <mita@miraclelinux.com> 89ml
- Patch from 2.4.9-e.34 (#4270)
- - Fix outstanding timer issues (Ingo Molnar):
-   *races b/w add_timer vs. add_timer, mod_timer, del_timer
-   *make del_timer_sync more robust
-   *race of mod_timer vs. mod_timer, if timer->base is not initialized

* Wed Jun 15 2005 Akinobu Mita <mita@miraclelinux.com> 88ml
- fix sysrq deadlock (#4260)

* Mon Apr 25 2005 Seiichi Ikarashi <ikarashi@miraclelinux.com> 87ml
- update ips driver to 7.10.18 Build 731 (#5521 and #9001) and
  preserve 6.11.07 as ips_61107.o (#9000).
- rearrange diffs in two patch files (#5521 and #9040).

* Thu Apr 14 2005 Bernard Owuor <owuor@miraclelinux.com> 86ml
- e100 update to v3.3.6 (#9040)
- Floppy locking fix  (#10290)
- Floppy boot time detection fix (#10295)

* Thu Mar 31 2005 Yasuma Takeda <yasuma@miraclelinux.com> 85ml
- Fix a aic79xx driver for Dell OEM Adaptec U320 Card w/HostRAID(#9021)

* Tue Jan 18 2005 Akinobu Mita <mita@miraclelinux.com> 84ml
- Fix incorrect clearing of %gs when releasing mm (#4250)

* Tue Jan  4 2005 Yasuma Takeda <yasuma@miraclelinux.com> 83ml
- update cciss to v2.4.52(#2491)
- update bcm5700 to v7.3.5a(#5532)
- fix ICH6R DMA setting(#4190)

* Fri Dec 24 2004 Akinobu Mita <mita@miraclelinux.com> 82ml
- Security fixes:
-    CAN-2004-1068, fix missing serialazation in unix_dgram_recvmsg (#4240)
-    CAN-2004-0883, CAN-2004-0949, fix smbfs buffer overflows (#3100)
-    CAN-2004-0685, fix USB driver info leaks (#2732)
-    CAN-2004-0177, fix possible ext3 infoleak (update #5370)
- Fixes for security holes in binfmt_elf loader (update #2050)

* Fri Dec 24 2004 Akinobu Mita <mita@miraclelinux.com> 81ml
- update aacraid to 1.1.5-2440, backup 0.9.9 (#5011,#5012,#5115)
- update addon_ML.patch and varyio-driver.patch (#5521,#10266)

* Wed Dec 22 2004 Seiichi Ikarashi <ikarashi@miraclelinux.com> 80ml
- Update 3w-9xxx to v2.24.01.011fw (#5630).

* Tue Dec 14 2004 Seiichi Ikarashi <ikarashi@miraclelinux.com> 79ml
- Update pci.ids (#4190 and #8010).
- Update e1000 to v5.5.4 (#9030) and preserve v5.2.30.1 (#9031 and #5521).
- Add 3w-9xxx v2.24.00.011fw (#5630 and #5631).
- Update megaraid to v2.10.9 (#5305) and preserve v2.10.6-RH1
  (#5308 and #5521).
- Add aic7xxx v6.3.9 and aic79xx v2.0.12 (#9020), change a macro
  "ahd_attach_to_HostRAID_controllers" from 1 to 0 in aic79xx v2.0.12
  (#9021), and change default of aic79xx from v1.3.10 to v2.0.12 (#9022).
- Update dpt_i2o to 2.5.0 Build2331 (#9010 and #9011) and
  backup 2.4 Build5 into addon (#9012 and #5521).

* Tue Sep 28 2004 Akinobu Mita <mita@miraclelinux.com> 78ml
- update megaraid2 to v2.10.6 (#5305), and preserve v.2.10.1 (#5307)
- delete duplicated changes in old megaraid-v2.00 (#5300)
- fix and update an addon_ML.patch (move a part of emulex-makefile.patch
  to addon_ML.patch)

* Mon Sep 27 2004 Akinobu Mita <mita@miraclelinux.com> 77ml
- updated the VM fixes (#12090,#12000), and removed slabpages.patch and
  vmfix-buffermem_over_max.patch
- fix a socket shutdown problem from SteelEye (#4112)

* Fri Aug 20 2004 Seiichi Ikarashi <ikarashi@miraclelinux.com> 76ml
- Apply ext2/ext3 patches from RHEL2.1.
  (Add No.5362, 5364, 5366, 5368, 5370, 5372, 5373)

* Mon Aug 09 2004 Seiichi Ikarashi <ikarashi@miraclelinux.com> 75ml
- Restore aic79xx to v1.3.10 and aic7xxx to v6.2.36 as of 73ml.
                 (Add     No.10140, 10141, 10145)
                 (Delete  No.10148)
                 (Restore No.5522, 10266)
- Fix three security bugs:
  CAN-2004-0415: Invalid conversions of 64 to 32-bit file offset pointers
                 and possible race conditions (Update No.5620, 10288).
  CAN-2004-0535: The e1000 driver does not properly initialize memory
                 before using it, which allows local users to read
                 portions of kernel memory (Delete No.5592) (Update No.10288).
  CAN-2004-0587: Insecure permissions for the /proc/scsi/qla2300/HbaApiNode
                 file allows local users to cause a denial of service
                 (Delete No.5544) (Update No.10160, 10288).

* Thu Jul 22 2004 Seiichi Ikarashi <ikarashi@miraclelinux.com> 74ml
- Update aic79xx to v2.0.12 and aic7xxx to v6.3.9
                 (Delete No. 10140, 10141, 10145)
                 (Add    No. 10148)
                 (Modify No. 5522, 10266)

* Mon Jul 05 2004 Akinobu Mita <mita@miraclelinux.com> 73ml
- CAN-2004-0497: users can change the group affiliation of arbitrary files to
  the group they belong to (updates No.10288)

* Fri Jun 25 2004 Akinobu Mita <mita@miraclelinux.com> 72ml
- fix bug in e1000 security fix patch.
- fix insecure permissions for the /proc/scsi/qla2x00/HbaApiNode
  (CAN-2004-0587)
- fix procfs race condition. (No.4230)
- fix KMI/ABI ksyms incompatibility for linux-2.4.26-updates.patch
  (No.8040)

* Mon Jun 21 2004 Seiichi Ikarashi <ikarashi@miraclelinux.com> 70ml
- fix cdrom driver to get out a potential problem of install failure,
  requested by TOSHIBA CORP. (No.4220)

* Mon Jun 21 2004 Akinobu Mita <mita@miraclelinux.com> 69ml
- applied Patch4111
- make kswapd aggressive to reclaim buffermem pages, while most of
  lowmem is consumed in buffermem.(No.4161)
- fix probable security hole in e1000 (No.5592)
- Various drivers sparse type-fixes from Al Viro (No.10288). and
  local-exploit and fork memleak patches (No.4210, No.4170) are
  included in this patch.

* Wed Jun 16 2004 Akinobu Mita <mita@miraclelinux.com> 68ml
- disable superbh in DAC960. (No.4200)
- fix stack waisting in steeleye_nfsd patch. but not appled.(No.4111)
- backup lilo.conf before kernel is uninstalled.
- fix kernel crash-exploit (No.4210)

* Wed Jun  9 2004 Seiichi Ikarashi <ikarashi@miraclelinux.com> 67ml
- Fix the problem that auto ide dma setting does not work
  for intel ICH5, 6300ESB(aka HR), and ICH6 (No.4190)

* Mon May 10 2004 Akinobu Mita <mita@miraclelinux.com> 66ml
- a fix for the memleak in do_fork()
- a fix for the buffer overflow in panic() (CAN-2004-0394)

* Tue May  6 2004 Akinobu Mita <mita@miraclelinux.com> 65ml
- make do_proc_readlink() return -EFAULT when copy_to_user() fails.
  (update No.4150)

* Tue Apr 27 2004 Akinobu Mita <mita@miraclelinux.com> 64ml
- update ips to v6.11.07 (No.9000)
- Fix slabpages counting (the number of pages in the slabcache).

* Fri Apr 23 2004 Akinobu Mita <mita@miraclelinux.com> 62ml
- CAN-2004-0109 isofs fix (update No.10286)

* Mon Mar 29 2004 Akinobu Mita <mita@miraclelinux.com> 60ml
- add grubby to %post and %preun to automatically change lilo.conf
- add megaide to module-info

* Fri Mar 26 2004 Akinobu Mita <mita@miraclelinux.com> 59ml
- update aic7xxx, aic79xx, megaraid
- 1: apply update patches (No. 5305, 10141, 10145, 10147) from 2.4.9-e.37
- 2: remove old update patches (No. 5500, 5501, 5502, 5503, 5520)
- 3: make those default drivers. (No. 5521, 5522)

* Thu Mar 25 2004 Akinobu Mita <mita@miraclelinux.com> 58ml
- add megaide driver (No. 5595)

* Wed Mar 24 2004 Akinobu Mita <mita@miraclelinux.com> 57ml
- update e1000 to v5.2.50.1 (No.5591)

* Sun Mar 21 2004 Yasuma Takeda <yasuma@miraclelinux.com> 56ml
- Fix FDD locking patch(No.4140)

* Mon Mar  8 2004 Akinobu Mita <mita@miraclelinux.com> 55ml
- make proc_info_read() return -EFAULT when copy_to_user() fails.
  (No.4150)

* Mon Mar  1 2004 Yasuma Takeda <yasuma@miraclelinux.com> 54ml
- Fix FDD locking(No.4140)

* Thu Feb 19 2004 Yasuma Takeda <yasuma@miraclelinux.com> 52ml
- Fix following vulnerabilities (No.10286)
    check return value of the do_unmap() (CAN-2004-0077)
    ncfps driver                         (CAN-2004-0010)
    r128 DRI driver                      (CAN-2004-0003)
    C-Media PCI sound driver             (CAN-2004-0700)
    IJX Telephony Card driver            (CAN-2002-1574)
- No.999 patch is included in No.10286
    bound check inside the do_mremap() (CAN-2003-0985)

* Tue Jan 6 2004 Akinobu Mita <mita@miraclelinux.com> 50ml
- Fix bound check inside the do_mremap() (No.999)

* Thu Dec 25 2003 Akinobu Mita <mita@miraclelinux.com> 49ml
- Fix tty oops (No.4130)

* Mon Dec 15 2003 Akinobu Mita <mita@miraclelinux.com> 48ml
- Update bcm5700 (v7.1.9)  (No.5531)

* Tue Dec 9 2003 Akinobu Mita <mita@miraclelinux.com> 47ml
- fix an Oops in the locking code by Trond Myklebust (No.10280)

* Tue Dec 2 2003 Akinobu Mita <mita@miraclelinux.com> 46ml
- check do_brk range (No.2770)

* Fri Nov 21 2003 Akinobu Mita <mita@miraclelinux.com> 44ml
- update aacraid driver to v1.1.4 (No.5504)

* Fri Nov 14 2003 Akinobu Mita <mita@miraclelinux.com> 43ml
- fix oops on CONFIG_DEBUG_HIGHMEM <y> (No.5606)
- enable crash dump via NMI button (No.5607)
- add SysRq entry to generate a NMI (No.5608)
- disable icmp echo reply while crash dumping for LifeKeeper (No.5609)
- to avoid data crash when the disk is very busy by HITACHI, Inc.(No.4120)
- add the mechanism of the installation of the proprietary drivers
  at post/preun scripts (SourceNo.90,91)

* Thu Oct 23 2003 Akinobu Mita <mita@miraclelinux.com> 42ml
- Export gendisk_head for SANARENA (No.8030)

* Fri Oct 10 2003 Akinobu Mita <mita@miraclelinux.com> 41ml
- Update e1000 to v5.2.16(No.5590)

* Thu Oct 02 2003 Tatsuo Ito <tito@miraclelinux.com> 40ml
- revive depmod at post section

* Sun Sep 28 2003 Tatsuo Ito <tito@miraclelinux.com> 38ml
- fix the lkcd on es7000 (No.5624)
- fix the problem of IDE CD interrupt on ES7000/520 (No.5625)
- modify BOOT config (CONFIG_ES7000=y) to install in megaraid 
  disk on ES7000/520 (No.5626)

* Thu Aug 28 2003 Yasuma Takeda <yasuma@miraclelinux.com> 36ml
- fix nbd for LifeKeeper (No.4100)
- support HA-NFS for LifeKeeper (No.4110)
- CONFIG_NFSD_FHALIAS -> y (except BOOT kernel)

* Tue Aug 19 2003 Yasuma Takeda <yasuma@miraclelinux.com> 34ml
- Add QikData driver(V1.1.D585) (No.5580,5581)
- CONFIG_BLK_DEV_QIKDATA -> m

* Fri Aug  8 2003 Yasuma Takeda <yasuma@miraclelinux.com> 32ml
- CONFIG_BLK_DEV_LVM -> m
- fix lvm to build (No.5562)

* Fri Aug  1 2003 Yasuma Takeda <yasuma@miraclelinux.com> 30ml
- make qla2x00.o from qla2100.o for compatibility
- update qla2200_531RH1 (v5.31.RH1S) (No.5543)

* Thu Jul 31 2003 Yasuma Takeda <yasuma@miraclelinux.com> 28ml
- change default tulip driver(No.5560)

* Thu Jul 31 2003 Yasuma Takeda <yasuma@miraclelinux.com> 27ml
- update LVM (v1.0.7) (No.5560,5561)

* Wed Jul 30 2003 Tatsuo Ito <tito@miraclelinux.com> 25ml
- make kernel symbol number same value as RH (No.5622, 8021)
- modify IPI process for lkcd synchronous (No.5623)

* Tue Jul 29 2003 Yasuma Takeda <yasuma@miraclelinux.com> 23ml
- change default megaraid driver (v2.00.2) (No.5520)

* Wed Jul 16 2003 Tatsuo Ito <tito@miraclelinux.com> 21ml
- add emulex driver v1.21g (No.5550, 5551, 5552)
- modify kernel configuration for BOOT kernel to boot ES7000
- fix lkcd bug for smp wait

* Fri Jul 11 2003 Tatsuo Ito <tito@miraclelinux.com> 19ml
- modify Unisys ES7000 compile error for BOOT and up kernel
 (No.5621)

* Fri Jul 11 2003 Tatsuo Ito <tito@miraclelinux.com> 17ml
- add Unisys ES7000 patch (No.5620)

* Thu Jul 10 2003 Tatsuo Ito <tito@miraclelinux.com> 15ml
- modify lkst patch to remove extra rej file (No.5610)

* Wed Jul 09 2003 Tatsuo Ito <tito@miraclelinux.com> 13ml
- update qlogic driver v6.04.02 (No.5540, 5541, 5542)

* Mon Jul 07 2003 Tatsuo Ito <tito@miraclelinux.com> 11ml
- add netdevice patch for kernel symbol magic number
  to be same value as RH (No.8020) 

* Tue Jun 24 2003 Yasuma Takeda <yasuma@miraclelinux.com>
- removed megaraid patch(No.5520)
- changed LKCD patch(removed No.5605,5606)

* Mon Jun 23 2003 Yasuma Takeda <yasuma@miraclelinux.com>
- Add LKST 1.3 support(No.5610,5611,5612,5613,5614)

* Mon Jun 23 2003 Yasuma Takeda <yasuma@miraclelinux.com>
- Update bcm5700 (v6.2.11)  (No.5530)
- Turn on VARYIO aic7xxx,aic79xx,cciss (No.5590)

* Sat Jun 21 2003 Yasuma Takeda <yasuma@miraclelinux.com>
- Update aic7xxx
  aic79xx-linux-2.4-20030502: aic7xxx=6.2.33, aic79xx=1.3.8
  (No.5500,5501,5502)
- Not use aic7xxx_mod.o
- change tagged queue depth from 253 to 32 on aic7xxx and aic79xx driver
  - CONFIG_AIC7XXX_CMDS_PER_DEVICE=32
  - CONFIG_AIC79XX_CMDS_PER_DEVICE=32
- update e100 v2.3.13(No.5510)
- update megaraid v1.18d(No.5520)

* Fri Jun 20 2003 Yasuma Takeda <yasuma@miraclelinux.com>
- Update pci.ids from http://pciids.sourceforge.net (No.8010)
- Remove netdump module(Add define of netdump to spec)
- Add LKCD 4.1 support
   - LKCD 4.1-1(No.5600)
   - don't dump in die() (No.5601)
   - fix double free in zlib (No.5602)
   - modify make clean to remove Kerntypes (No.5603)
   - modify lkcd in order to reboot after dumping memory core (No.5604)
   - fix stall in dump progress (No.5605)
   - don't duplicate DUMP_VECTOR (No.5606)
   - CONFIG_DUMP -> y
   - CONFIG_DUMP_COMPRESS_RLE  -> y
   - CONFIG_DUMP_COMPRESS_GZIP -> y
   - install Kerntypes

* Fri Jun 20 2003 Yasuma Takeda <yasuma@miraclelinux.com>  
- cleanup config files
- CONFIG_SCSI_MULTI_LUN -> y (up,smp,enterprise,BOOT)
- Fix /proc/version LANG (No.8000)
- Add NMI hook patch for ESMPRO(No.4000)
- Fix io request queue length for I/O response (No.4010)
- Fix ICH2 interrupt trouble
     - add to noskip-apic patch (No.4020)
     - Change CONFIG_X86_UP_APIC -> y in up config
     - Change CONFIG_X86_UP_IOAPIC -> y in up config
- Set 0 to support_dma for ide_cdrom_driver (No.4030)
- Add p4apic patch for detect_init_APIC() to succeed on P4 UP machine(No.4040)
- Fix the problem of dd on raw disk (No.4050)
- Fix a100u2w driver for large disk(No.4060)
- fixed a bug for over 2.0GB size file creation on reiserfs(No.4070)
- Fix the problem that auto ide dma setting ide does not work
  for intel ich4 (No.4080)
- expand INR_OPEN:1024->10240 (No.4090)

* Fri Jun 20 2003 Yasuma Takeda <yasuma@miraclelinux.com>  
- Change spec for MIRACLE LINUX
  - Change BuildRequires:gcc >= 2.95.3 
  - Change BOOT kernel to i686, %files source
  - Remove RedHat GPG key from kernel package
  - Change description
  - Change installed config files only i686
  - Change UP kernel from i386 to i686
  - Link /usr/include/asm on i686 
    "cp -a $RPM_BUILD_ROOT/usr/src/linux/include/asm/* $RPM_BUILD_ROOT/usr/..."
  - Improve source package install/uninstall process
  - Change mkinitrd process for all kernel packages
  - Remove summit config
- Add i686-BOOT.config(Source No.49)
- Add linux-SetupKernelSource.sh(Source No.10), %install, %files
- Fix bcm5820 to build by gcc 2.95.3(No. 5094)

* Fri Jun 6 2003 Jason Baron <jbaron@redhat.com>
-qlogic double-deallocate oops

* Wed May 21 2003 Jason Baron <jbaron@redhat.com>
-fix ext3 races (Stephen Tweedie)
-upstream ext3 updates (Stephen Tweedie)
-upstream end_that_request_last fix (Stephen Tweedie)

* Wed May 21 2003 Jason Baron <jbaron@redhat.com>
- fix cpqarray request completion    

* Fri May 16 2003 Jason Baron <jbaron@redhat.com>
- limit cciss to 32-bit addresses

* Fri May 2 2003 Jason Baron <jbaron@redhat.com>
- aplly summit patches just for summit build

* Wed Apr 9 2003 Tom Coughlan <coughlan@redhat.com>
- Add platypus to scsi whitelist.

* Mon Mar 31 2003 Tom Coughlan <coughlan@redhat.com>
- Turn on varyio for qla2xxx, cciss, aic7xxx, aic79xx, 
mptfusion, aacraid.

* Mon Mar 31 2003 Tom Coughlan <coughlan@redhat.com>
- Rename old ips driver from ips to ips_48026
- Rename new ips driver from ips_60026 to ips.

* Mon Mar 31 2003 Tom Coughlan <coughlan@redhat.com>
- Update cciss to 2.4.45. 
- Update cpqarray to 2.4.26.
- Preserve old cciss and cpqarray drivers, as alternatives.

* Fri Mar 28 2003 Ernie Petrides <petrides@redhat.com>
- Add upstream support for /proc/sysrq-trigger feature.

* Wed Mar 26 2003 Pete Zaitcev <zaitcev@redhat.com>
- Fix usb-storage problem popped on IBM Bladecenter (bz#85211).

* Wed Mar 26 2003 Tom Coughlan <coughlan@redhat.com>
- update mpt fusion from 2.02.01 to 2.05.00

* Wed Mar 26 2003 Jason Baron <jbaron@redhat.com>
- fix msg queue race condition

* Wed Mar 26 2003 Larry Woodman <lwoodman@redhat.com>
- Bug 86531, export symbol brw_kvec_async.

* Wed Mar 26 2003 Tom Coughlan <coughlan@redhat.com>
- update cpqfc from 2.1.1 to 2.1.2
- update alternate ServRAID ips driver from v5.10.21 to v6.00.26

* Wed Mar 26 2003 Tom Coughlan <coughlan@redhat.com>
- update qlogic FC v6.04.00 to v6.04.01
- update the scsi whitelist for HP 

* Tue Mar 25 2003 Doug Ledford <dledford@redhat.com>
- update the aic7xxx driver to version 6.2.30
- update aic79xx driver to version 1.3.4

* Mon Mar 24 2003 Doug Ledford <dledford@redhat.com>
- integrate update summit support patches
- apply summit patches to base kernel source, but only enable
  in summit kernel package

* Mon Mar 24 2003 Jason Baron <jbaron@redhat.com>
- reduce stack usage for random.c

* Mon Mar 24 2003 Tom Coughlan <coughlan@redhat.com>
- No longer build qla2x00 (version 4.31.7b)
- Remove qla2300_new, qla2200_new (version 5.31.RH3)
- Rename qla2200, qla2300 (version 5.31.RH1) to qla2200_531RH1,
  qla2300_531RH1.  Keeping as a backup.
- Remove qla2300_60300, qla2200_60300 qla2100_60300
- Add qla2100, qla2200, qla2300 (version 6.04.00).  This driver 
  will become the default. 

* Wed Mar 19 2003 Tom Coughlan <coughlan@redhat.com>
- Update aacraid driver from 0.9.9ac2.1 to 0.9.9ac6-TEST.
  Also turn on can_dma_32 (and single_sg_ok, as a prerequsite)
- Add a BUG to scsi midlayer, if a driver sets can_dma_32
  without setting single_sg_ok. 

* Mon Feb 17 2003 Larry Woodman <lwoodman@redhat.com>
- Fix sleeping forever in wakeup_kswapd.
- Fix inode cache pruning when there is lowmem shortage but
  no highmem shortage
- Fix aio corruption of inode semaphore.

* Mon Feb 17 2003 Larry Woodman <lwoodman@redhat.com>
- Fix VM_SHOULD_SLEEP macro.

* Thu Feb 13 2003 Pete Zaitcev <zaitcev@redhat.com>
- Fix it#8857 Token Ring lockups on SMP and multiply boards.

* Fri Feb 7 2003  Dave Anderson <anderson@redhat.com>
- Fix to prevent deadlock with Alt-Sysrq-M when pagemap_lru_lock
- is held.  Added to linux-2.4.9-showmem.patch. 

* Thu Feb 6 2003  Larry Woodman <lwoodman@redhat.com>
- Fix blocknumber calculation in varyio patch.

* Wed Feb 5 2003 Doug Ledford <dledford@redhat.com>
- Update the pci quirks patch to include a hardware workaround

* Wed Feb 5 2003  Larry Woodman <lwoodman@redhat.com>
- fix aio.
- fix summit uninstall typo, bug 83568.

* Tue Feb 4 2003 Tom Coughlan <coughlan@redhat.com>
- Update from megaraid v2.00.1 to v2.00.2.  This fixes possible 
system hang when driver configures older megaraid hardware.

* Mon Feb  3 2003 Dave Anderson <anderson@redhat.com>
- Make varyio patch ABI-compliant (linux-2.4.9-varyio-abi.patch).

* Thu Jan 30 2003 Jason Baron <jbaron@redhat.com>
- tcp stall fix (DaveM)

* Wed Jan 29 2003 Larry Woodman <lwoodman@redhat.com>
- Fix inverted logic in refill_inactive_backgroundscan().

* Thu Jan 23 2003 Larry Woodman <lwoodman@redhat.com>
- Back out the 3 NFS patches that havent been properly tested.
- Fix __alloc_pages to limit retries of large order allocations.
- Add patch to remove duplicate readpage() on an aio read.

* Tue Jan 21 2003 Steve Dickson <SteveD@RedHat.com>
- Added NFS fattrs patch
- Added NFS reading passed EOF patch
- Added NFS over tcp patches

* Mon Jan 20 2003 Larry Woodman <lwoodman@redhat.com>
- Fix typo in zone_free_shortage_type.
- Take in o(1) scheduler patch.

* Thu Jan 16 2003 Larry Woodman <lwoodman@redhat.com>
- Backout the elevator patches from vmfixes9 to restore ABI compatibility.

* Thu Jan 16 2003 Tom Coughlan <coughlan@redhat.com>
- Update module_license.patch.

* Thu Jan 16 2003 Doug Ledford <dledford@redhat.com>
- Add support for the upcoming x445 machine from IBM to the summit kernel
- Make the notsc boot option disable kernel tsc use only, not user space
  tsc use.  This is because the i686 glibc will segfault on boot if it
  can't access the tsc registers.

* Thu Jan 16 2003 Larry Woodman <lwoodman@redhat.com>
- Fix boot-time bigpages ccounting and account for all 
  reserved pages in inactive_target and swapout_priority.

* Thu Jan 16 2003 Stephen C. Tweedie <sct@redhat.com>
- More superbh fixes --- restore ABI compatibility and fix bounce buffering

* Thu Jan 16 2003 Larry Woodman <lwoodman@redhat.com>
- Change page_lauder to call page_launder_zone for
  the highmem zone when there is lowmem exhaustion
  do to excessive slab pages.  page_launder_zone
  will call try_to_free_buffers to free up lowmem
  without freeing the highmem pages from the pagecache.

* Mon Jan 13 2003 Larry Woodman <lwoodman@redhat.com>
- Dont apply the swap_map indexing patch in the specfile.
- Clean up the free_swap_and_cache deadlock by changing
  find_trylock_page to spin_trylock the PAGECACHE_LOCK.
- Fix refill_inactive_scan so that it resolves the
  inactive_shortage in the global balancing loop instead
  of the local balancing loop.
- Fix Shared mmap()s to work with bigpages, (bcrl).

* Thu Jan 09 2003 Larry Woodman <lwoodman@redhat.com>
- Make sure refill_inactive_scan does call refill_inactive_zone
  when there is an inactive_shortage or system will hang.
- Disable the swap_map indexing, looks like it causes corruption.

* Fri Jan 03 2003 Larry Woodman <lwoodman@redhat.com>
- Change "Alt-Sysrq m" to print out entire zone stats.

* Tue Dec 24 2002 Larry Woodman <lwoodman@redhat.com>
- Take boot-time bigpages into account for kswapd
  calculations.

* Wed Dec 18 2002 Stephen C. Tweedie <sct@redhat.com>
- Add superbh support for contiguous raw IO requests

* Wed Dec 18 2002 Dave Anderson <anderson@redhat.com>
- Add netdump support for tg3.c and tg3_e121.c drivers
- in linux-2.4.9-netdump-fixes.patch

* Tue Dec 17 2002 Jason Baron <jbaron@redhat.com>
- do not clear bh flags for off disk access (Stephen C. Tweedie)

* Tue Dec 17 2002 Tom Coughlan <coughlan@redhat.com>
- qla2100 not working with qla2xx_60300.  Fix by initializing 
  iocb_hiwat correctly for qla2100.
- Update sis900_new from 1.08.01 to 1.08.06

* Tue Dec 17 2002 Jason Baron <jbaron@redhat.com>
- remove double show_stack call for sysrq-t

* Mon Dec 16 2002 Jason Baron <jbaron@redhat.com>
- move megaraid2 to megaraid_2001

* Mon Dec 16 2002 Larry Woodman <lwoodman@redhat.com>
- Add kswapd performance patches.
- Allow the krefilld and swapout performance improvements
  to be disabled via the "novmfixes" boot command-line
  option.

* Mon Dec 16 2002 Jason Baron <jbaron@redhat.com>
- add tg3 alternate as addon/tg3_e121
- export GPL unmap_kvec(), free_kvec(), map_user_kvec()

* Mon Dec 16 2002 Tom Coughlan <coughlan@redhat.com>
- Fix mistake in qla2xx_60300 Makefile. 

* Fri Dec 13 2002 Tom Coughlan <coughlan@redhat.com>
- Update the mpt fusion driver
- Add more pci ids to aacraid driver

* Fri Dec 13 2002 Jason Baron <jbaron@redhat.com>
- move e100 2.1.24-k2, e1000 4.4.12-k1 to addon
- move megaraid2 to addon

* Fri Dec 13 2002 Tom Coughlan <coughlan@redhat.com>
- Update qlogic v6 from 6.03.00b7 to v6.03.00.
- Add config param for alternate pcnet32 driver

* Fri Dec 13 2002 Jason Baron <jbaron@redhat.com>
- Add support for AMD 762 chipset
- Add pcnet32 1.27b alternate driver

* Thu Dec 12 2002 Jason Baron <jbaron@redhat.com>
- turn on high pte for summit kernel

* Thu Dec 12 2002 Jason Baron <jbaron@redhat.com>
- add hangcheck

* Thu Dec 12 2002 Tom Coughlan <coughlan@redhat.com>
- Update i810_audio and ac97_codec

* Thu Dec 12 2002 Jason Baron <jbaron@redhat.com>
- add ext2 htree compatibility patch

* Wed Dec 11 2002 Jason Baron <jbaron@redhat.com>
- add lsb compliance (Julie DeWandel)
- add cmd line disable hyper threading (Jim Paradis) 
- add nfs timeout fixes (Steve Dickson)

* Wed Dec 11 2002 Tom Coughlan <coughlan@redhat.com>
- Add ServRAID ips v5.10.21 as an alternate driver.
- Add parameters to config-generic for alternate ips, 
e100, and e1000.
- Comment out linux-2.4.20-e100e1000.patch temporarily.

* Tue Dec 10 2002 Jason Baron <jbaron@redhat.com>
- add e100 2.1.24-k2 as alternate driver (Jeff Garzik)
- add e1000 4.4.12-k1 as alternate driver (Jeff Garzik)

* Fri Dec 6 2002 Tom Coughlan <coughlan@redhat.com>
- 3ware update from 1.02.00.008 to 1.02.00.027
- update to whitelist (Oracle's request)

* Thu Dec 5 2002 Tom Coughlan <coughlan@redhat.com>
- megaraid v1.18: add LSI Logic vendor ID, and check return 
  from copy_to_user.
- megaraid2: update from v2.00rc5 to v2.00.1 

* Wed Dec 4 2002 Jason Baron <jbaron@redhat.com>
- enable prune_icache

* Tue Dec 3 2002 Jason Baron <jbaron@redhat.com>
- turn off prune_icache
- add proc mem leak fix, #77333, patch by Steve Dickson

* Tue Dec 3 2002 Doug Ledford <dledford@redhat.com>
- add notsc patch to summit kernel
- add cyclone patch to summit kernel

* Fri Nov 1 2002 Jason Baron <jbaron@redhat.com>
- add vmfixes and prune_icache 

* Fri Nov 1 2002 Tom Coughlan <coughlan@redhat.com>
- Add megaraid v2.00 driver. (Old driver is still default.)

* Fri Oct 25 2002 Tom Coughlan <coughlan@redhat.com>
- Fix scsi.c to solve gdth oops (from dledford).

* Fri Oct 25 2002 Tom Coughlan <coughlan@redhat.com>
- Update qla2xxx v6 driver, and move it from scsi to addon.

* Wed Oct 23 2002 Tom Coughlan <coughlan@redhat.com>
- Add HITACHI "OPEN-" SPARSELUN to the whitelist (for BofA).

* Tue Oct 22 2002 Tom Coughlan <coughlan@redhat.com>
- qla2xxx v6 driver

* Wed Oct 2 2002 Jason Baron <jbaron@redhat.com> 2.4.9-e.9
- add pge and quicklist patches

* Mon Sep 23 2002 Jason Baron <jbaron@redhat.com>
- add Pete Zaitev's updates to tg3 

* Tue Sep 17 2002 Tom Coughlan <coughlan@redhat.com>
- Fix sd so it can handle up to 128 devices (bug 58442).
- Increase SD_EXTRA_DEVS from 40 to 128.
- Don't start logical units that require manual intervention 
(bug 68883).
- Fix scsi_merge.c case where request consists of a single 
segment but multiple buffer headers (bug 64149). Change is in 
linux-2.4.9-blockhighmem.patch.

* Wed Sep 05 2002 Pete Zaitcev <zaitcev@redhat.com>
- Fix for weird iostat vaules (bug 67555). Actual fix by Stephen Tweedle.

* Wed Jul 31 2002 Tom Coughlan  <coughlan@redhat.com> 
- Fix addon/qla2200 so that it configures sparse LUNs (bug 64067). 

* Mon Jul 29 2002 Tom Coughlan  <coughlan@redhat.com> 
- Add systcl to set core file name (for MSDW). 

* Fri Jul 19 2002 Michael K. Johnson <johnsonm@redhat.com> 2.4.9-e.8
- linux-2.4.9-veritasexports.patch re-added to re-add the now-upstream
  __find_get_page export, separated from the close-unmount patch

* Wed Jun 26 2002 Tom Coughlan <coughlan@redhat.com> 
- Remove "mv scsi/aic7xxx/aic7xxx.o scsi/aic7xxx_mod.o" from this file. 
  No longer needed with change to aic7xxx/Makefile.

* Tue Jun 25 2002 Jason Baron <jbaron@redhat.com> 
- Benjamin LaHaise's fix for aio write deadlocks 

* Tue Jun 25 2002 Tom Coughlan <coughlan@redhat.com> 
- Add the new aic79xx driver, and update the aic7xxx from
  6.2.1 to 6.2.8 (bug 60944). 

* Tue Jun 25 2002 Tom Coughlan <coughlan@redhat.com> 
- fix bug 66685, add entries to the list of SCSI devices 
  that get special treatment (scsi_scan.c whitelist). 

* Tue Jun 25 2002 Michael K. Johnson <johnsonm@redhat.com>
- linux-2.4.9-veritasexports.patch removed, replaced with patch
  linux-2.4.9-close-unmount.patch containing only the (pre-existing,
  no new bugzilla number) bugfix for "close while unmounting".

* Tue Jun 25 2002 Larry Woodman <lwoodman@redhat.com> 
- fix bug 67080, remove the exported symbols from
  linux-2.4.9-veritasexports.patch.

* Mon Jun 24 2002 Larry Woodman <lwoodman@redhat.com>
- merge the tg3 driver fixes from 2.4.18 back into 2.4.9.

* Mon Jun 24 2002 Larry Woodman <lwoodman@redhat.com>
- fix bug 66535, leaking XMM registers between processes.

* Mon Jun 24 2002 Larry Woodman <lwoodman@redhat.com>
- fix bug 67167, potential RAID5 data corruption.

* Mon Jun 24 2002 Larry Woodman <lwoodman@redhat.com>
- fix bug 67080, unreliable reboots with "reboot=bios" option.

* Fri Jun 21 2002 Larry Woodman <lwoodman@redhat.com>
- fix bug #66527 and #66966, DMA address truncation over 4GB.

* Fri Jun 21 2002 Larry Woodman <lwoodman@redhat.com>
- Fix bug #60903, remove IOAPIC warning on discovery.

* Fri Jun 21 2002 Jason Baron <jbaron@redhat.com>
- fix for bug #63879, need to update to the 
  "correct" fix when it becomes available upstream

* Fri Jun 21 2002 Tom Coughlan <coughlan@redhat.com>
- Fix bug #59894, qlogic driver not seeing all luns.

* Fri Jun 14 2002 Larry Woodman <lwoodman@redhat.com>
- Ingo's fix for bug #63209, can't create SGA > 8GB on 16GB machine
  using bigpages and shmfs.

* Thu May  2 2002 Benjamin LaHaise <bcrl@redhat.com>
- fix bug #64233 with updated fs/locks.c from later 2.4 by 
  adding linux-2.4.9-fs-locks-update.patch

* Tue Apr 30 2002 Doug Ledford <dledford@redhat.com>
- add Matthew Jacob's feral qlogic driver to replace the qlogicisp driver

* Fri Apr 26 2002 Benjamin LaHaise <bcrl@redhat.com>
- add linux-2.4.9-proc-vmalloc.patch
- add linux-2.4.9-vsnprintf-fix.patch
- add linux-2.4.9-proc-stat-fix.patch

* Thu Apr 25 2002 Benjamin LaHaise <bcrl@redhat.com>
- aio request chunking

* Tue Apr 23 2002 Benjamin LaHaise <bcrl@redhat.com>
- further aio fixes

* Tue Apr 16 2002 Benjamin LaHaise <bcrl@redhat.com>
- add linux-2.4.9-slabinfo.patch
- add LGPL headers to libredhat-kernel.so

* Fri Apr 12 2002 Benjamin LaHaise <bcrl@redhat.com>
- remove linux-2.4.3-rawio.patch: unlock_buffer requires a reference 
  to the buffer head, or else the wake_up can race with buffer freeing 
  as it is after the actual unlock bitop.
- add linux-2.4.9-highmem_bounce_debug.patch

* Tue Mar 26 2002 Arjan van de Ven <arjanv@redhat.com>
- add patch required by Veritas VxVM

* Thu Mar 21 2002 Doug Ledford <dledford@redhat.com>
- EMC confirmed that the lun0 scanning patch I made solves their problem, so
  I added it.  It's off by default and only on when enabled by passing
  a module option to the scsi_mod.o module.

* Wed Mar 20 2002 Benjamin LaHaise <bcrl@redhat.com>
- greedy swap reclaim

* Thu Mar 14 2002 Michael K. Johnson <johnsonm@redhat.com>
- improved netconsole 

* Thu Mar 7 2002 Doug Ledford <dledford@redhat.com>
- update ikd patch to current kernel

* Wed Mar 6 2002 Benjamin LaHaise <bcrl@redhat.com>
- merge vma patch from davem
- statm fixups

* Tue Mar 5 2002 Benjamin LaHaise <bcrl@redhat.com>
- add statm patch to speed up top

* Fri Mar 1 2002 Benjamin LaHaise <bcrl@redhat.com>
- add stackcheck patch

* Tue Feb 26 2002 Benjamin LaHaise <bcrl@redhat.com>
- fix aio readevents bug, improve fastpath of same

* Thu Feb 21 2002 Arjan van de Ven <arjanv@redhat.com>
- improved shmfs to be less braindead involving swapping

* Tue Feb 19 2002 Ingo Molnar <mingo@redhat.com>
- added vma merging for mmaped, file backed areas

* Thu Feb 14 2002 Arjan van de Ven <arjanv@redhat.com>
- add Andrea's pagetable in highmem patch; rewritten

* Sat Feb 09 2002 Arjan van de Ven <arjanv@redhat.com>
- improve aio locking

* Fri Feb  8 2002 Stephen C. Tweedie <sct@redhat.com>
- Add fix for end_buffer_io_async on md devices

* Fri Feb 08 2002 Arjan van de Ven <arjanv@redhat.com>
- make fstat() do i_size on pipes again (still undefined behavior!)

* Thu Feb 07 2002 Arjan van de Ven <arjanv@redhat.com>
- updated O(1) patch
- improved megaraid driver

* Wed Jan 30 2002 Arjan van de Ven <arjanv@redhat.com>
- per cpu keventd

* Tue Jan 29 2002 Benjamin LaHaise <bcrl@redhat.com>
- aio update:
	- properly destroy io context when io_setup -EFAULTs
	- fixed bug in generic page cache aio read that resulted in
	  potentially corrupt state
	- poison aio contexts on completion
	- workaround potential request starvation
	- BUG() on negative ioctx usage counts
	- clear ioctx_list on exec
	- check for cancel != NULL
	- enable debugging printk for raw io
	- return 0 past eof on files instead of EINVAL

* Tue Jan 29 2002 Arjan van de Ven <arjanv@redhat.com>
- prepare for summit package

* Mon Jan 28 2002 Doug Ledford <dledford@redhat.com>
- Final minor touchups to the i810 sound driver.

* Mon Jan 28 2002 Arjan van de Ven <arjanv@redhat.com>
- use the nmi timer for profiling now

* Fri Jan 25 2002 Benjamin LaHaise <bcrl@redhat.com>
- performance tweak in brw_kiovec_async
- really fix aio fput
- fix stack overflow on large cached writes

* Thu Jan 24 2002 Benjamin LaHaise <bcrl@redhat.com>
- fix aio fput bug
- make io_submit return -EINVAL instead of sending completion 
  events on file descriptors that don't support aio

* Mon Jan 21 2002 Benjamin LaHaise <bcrl@redhat.com>
- disable unofficial aio syscall numbers, rely on syscall by name 
- conflict with dev < 3.2-9 to pull in /dev/vsys
- really fix hexdump resulting in an occasional compile error
- add io_cancel core work + cleanup core to use generic lists
- faster aio poll code

* Fri Jan 18 2002 Benjamin LaHaise <bcrl@redhat.com>
- remove a few chunks from syscall-by-name (update to -A5)
- fix makefile to prevent garbage LINUX_UNIQUE_BYTES from being generated
- make libredhat-kernel.so use symbol versions: REDHAT_0.90
- fix NULL timeout in io_getevents
- support larger aio rings via vmalloc

* Fri Jan 18 2002 Arjan van de Ven <arjanv@redhat.com>
- make si_swapinfo() cache it's results for a second
- make megaraid driver use the new style locking
- allow prefetch() to be used in generic i686 kernels

* Thu Jan 17 2002 Benjamin LaHaise <bcrl@redhat.com>
- add syscall-by-name patch: rev A4

* Thu Jan 17 2002 Arjan van de Ven <arjanv@redhat.com>
- Pete's NFS failover port (originally by Tim Burke)
- tcp/ip fixes from DaveM
- rhconfig fixes for debug kernel
- hyperthreading fix from IBM (in linux-2.4.9-acpi.patch)
- minor vm tweaks (in linux-2.4.9-aging.patch, rm linux-2.4.9-page_dirty.patch)

* Tue Jan 15 2002 Benjamin LaHaise <bcrl@redhat.com>
- aio update: fix memory leak, allow more requests

* Tue Jan 15 2002 Arjan van de Ven <arjanv@redhat.com>
- add MPS 1.4 fix for io apics
- add the safe part of the lowlatency patch

* Mon Jan 14 2002 Benjamin LaHaise <bcrl@redhat.com>
- split aio up, update further

* Mon Jan 14 2002 Michael K. Johnson <johnsonm@redhat.com>
- netconsole/netdump
- iorl draft 2
- aio

* Mon Jan 14 2002 Arjan van de Ven <arjanv@redhat.com>
- improve rawio performance by lazy filling in the kiovec

* Thu Jan 10 2002 Doug Ledford <dledford@redhat.com>
- Update i810 sound driver to fix hang on close bug
- iorl-2.4.9.patch

* Thu Jan 10 2002 Michael K. Johnson <johnsonm@redhat.com>
- Allow iptables NAT/MASQ over CIPE

* Tue Jan 8 2002 Arjan van de Ven <arjanv@redhat.com>
- added experimental emu10k driver 

* Fri Jan 4 2002 Benjamin LaHaise <bcrl@redhat.com>
- fix bug in page_launder

* Thu Dec 20 2001 Michael K. Johnson <johnsonm@redhat.com>
- Fix static build of DAC960 (even though we don't build it static...)

* Tue Dec 18 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added watchdog patch
- Fixed dma mask signedness problem

* Mon Dec 17 2001 Harald Hoyer <harald@redhat.de> 2.4.9-17.3-s390
- IBM patchset no. 4 added
- procfs patch
- linux kernel crash dump support
- /boot/Kerntypes-${version} with -gstabs
- mathemu patch
- IPV6 enabled
- second ramdisk

* Sat Dec 15 2001 Pete Zaitcev <zaitcev@redhat.com>
- update usb/pegasus, #57531 - downport from 2.4.16

* Wed Dec 13 2001 Benjamin LaHaise <bcrl@redhat.com>
- update ns83820.c to 0.15

* Thu Dec 13 2001 Arjan van de Ven <arjanv@redhat.com>
- added Doug's patch for i810

* Wed Dec 12 2001 Arjan van de Ven <arjanv@redhat.com>
- updated qla2200/2300 driver

* Tue Dec 11 2001 Benjamin LaHaise <bcrl@redhat.com>
- add linux-2.4.9-nfs_svc_quiet.patch to silence logging of nfs pings

* Mon Dec 10 2001 Stephen C. Tweedie <sct@redhat.com>
- Merge in important ext3 fixes between ext3-0.9.11 and 0.9.16:
 * Remove redundant MODULE_LICENSE()
 * Don't do show_stack() on archs which don't have it
 * Fix a rare EFAULT himem handling case
 * Fix a rare race between truncate and write
 * Don't use atomic bitops on int values (can break on 64-bit)

- Also move the dir readahead fix into the general ext3-updates patch.

* Thu Dec 06 2001 Pete Zaitcev <zaitcev@redhat.com>
- Fix for #55420 (scsi oopses)

* Thu Dec 06 2001 Arjan van de Ven <arjanv@redhat.com>
- enable highmem for megaraid
- fix cramfs SMP issues

* Tue Dec 04 2001 Michael K. Johnson <johnsonm@redhat.com>
- update to udf 0.9.5 for testing
- update to DAC960 2.4.11

* Tue Dec 04 2001 Arjan van de Ven <arjanv@redhat.com>
- updated qlogic driver
- updated hotplug pci

* Mon Dec 03 2001 Pete Zaitcev <zaitcev@redhat.com>
- made linux-2.4.9-s390-realrootdev.patch architecture neutral.

* Tue Nov 27 2001 Arjan van de Ven <arjanv@redhat.com>
- updated qlogic driver

* Mon Nov 26 2001 Arjan van de Ven <arjanv@redhat.com>
- fix hang with idefloppy on via (#56613)

* Fri Nov 09 2001 Arjan van de Ven <arjanv@redhat.com>
- added official VIA fix for the athlon crash bug

* Thu Nov 08 2001 Arjan van de Ven <arjanv@redhat.com>
- added Ingo's smp scheduler improvement
- added cpu_relax() patch

* Tue Nov 06 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed another s/ULONG/unsigned long/ to u32 bug in e1000 
- added Al Viro's /proc/mounts overflow fix
- add fancy sw io mmu speed workaround

* Mon Nov 05 2001 Harald Hoyer <harald@redhat.de> 2.4.9-13-s390
- specfile fixes for tape kernel

* Wed Oct 31 2001 Harald Hoyer <harald@redhat.de> 2.4.9-9.1-s390
- compiled in ext3 and dasd in normal kernel

* Tue Oct 30 2001 Harald Hoyer <harald@redhat.de> 2.4.9-9.1-s390
- s390 version
- ported IBM 2.4.7 patch 2
- integrated DASD patch from zaitcev@redhat.com

* Mon Oct 29 2001 Arjan van de Ven <arjanv@redhat.com>
- add fix for race in tty switching code

* Wed Oct 24 2001 Stephen C. Tweedie <sct@redhat.com>
- Get page mappings right after EFAULT on highmem page cache writes

* Tue Oct 23 2001 Bill Nottingham <notting@redhat.com>
- fix short read() in GPT code

* Tue Oct 16 2001 Pete Zaitcev <zaitcev@redhat.com>
- Killed port-specific __cpu_raise_softirq on s390 and s390x (warning flood)
- Removed loopfix part from linux-2.4.9-s390-ac11.patch, now generic.

* Sat Oct 13 2001 Pete Zaitcev <zaitcev@redhat.com>
- usb-uhci bugfix from mainstream, until it reaches us down the line

* Wed Oct 10 2001 Pete Zaitcev <zaitcev@redhat.com>
- ide-tape fix for HP Colorado, #36628

* Mon Oct 8 2001 Arjan van de Ven <arjanv@redhat.com>
- New Broadcom 5700/5701 driver version
- ptrace patches

* Mon Oct 8 2001 Stephen Tweedie <sct@redhat.com>
- Fix ext3 directory readahead bug on empty (deleted) directories

* Sun Oct 7 2001 Arjan van de Ven <arjanv@redhat.com>
- merge 2.4.10-ac7 bugfixes
- make alpha compile again

* Fri Oct 5 2001 Stephen Tweedie <sct@redhat.com>
- Bring ext3 up to version 0.9.11

* Fri Oct 5 2001 Arjan van de Ven <arjanv@redhat.com>
- went back to old emu10k driver; the new one has too many problems
- added PPP over ATM patch

* Thu Oct 4 2001 Arjan van de Ven <arjanv@redhat.com>
- merged a few 2.4.9-ac18 bugfixes

* Wed Oct 3 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed hotplug driver to make system load not 1.00

* Mon Oct 1 2001 Arjan van de Ven <arjanv@redhat.com>
- update qla1280 driver

* Wed Sep 25 2001 Arjan van de Ven <arjanv@redhat.com>
- update Serverraid driver
- add quite a few MODULE_LICENSE() tags
- revert gendisk patch from -ac10
- add "tainted" patch from Keith Owens

* Mon Sep 23 2001 Arjan van de Ven <arjanv@redhat.com>
- updated ataraid to latest versions
- updated to block highmem patch version 15 
- updated hotplugpci patch

* Sun Sep 23 2001 Arjan van de Ven <arjanv@redhat.com>
- Add Rik van Riels VM tuning patch

* Sun Sep 23 2001 Florian La Roche <Florian.LaRoche@redhat.de>
- update s390 patches to 2.4.9ac14
- start s390x support
- add printk patch again

* Fri Sep 21 2001 Ingo Molnar <mingo@redhat.com>
- update TUX

* Fri Sep 21 2001 Arjan van de Ven <arjanv@redhat.com>
- added aic7xxx_old to the "highmem capable" devicelist

* Mon Sep 17 2001 Arjan van de Ven <arjanv@redhat.com>
- update Jens' block highmem patch
- add patch for 48bit IDE LBA 
- updated e100/e1000 drivers
- added sd maxsectors patch

* Sat Sep 15 2001 Florian La Roche <Florian.LaRoche@redhat.de>
- put all Red Hat specific s390 patches in one file

* Thu Sep 13 2001 Arjan van de Ven <arjanv@redhat.com>
- make freevxfs autoload

* Mon Sep 10 2001 Arjan van de Ven <arjanv@redhat.com>
- go to 2.4.9-ac10
- update linux-abi to upstream 2.4.9-0 version

* Thu Sep 06 2001 Arjan van de Ven <arjanv@redhat.com>
- fix oops in ia64 unwind (#52486)
- added /proc/unalignedinfo for ia64 (#42310) while
  disabling the evil printk's

* Wed Sep 05 2001 Arjan van de Ven <arjanv@redhat.com>
- go to 2.4.9-ac7

* Fri Aug 31 2001 Michael K. Johnson <johnsonm@redhat.com>
- make quota messages look saner
- pci hotplug modular

* Tue Aug 28 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed oops on ieee1394 disconnect

* Mon Aug 27 2001 Arjan van de Ven <arjanv@redhat.com>
- add grubby to %post and %preun to automatically change grub.conf
- added patch to fix #50785 (cipe doesn't reload)
- minor updates from 2.4.9-ac1

* Mon Aug 27 2001 Stephen C. Tweedie <sct@redhat.com>
- Bring ext3 up to version 0.9.8: fixes an NFS oops, cleans up some
  printk log levels, updates error state on disk more rigorously and
  adds a "do_sync_supers" module parameter to allow the  sychronous
  superblock flush behaviour of ext3-0.9.6 to be restored on demand. 

* Sat Aug 25 2001 Ingo Molnar <mingo@redhat.com>
- fix the acenic driver bug that caused random kernel memory being
  sent out on the wire, on x86 systems with more than 4 GB RAM.

* Sat Aug 25 2001 Arjan van de Ven <arjanv@redhat.com>
- backout out the ewrk3 driver to the 2.4.2 version (#51961)
  as that one worked.
- disabled oom moderation
- added tulip_old driver (the 2.4.2/2.4.3 version) (#49966, #51622)
- added Doug's latest i810 driver (#49876)
- fixed USB device table (#51229)

* Fri Aug 24 2001 Benjamin LaHaise <bcrl@redhat.com>
- update ns83820 to v0.10

* Fri Aug 24 2001 Pete Zaitcev <zaitcev@redhat.com>
- Fix for 52229

* Fri Aug 23 2001 Arjan van de Ven <arjanv@redhat.com>
- updated e1000 driver (#52154)
- removed /sbin/installkernel from the kernel rpm (moved 
  to the initscripts rpm)
- created 'noathlon' DMI blacklist entry for MSI MS-6330 motherboards
- fixed tasklet bug reported by both Broadcom and Intel
- backout a segment reload optimisation, lkml has bad bugreports about it
- added aic7xxx config option patch (Doug)

* Fri Aug 23 2001 Stephen C. Tweedie <sct@redhat.com>
- added uptodate ext3 code from the ext3 abort-handle-branch
  to handle taking the filesystem offline/readonly on fatal error
  cleanly.

* Thu Aug 22 2001 Benjamin LaHaise <bcrl@redhat.com>
- added clear_page_tables lock patch

* Thu Aug 22 2001 Arjan van de Ven <arjanv@redhat.com>
- added periodic shrink of icache (#52374)
- merged trivial VM tuning patch from 2.4.8-ac9
- added more reservation bouncebuffers 
  for highmem performance (#52340)
- updated e100 driver to latest version

* Wed Aug 22 2001 Arjan van de Ven <arjanv@redhat.com>
- merged S390 patches from bero
- removed dmi chunk (#51458)
- merged bugfixes from 2.4.8-ac9 
- * posixthreads tid!=pid patch
- * scsi tape bugfixes

* Tue Aug 21 2001 Arjan van de Ven <arjanv@redhat.com>
- add scsi hang fix and USB net hang fix from 2.4.8-ac8

* Mon Aug 20 2001 Michael K. Johnson <johnsonm@redhat.com>
- modification to e1000 driver at Intel's request (#49571)

* Mon Aug 20 2001 Arjan van de Ven <arjanv@redhat.com>
- added PCI ID's for KT133A chipset to AGP/DRM
- added S390 tape patch (bero)
- add missing Fritz PCMCIA driver (#50999)
- removed CONFIG_BLK_DEV_OFFBOARD (#52073) as it was bogus
- merged several DRM fixes from 2.4.7-ac7

* Sat Aug 18 2001 Arjan van de Ven <arjanv@redhat.com>
- fix oops in NFS code
- merged "DRM scribbles memory" patch from SuSE

* Fri Aug 17 2001 Arjan van de Ven <arjanv@redhat.com>
- fix critical bugfixes from 2.4.8-ac6:
-  * cpu flags are unsigned long, not int (64 bit issue)

* Thu Aug 16 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.9-vma_merge_full.patch vma merging patch that
  speeds up mozilla and gcc quite a bit

* Thu Aug 15 2001 Arjan van de Ven <arjanv@redhat.com>
- IKD included for the debug kernel
- add bcm5700 bugfixes (PCI access functions)
- upgraded wvlan_cs to not sleep with spinlocks helt (#51507)
- added "noathlon" bootflag (#50926)
- updated ia64 drm to upstream version, ifarch ia64 only

* Wed Aug 15 2001 Michael K. Johnson <johnsonm@redhat.com>
- clean up filelists a bit, add all_x86

* Wed Aug 15 2001 Arjan van de Ven <arjanv@redhat.com>
- fix "cardbus has IRQ 0 and crashes" bug (#51706)
- update i810 driver to fix oopses (Doug)
- add patch from 2.4.7-ac5 to fix a thinko in the VM

* Wed Aug 15 2001 Pete Zaitcev <zaitcev@redhat.com>
- Patch that allows to change USB printer probing order (#50218)

* Tue Aug 14 2001 Arjan van de Ven <arjanv@redhat.com>
- Made the USB keyboard patch not printk on every keypress
- added udelay(1) to the eepro100 driver
- merged bugfixes from 2.4.8-ac5
- added arch/ppc64 code, doesn't touch non-ppc

* Mon Aug 13 2001 Pete Zaitcev <zaitcev@redhat.com>
- Add fix for #51142 (Japanese USB keyboard).

* Mon Aug 13 2001 Stephen C. Tweedie <sct@redhat.com>
- Merge ext3-0.9.6

* Mon Aug 13 2001 Benjamin C.R. LaHaise <bcrl@redhat.com>
- updated linux-2.4.7-page_table_races.patch see bug #51652
- remove comments about set_page_dirty (it's actually okay)

* Mon Aug 13 2001 Michael K. Johnson <johnsonm@redhat.com>
- Minor specfile cleanups

* Mon Aug 13 2001 Arjan van de Ven <arjanv@redhat.com>
- critical bugfixes from 2.4.8-ac2
- more eepro100 PCI ID's (notting)
- more aacraid PCI ID's (adaptec)
- add patch to fix parport console pinning lp module (#51387)
- added LDT bugfix (from 2.4.8-ac2) needed for glibc

* Sun Aug 12 2001 Arjan van de Ven <arjanv@redhat.com>
- S/390 updates (Florian)

* Fri Aug 10 2001 Benjamin LaHaise <bcrl@redhat.com>
- update ns83820.c to v0.6

* Fri Aug 10 2001 Arjan van de Ven <arjanv@redhat.com>
- Added bigendian patch for ext3 (sct)
- fix resume on Dell Inspiron 8000 (#51407)
- fix oops in parport code (#51194)
- added bugfixes from 2.4.7-ac11, including fix for #49287
- Added MXT bugfix (IBM CRIT)
- removed fs/namei patch as it breaks too much

* Thu Aug 9 2001 Arjan van de Ven <arjanv@redhat.com>
- added patch from Broadcom to fix crash under high load (#51272, #51041) 
- merged bugfixes from 2.4.7-ac10; including switching to DRM4.1 from -ac10
- added Dell DMI entries for rebooting/suspend (#51269, #51202)
- added aacraid PCI ID's (#51246)
- synced S390 tree (bero)
- new iscsi drop from Cisco to comply with latest ietf standard

* Wed Aug 8 2001 Arjan van de Ven <arjanv@redhat.com>
- added ia64 TLB patch from Ben (#45204)
- added io elevator stall patch from Ben
- merge bugfixes from 2.4.7-ac9
- add IDE blacklist entries (#50775)

* Tue Aug 7 2001 Arjan van de Ven <arjanv@redhat.com>
- merged bugfixes from 2.4.7-ac8
- increased SCSI timeout (#50853)
- updated hotplug PCI patch (#50856)
- updated cpqfc driver (Compaq CRIT)
- added vfat-nfs patch (#50820, #50822, #45525, #37031)

* Mon Aug 6 2001 Arjan van de Ven <arjanv@redhat.com>
- merged bugfixes from 2.4.7-ac7
- updated bcm5820 driver
- updated linux-abi patch

* Fri Aug 3 2001 Arjan van de Ven <arjanv@redhat.com>
- Added DRI for XFree 4.1

* Thu Aug 2 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed bug where inodes were cached WAAY too long (vm bug)
- Added ethtool support to several drivers (Dell)
- Updated bcm5820 driver

* Wed Aug 01 2001 Michael K. Johnson <johnsonm@redhat.com>
- ext3 no longer optional

* Wed Aug 1 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to 2.4.7-ac3

* Tue Jul 31 2001 Arjan van de Ven <arjanv@redhat.com>
- Added DaveM's fix for the ethtool ioctl

* Wed Jul 25 2001 Guy Streeter <streeter@redhat.com>
- ppc build fixes
- mac and pSeries rpm and Makefile support

* Wed Jul 25 2001 Michael K. Johnson <johnsonm@redhat.com>
- update to cpqarray 2.4.5

* Tue Jul 24 2001 Michael K. Johnson <johnsonm@redhat.com>
- add spinlocks to cramfs decompression for SMP operation

* Tue Jul 24 2001 Ingo Molnar <mingo@redhat.com>
- fixed rare BUG in reclaim_page

* Mon Jul 23 2001 Michael K. Johnson <johnsonm@redhat.com>
- removed accidentally added and unneeded ia64 BOOT kernel

* Mon Jul 23 2001 Benjamin LaHaise <bcrl@redhat.com>
- update ns83820 driver to v0.5

* Mon Jul 23 2001 Arjan van de Ven <arjanv@redhat.com>
- Update MXT patch
- Updated GDTH driver
- Made EXT3 a module again
- Fixed module oops dumps
- Fiddled with VM some more
- Updated BCM5820 driver

* Sat Jul 21 2001 Arjan van de Ven <arjanv@redhat.com>
- made oom killer less trigger-happy

* Fri Jul 20 2001 Stephen C. Tweedie <sct@redhat.com>
- Fix slab-poison oops in ext3 checkpoint cleanup code

* Fri Jul 20 2001 Arjan van de Ven <arjanv@redhat.com>
- made EXT3 nonmodular to allow for better debugging/oopstracing
- updated e1000 driver to new version from Intel

* Thu Jul 19 2001 Stephen C. Tweedie <sct@redhat.com>
- Merge in ext3-0.9.3

* Thu Jul 19 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to 2.4.6-ac5
- updated cciss driver
- renabled tux
- added Florian's s390 patch

* Mon Jul 16 2001 Stephen C. Tweedie <sct@redhat.com>
- Added ext3 fix for block allocation race

* Fri Jul 13 2001 Philip Copeland <bryce@redhat.com>
- Removed extra show_stack() function on the end of the tux2 patch
  arch/alpha/kernel/traps.c +103 and +129

* Fri Jul 13 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added raid1 wait_event patch

* Thu Jul 12 2001 Arjan van de Ven <arjanv@redhat.com>
- added updated cpqfc driver

* Tue Jul 10 2001 Ingo Molnar <mingo@redhat.com>
- merge multipath patch

* Mon Jul 09 2001 Michael K. Johnson <johnsonm@redhat.com>
- change from 8 to 32 available swap areas (~1k memory cost)

* Sun Jul 08 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Pete's patch to fix the IDE tape

* Sat Jul 07 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch to not allocate highmem bouncepages on non-highmem machines
- fixed ia64 boot

* Fri Jul 06 2001 Arjan van de Ven <arjanv@redhat.com>
- Updated Broadcom bcm5700 driver

* Thu Jul 05 2001 Arjan van de Ven <arjanv@redhat.com>
- updated airo_cs driver

* Thu Jul 05 2001 Michael K. Johnson <johnsonm@redhat.com>
- initrd_dir because ia64 uses /boot/efi

* Mon Jul 03 2001 Arjan van de Ven <arjanv@redhat.com>
- Update hpt/pdcraid support
- updated to 2.4.5-ac23

* Mon Jul 02 2001 Michael K. Johnson <johnsonm@redhat.com>
- Removed nested ifarch's from %build/%files by adding arch exclusions

* Thu Jun 28 2001 Arjan van de Ven <arjanv@redhat.com>
- Add prefetch() support to ia64

* Wed Jun 27 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.5-ac19
- fixed O(N^2) algorithm in buffercache sync code

* Tue Jun 26 2001 Philip Copeland <bryce@redhat.com>
- updated IPVS

* Tue Jun 26 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch fom Jakub to fix sections

* Mon Jun 25 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch from marcelo@conectiva.com.br to show better swapinfo

* Sun Jun 24 2001 Arjan van de Ven <arjanv@redhat.com>
- Updated HPT370 driver

* Fri Jun 22 2001 Arjan van de Ven <arjanv@redhat.com>
- added HPT370 driver
- reverted xircom_cb to older version

* Fri Jun 22 2001 Michael K. Johnson <johnsonm@redhat.com>
- a bit more RPM flexibility with more existence macros
- conditionalize tape and BOOTtape kernels

* Thu Jun 21 2001 Arjan van de Ven <arjanv@redhat.com>
- reverted borken ext3 bit
- 2.4.5-ac17
- added /proc/sys/kernel/cad_pid patch

* Wed Jun 20 2001 Arjan van de Ven <arjanv@redhat.com>
- renumbered all the patches for future expansion / better separation
- new hotplug patch
- MXT patch

* Wed Jun 20 2001 Michael K. Johnson <johnsonm@redhat.com>
- speed things up a bit more for test builds:
  o buildup define for choosing whether to build the uniprocessor kernel
  o builddevfsd define ditto for devfsd (devfs itself still off)

* Tue Jun 19 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to 2.4.5-ac16

* Mon Jun 18 2001 Arjan van de Ven <arjanv@redhat.com>
- added updated pdcraid driver

* Sun Jun 17 2001 Arjan van de Ven <arjanv@redhat.com>
- added CONFIG_SMALL, will need more tweaks for the BOOT kernel still

* Sat Jun 16 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.5-ac15

* Fri Jun 15 2001 Arjan van de Ven <arjanv@redhat.com>
- moved to 2.4.5-ac14
- made i386 optimize for cpu=586
- disabled TUX for VM testing
- updated ext3


* Mon Jun 11 2001 Michael K. Johnson <johnsonm@redhat.com>
- killed some spec file cruft, made the spec file easier to maintain

* Sat Jun 09 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.5-ac12
- New aacraid driver

* Sat Jun 09 2001 Michael K. Johnson <johnsonm@redhat.com>
- ieee1394 update

* Fri Jun  8 2001 Bill Nottingham <notting@redhat.com>
- add 0530 ia64 patch, make it apply, etc.

* Thu Jun 07 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Marcelo's swap patch
- added but disabled new DRM code

* Mon Jun  4 2001 Bill Nottingham <notting@redhat.com>
- add locking fix for usb-uhci from Pete Zaitcev to linux-2.4.3-usb.patch

* Tue May 29 2001 Pete Zaitcev <zaitcev@redhat.com>
- re-enable usb patches 263, 271. The latter is on its way out but
  we need it still.

* Tue May 29 2001 Bill Nottingham <notting@redhat.com>
- regen ia64 patch

* Tue May 29 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.5-ac3
- updated EXT3
- Added hotplug pci for test
- Added VM patch by Andrea

* Mon May 28 2001 Arjan van de Ven <arjanv@redhat.com>
- go to 2.4.5-ac2

* Sat May 26 2001 Arjan van de Ven <arjanv@redhat.com>
- merge base to 2.4.5-ac1

* Fri May 25 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.4-ac17 (mostly null pointer fixes)
- New version of 3ware driver
- New version of symbios driver
- New version of FreeVxFS 
- Added ECC module
- merge base to 2.4.4-ac17

* Thu May 24 2001 Arjan van de Ven <arjanv@redhat.com>
- Added rawio fix from Shinya Narahara
- New version of EXT3

* Thu May 24 2001 Michael K. Johnson <johnsonm@redhat.com>
- modprobe loop on preun as well

* Wed May 23 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.4-ac14

* Tue May 22 2001 Arjan van de Ven <arjanv@redhat.com>
- Added fixes from 2.4.4-ac12 and ac13

* Mon May 21 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Jakub's ELF loader patch
- Added i82365 patch
- Updated TUX2 patch to 2.4.4 E4 level

*  Fri May 18 2001 Philip Copeland <bryce@redhat.com>
- added ext3 support for 2.4 (EXPERIMENTAL AND **NOT** FOR PRODUCTION)

*  Fri May 18 2001 Philip Copeland <bryce@redhat.com>
- Added in the pyrixs chipset fix for stable PCI DMA xfer
  so things like udma5 burst xfers across bus masters will
  work without locking up sx/lx 164 alpha's

* Fri May 18 2001 Arjan van de Ven <arjanv@redhat.com>
- bugfixes from 2.4.4-ac10

* Thu May 17 2001 Bill Nottingham <notting@redhat.com>
- add qla2x00 v4.28
- revert tlb-shootdown portion of -ac patch for ia64

* Thu May 17 2001 Arjan van de Ven <arjanv@redhat.com>
- compaq raid update now for all archs
- new e100 / e1000 / megaraid drivers


* Wed May 16 2001 Arjan van de Ven <arjanv@redhat.com>
- Fix Dell Poweredge 8450 patch

* Tue May 15 2001 Benjamin LaHaise <bcrl@redhat.com>
- replace reservation patch with vmfixes for a few vm deadlocks with highmem

* Tue May 15 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Dell Poweredge 8450 patch
- Disable weird fixup for intel 450nx chipset

* Mon May 14 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed bugfixes from 2.4.4-ac9
- discourage IRQ 12 for yenta_socket

* Fri May 11 2001 Arjan van de Ven <arjanv@redhat.com>
- Made ECN default to off and enabled CONFIG_INET_ECN

* Fri May 11 2001 Philip Copeland <bryce@redhat.com>
- no need for %ifdef'ing ipvs anymore

* Thu May 10 2001 Bill Nottingham <notting@redhat.com>
- add update for uhci driver on ia64

* Thu May 10 2001 Michael K. Johnson <johnsonm@redhat.com>
- disable reservation patch for now, not quite cooked yet.

* Thu May 10 2001 Benjamin LaHaise <bcrl@redhat.com>
- updated reservation patch.  should work now.

* Thu May 10 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Al Viro's audit patches
- More drives for the blacklist 
- removed finer-flush patch

* Thu May 10 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added CD-532E-A to the ide dma blacklist

* Wed May 09 2001 Benjamin LaHaise <bcrl@redhat.com>
- added memory reservation

* Wed May 09 2001 Bill Nottingham <notting@redhat.com>
- new ia64 patch (based on 2.4.4, so back a couple bits out)

* Wed May 09 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch for serialport on xircom cardbus
- Merged bugfixes from 2.4.4-ac6

* Tue May 08 2001 Michael K. Johnson <johnsonm@redhat.com>
- Add headers for athlon smp to merged symbol set
- Revert the dead swap patch from -ac12

* Tue May 08 2001 Bill Nottingham <notting@redhat.com>
- new smartarray stuff from Compaq (ia64-only ATM)

* Tue May 08 2001 Arjan van de Ven <arjanv@redhat.com>
- Bugfixes from 2.4.4-ac4 and 2.4.4-ac5
- Updated 8139too
- Fixed 8x registration bug in eepro
- Update gdth driver
- added fix for brlocks

* Mon May 07 2001 Michael K. Johnson <johnsonm@redhat.com>
- added linux-2.4.3-r128-drm-do-wait-for-fifo.patch

* Fri May 04 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added Dell patch to be able to specify rebooting from boot cpu with "s" flag
- updated linux-2.4.3-ymfpci.patch to include niph patch from Pete Zaitcev
- updated linux-2.4.3-usb.patch to include dereg patch from Pete Zaitcev

* Fri May 4 2001 Benjamin LaHaise <bcrl@redhat.com>
- remove linux-2.4.3-smpcall-fix.patch

* Fri May 4 2001 Stephen C. Tweedie <sct@redhat.com>
- Fix race in smp_call_function

* Thu May 3 2001 Stephen C. Tweedie <sct@redhat.com>
- bump version number

* Thu May 3 2001 Philip Copeland <bryce@redhat.com>
- Added in submitted patch for the nautilus alpha system
  from Hyung Min SEO <HMSEO@sec.samsung.com>

* Thu May 3 2001 Stephen C. Tweedie <sct@redhat.com>
- allow urgent VM page allocation requests to be satisfied more
  easily

* Thu May 3 2001 Stephen C. Tweedie <sct@redhat.com>
- added significant speedup for scanning full swap maps

* Wed May 2 2001 Stephen C. Tweedie <sct@redhat.com>
- added trivial host-cpu sysrq-T debug output

* Wed May 2 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.3-page_table_races.patch vm fixups

* Wed May  2 2001 Bill Nottingham <notting@redhat.com>
- don't call tty_write_message on unaligned traps on ia64

* Wed May 2 2001 Arjan van de Ven <arjanv@redhat.com>
- Added irq-fault lockup patch 
- Merged 2.4.4-ac3 bugfixes:
  - USB acm
  - APM allow_ints option
  - Descriptortable corruption
  - DMFE driver skb alloc  
  - typo in IDE code
  - netfilter updates
  - core network updates
  - via workaraound 686a fix
  - Alpha fixes


* Wed May 2 2001 Philip Copeland <bryce@redhat.com>
- added in DaveM's ALI patch for the sparc, with luck it may
  even work for the alpha

* Tue May 1 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.3-smpcall-fix.patch to fix a rare deadlock

* Tue May 1 2001 Arjan van de Ven <arjanv@redhat.com>
- attempt DMA livelock fix

* Mon Apr 30 2001 Arjan van de Ven <arjanv@redhat.com>
- Add patch to revert the "schedule fork'd first" patch in
  mainstream tree. It makes broken userspace show up too much.
  Also causes performance problems in some normal cases.
- fix via audio pci_enable_device
- added sct's fix to the per-cpu-pages patch

* Sun Apr 29 2001 Arjan van de Ven <arjanv@redhat.com>
- Prevent negative inode-used counts (aviro)

* Sat Apr 28 2001 Arjan van de Ven <arjanv@redhat.com>
- added patch to avoid recursing in deadlocks in create_bounce

* Fri Apr 27 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.3-vmlockup.patch for testing

* Fri Apr 27 2001 Arjan van de Ven <arjanv@redhat.com>
- Added bcrl's highmem patch
- Removed bcrl's highmem patch
- Added Al Viro's sync_one patch
- Added a patch to add the "apic" commandline option for
  some broken motherboards

* Thu Apr 26 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added linux-2.4.3-highmemthrottle.patch

* Thu Apr 26 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed bug #37759
- updated ips (ServerRAID) to 4.72
- Added Al Viro's bufferrace patch

* Wed Apr 25 2001 Bill Nottingham <notting@redhat.com>
- add qla1280 cleanup patch

* Wed Apr 25 2001 Arjan van de Ven <arjanv@redhat.com>
- Merged to ac14
- Added IPv6 patch (DaveM)

* Mon Apr 23 2001 Arjan van de Ven <arjanv@redhat.com>
- Added IRIX NFS Patch
- Added Ingo's swap patch

* Sun Apr 22 2001 Pete Zaitcev <zaitcev@redhat.com>
- Added a patch to restore my khubd fix over that official one.
  I think the official fix is no good, while ours is tested.
- Applied patch 271 again (with duplicated pieces removed).
- Added a patch for iForce joystick (#37075).

* Sun Apr 22 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.3-ac12 (for the PDC oops and the DVD bugfixes)
- added "apm=allowints" kernel option for suspend problems,
  made this the default for IBM laptops

* Sat Apr 21 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.3-ac11

* Fri Apr 20 2001 Bill Nottingham <notting@redhat.com>
- revert CDROM changes from ac10

* Fri Apr 20 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed (hopefully) bouncebufferheads deadlock
- change reboot-behavior of Dell PE1300's

* Thu Apr 19 2001 Pete Zaitcev <zaitcev@redhat.com>
- fix for ymfpci buzzing (#29562).

* Thu Apr 19 2001 Philip Copeland <bryce@redhat.com>
- added in patch to fix a subtle 21143 autonegotiation problem
  The driver would claim to negotiate 100-FD, but would report
  late collisions and bad transmit throughput.

* Thu Apr 19 2001 Michael K. Johnson <johnsonm@redhat.com>
- cleaned up spec file a bit

* Thu Apr 19 2001 Arjan van de Ven <arjanv@redhat.com>
- added fix for FTP exploit
- merged to -ac10

* Wed Apr 18 2001 Arjan van de Ven <arjanv@redhat.com>
- upgraded to 2.4.3-ac9

* Tue Apr 17 2001 Bill Nottingham <notting@redhat.com>
- update ia64 to 010405 & sync

* Tue Apr 17 2001 Arjan van de Ven <arjanv@redhat.com>
- Updated to 2.4.3-ac7
- merged Pete Zaitcev's USB bugfix-patches

* Mon Apr 09 2001 Arjan van de Ven <arjanv@redhat.com>
- Added IDE corruption fix

* Sun Apr 08 2001 Michael K. Johnson <johnsonm@redhat.com>
- Update release to 2.4.2-2
- Clean up some cruft in spec file
- Relax ordering requirements: gawk used in postun
- Strengthen ordering requirements: now prereq correct initscripts
  for mkkerneldoth (read: "make kernel dot h")

* Sun Apr 08 2001 Doug Ledford <dledford@redhat.com>
- Fix some multipath issues (multipath-fixes-4)

* Sun Apr 08 2001 Arjan van de Ven <arjanv@redhat.com>
- Updated Xircom not-a-Tulip driver

* Sat Apr 07 2001 Doug Ledford <dledford@redhat.com>
- Hopefully the final round of i810 audio fixes

* Sat Apr 07 2001 Benjamin LaHaise <bcrl@redhat.com>
- extracted linux-2.4.2-page_bitmap.patch from vmpoison
  and added to all builds.

* Sat Apr 07 2001 Arjan van de Ven <arjanv@redhat.com>
- Hopefully fixed the /boot/kernel.h issue forever
- Silence a few more printk's to be syslog only

* Sat Apr  7 2001 Matt Wilson <msw@redhat.com>
- disable debugging
- 0.1.51

* Sat Apr  7 2001 Ingo Molnar <mingo@redhat.com>
- added swap fixes

* Sat Apr  7 2001 Ingo Molnar <mingo@redhat.com>
- ext2fs corruption fixes

* Fri Apr 06 2001 Bill Nottingham <notting@redhat.com>
- more ia64 csum tweaks

* Fri Apr 06 2001 Doug Ledford <dledford@redhat.com>
- fix the multipath code and re-enable

* Thu Apr 05 2001 Michael K. Johnson <johnsonm@redhat.com>
- Conditionalize multipath, disabled for now

* Thu Apr 05 2001 Arjan van de Ven <arjanv@redhat.com>
- Added bcrl's patch to fix SMP swap corruption

* Thu Apr 05 2001 Doug Ledford <dledford@redhat.com>
- fix i810 sound driver to work around broken artsd and a kernel bug

* Wed Apr 04 2001 Arjan van de Ven <arjanv@redhat.com>
- Added fixes for corruption in buffer.c and scsi_merge

* Wed Apr 04 2001 Michael K. Johnson <johnsonm@redhat.com>
- conflict with old versions of mount and nfs-utils

* Tue Apr 03 2001 Arjan van de Ven <arjanv@redhat.com>
- added ohci patch

* Tue Apr 03 2001 Ingo Molnar <mingo@redhat.com>
- TUX-fixes patch, update to -X4 version.

* Fri Mar 30 2001 Bill Nottingham <notting@redhat.com>
- fix ia64 build

* Thu Mar 29 2001 Bill Nottingham <notting@redhat.com>
- add patch to fix machine checks on ia64 (<asit.k.mallick@intel.com>)

* Wed Mar 28 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-dma-livelock-fix

* Wed Mar 28 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-vmtruncate.patch

* Wed Mar 28 2001 Stephen C. Tweedie <sct@redhat.com>
- Added aggressive reclaim of orphaned swap (if vmbalance enabled)

* Wed Mar 28 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Alan's cardbus patch
- Added zaitcev's USB message throttling

* Wed Mar 28 2001 Benjamin LaHaise <bcrl@redhat.com>
- added BUG() if buffer unlocked in end_io call to vmpoison patch
- added linux-2.4.2-rqdebug.patch from sct.

* Wed Mar 28 2001 Ingo Molnar <mingo@redhat.com>
- another batch of multipath-fixes, separate patch so that
  we have an easy way back.

* Tue Mar 27 2001 Benjamin LaHaise <bcrl@redhat.com>
- added BUG() if buffer unlocked in end_io call to vmpoison patch

* Tue Mar 27 2001 Stephen C. Tweedie <sct@redhat.com>
- fix debugging conflict with smbfs internal debugging

* Tue Mar 27 2001 Tim Waugh <twaugh@redhat.com>
- added linux-2.4.2-restorestate.patch: fix bug #31170

* Tue Mar 27 2001 Benjamin LaHaise <bcrl@redhat.com>
- fix debugging bug with reclaim_page

* Tue Mar 27 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Alan's "blacklist KT7RAID for IDE DMA" patch

* Tue Mar 27 2001 Benjamin LaHaise <bcrl@redhat.com>
- updated linux-2.4.2-no_profile.patch to correct patch
- updated linux-2.4.2-vmpoison.patch to fix a bug

* Mon Mar 26 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-find_page.patch: potential corruption fix
- added linux-2.4.2-no_profile.patch regain 6MB of memory on boot
- added linux-2.4.2-bootmem_oom.patch to panic on oom during boot
- updated linux-2.4.2-vmpoison.patch with more poison, removed
  linux-2.4.2-uptodate.patch
- added linux-2.4.2-i2oinit.patch from Arjan

* Mon Mar 26 2001 Bill Nottingham <notting@redhat.com>
- patch from David Mosberger to fix networking issues on ia64

* Mon Mar 26 2001 Arjan van de Ven <arjanv@redhat.com>
- Mark OSB4 driver experimental
- Update TUX2
- merged zaitcev's OV511 fix
- disabled dma66 for all via IDE chipsets

* Sun Mar 25 2001 Benjamin LaHaise <bcrl@redhat.com>
- Added linux-2.4.2-uptodate.diff to BUG() out on page cache misuse;
  also includes a potential fix for the corruption problem.

* Sun Mar 25 2001 Ingo Molnar <mingo@redhat.com>
- Update the multipath-fixes patch to the much less
  radical C0 version, B1 was never meant to be committed,
  it was a Dell-only test-patch!

* Sat Mar 24 2001 Stephen C. Tweedie <sct@redhat.com>
- Added buffer_head highmem fix

* Fri Mar 23 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-aviro-buffer.c.patch
- updated linux-2.4.2-vmpoison.patch

* Fri Mar 23 2001 Doug Ledford <dledford@redhat.com>
- Update the multipath-fixes patch to the B1 version from Ingo

* Fri Mar 23 2001 Arjan van de Ven <arjanv@redhat.com>
- Merged bugfixes from 2.4.2-ac23
  * isapnp fix
  * reiserfs corruption
  * sound lock_kernel thinkos
  * allow sleeping in C-A-D handlers
  * small PPP race


* Thu Mar 22 2001 Bill Nottingham <notting@redhat.com>
- merge in 010321 ia64 patch from David Mosberger
- don't apply vmpoison.patch on ia64 (it relies on per-cpu-pages)

* Thu Mar 22 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-req_finished_io.patch for req_finished_io
- updated vmpoison.patch to fix a kmap problem
- added linux-2.4.2-ip_conntrack.patch to fix a hash table
  size of 0 which results in an Oops on startup
- added linux-2.4.2-pmd_alloc_fix.patch
- added linux-2.4.2-bootmem.patch to fix an off by one error
  that results in memory overwrites

* Thu Mar 22 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch from DaveM to fix IPv6 tunnels.
- Merged tux V1
- Disabled the Serverworks UDMA support
- Added IBM's new ServerRAID driver. This one has survived lots of testing
    by IBM
- Added ptrace patch

* Wed Mar 21 2001 Philip Copeland <bryce@redhat.com>
- Updated config files to take account of two new config options
  CONFIG_IP_VS_DEBUG (n)
  CONFIG_IP_VS_TAB_BITS (16)
- Modified the 2.4.2-cipe.patch to acomodate the change of location
  of ipvs

* Wed Mar 21 2001 Philip Copeland <bryce@redhat.com>
- retired Patch275 and replaced it with 276 on the recomendation of
  Wensong which moves ipvs from 0.1.2 -> 0.2.4
  Structurally removes net/ipv4/netfilter/ip_vs and moves it to
  net/ipv4/ipvs

* Wed Mar 21 2001 Doug Ledford <dledford@redhat.com>
- fix memory leak in i810 sound driver
- update scsi-reset patch to correct some locking issues under heavy reset
  conditions (James Bottomley)

* Wed Mar 21 2001 Stephen C. Tweedie <sct@redhat.com>
- Added shared memory locking fix

* Wed Mar 21 2001 Arjan van de Ven <arjanv@redhat.com>
- silenced DRI debugging messages
- merged Ingo's patch for spinlocks around apic operations

* Wed Mar 21 2001 Doug Ledford <dledford@redhat.com>
- update i810 sound driver to solve artsd output problems
- added scsi_scan patch to make scanning of sparselun devices work again
- update old aic7xxx driver to possibly fix 7896 lockup problems
- updated new aic7xxx driver to version 6.1.7

* Tue Mar 20 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch for netgear fa31x boards powerstate
- Added patch to silence PS/2 code (no keyboard there if
  there is a USB keyboard)

* Mon Mar 19 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Zaitcev's patch for USB mice (#23670)


* Sun Mar 18 2001 Arjan van de Ven <arjanv@redhat.com>
- Added fix for HPT370 UDMA problem

* Fri Mar 16 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added qlogicfc to the list of controllers with limited scsi request sizes

* Thu Mar 15 2001 Michael K. Johnson <johnsonm@redhat.com>
- updated binfmt_misc patch to create directory

* Thu Mar 15 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-ac20-pmd_alloc.diff fix for PAE

* Thu Mar 15 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Al Viro's patch to fs/namei.c
- Added the BKL patch for truncate (2.4.2-ac)
- added VM poison

* Wed Mar 14 2001 Arjan van de Ven <arjanv@redhat.com>
- Added 2.4.2-ac20 I2O patches
- Made PCI printk's KERN_INFO

* Thu Mar 13 2001 Stephen C. Tweedie <sct@redhat.com>
- merge in VM performance changes up to 2.4.2-ac18

* Tue Mar 13 2001 Arjan van de Ven <arjanv@redhat.com>
- fix bug 30513 (iostat vs promise IDE boards)
- TUX 2.4.2-S4
- merged md fixes

* Mon Mar 12 2001 Bill Nottingham <notting@redhat.com>
- run /usr/sbin/module_upgrade in a kudzu trigger as well

* Mon Mar 12 2001 Arjan van de Ven <arjanv@redhat.com>
- merged bugfixes from 2.4.2-ac18:
  - reiserfs cleanup
  - zerocopy bugfixes
  - zerocopy nbd
  - smbfs fixes
  - cyrix III MTRR checks
  - vmalloc race fix
  - pcmcia resource fix
- merged TUX 2.4.2-P3
- new version of the xircom driver
- default limit of 64 sectors in a scsi request
- enabled slab poison
- fixed 28489

* Fri Mar 09 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added another request-size limiting patch for Qlogic sbus and BusLogic,
  may need to add more adapters to this patch over time

* Fri Mar 09 2001 Arjan van de Ven <arjanv@redhat.com>
- Added QLogic ISP request-size limiting patch
- Updated xircom_cb driver to newer version
- Potential workaround for Abit KT7ARAID board bugs in via-corruption patch

* Thu Mar 08 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added cipefix patch from David Miller

* Thu Mar 08 2001 Stephen C. Tweedie <sct@redhat.com>
- add current raw IO fixes

* Thu Mar 08 2001 Pete Zaitcev <zaitcev@redhat.com>
- Adding a fix for usb-uhci to work when SLAB is not aligned (poisoned).

* Thu Mar 08 2001 Michael K. Johnson <johnsonm@redhat.com>
- now prereq modutils 2.4.2-5 for new binfmt_misc support

* Thu Mar 08 2001 Arjan van de Ven <arjanv@redhat.com>
- added Ingo's bouncebuffer patch
- added Tim Waughs parport fixes
- switched to Alan's cleaned up megaraid
- added zaitcev's patch to prevent LVM oops
- added Than Ngo's patch for pcmcia ISDN
- forward-ported 2.2.19pre1 via timerbug workaround
- added Al Viro's binfmt_misc

* Wed Mar 07 2001 Arjan van de Ven <arjanv@redhat.com>
- added epca patch and more USB scanner ID's from 2.4.2-ac13
- added the IDE dma blacklist

* Tue Mar 06 2001 Doug Ledford <dledford@redhat.com>
- heavily patched/modified version of the i810 audio driver

* Tue Mar 06 2001 Arjan van de Ven <arjanv@redhat.com>
- added pge patch for Cyrix 686 kernels from Arjan

* Tue Mar 06 2001 Michael K. Johnson <johnsonm@redhat.com>
- depmod -ae

* Tue Mar 06 2001 Arjan van de Ven <arjanv@redhat.com>
- 2 more patches from 2.4.2-ac11/12 (8139too and the pci resources API change )
- workaround for the tokenring init mess
- added patch to enable the second IDE channel on PDC20265's

* Tue Mar  6 2001 Matt Wilson <msw@redhat.com>
- added linux-2.4.2-i2o-blocksize.patch (Patch225) to fix i2o /proc/partitions
  entries

* Mon Mar 05 2001 Michael K. Johnson <johnsonm@redhat.com>
- Turned off CONFIG_USB_MOUSE because the HID code handles all mice we know

* Mon Mar 05 2001 Arjan van de Ven <arjanv@redhat.com>
- Added the patch from DHinds to fix cardbus irqs
- enabled multicast routing, bridging and QOS
- merged patches 214 to 224 from 2.4.2-ac11


* Sun Mar 4 2001 Philip Copeland <bryce@redhat.com>
- Reverted the parport_device_id changes that are in ac3
  which prevent the kernel-sources-x.y.z.src.rpm from
  being recompiled

* Fri Mar 02 2001 Ingo Molnar <mingo@redhat.com>
- linux-2.4.2-nmi-lockup-workaround.patch temporarily defaults nmi watchdog off

* Fri Mar 02 2001 Philip Copeland <bryce@redhat.com>
- added linux-2.4.2-alpha-irongate.patch from Compaq

* Fri Mar 02 2001 Michael K. Johnson <johnsonm@redhat.com>
- added Arjan's linux-2.4.2-via-corruption.patch to fix disk corruption
  problems widely reported on KT133 machines
- Stephen/Tim fixed linux-2.4.1-axboe-scsi-max-sec.patch fixing scsi performance

* Thu Mar 01 2001 Doug Ledford <dledford@redhat.com>
- Added the scsi-reset patch so that you can reset devices through their
  sg entry

* Thu Mar 01 2001 Arjan van de Ven <arjanv@redhat.com>
- updated reiserfs to latest version
- prevent raid from oopsing
- lockd patch
- added alternate airo_cs driver
- added zaitcev's USB alloc fix

* Wed Feb 28 2001 Michael K. Johnson <johnsonm@redhat.com>
- atp.c would not compile as a module, fixed

* Wed Feb 28 2001 Arjan van de Ven <arjanv@redhat.com>
- Added extra Toshoboe PCI ID (29993)
- added "fix hang in parport" patch (twaugh)
- maestro3 DMA fix
- fixed 29908 (loopdevice oops)

* Tue Feb 27 2001 Matt Wilson <msw@redhat.com>
- added a patch to fix for non-atomic bit clear in eepro100 driver on alpha
  (linux-2.4.2-eepro100-alpha.patch)

* Tue Feb 27 2001 Arjan van de Ven <arjanv@redhat.com>
- updated ikd to 2.4.2
- added olympic driver fix
- make Alpha happy
- added opl3sa patch
- added netdevice setup patch
- added 3ware patch
- merged TUX version G9
 
* Mon Feb 26 2001 Doug Ledford <dledford@redhat.com>
- bug fix to the aic7xxx-5.2.3 driver
- Added Michael E. Brown <michael_e_brown@dell.com> patch to add an ioctl to
  the block device layer to allow accessing the last sectors in a block
  device that has an odd number of sectors (needed for EFI compliance)
- Added Ingo's multipath I/O support for the md raid layer

* Mon Feb 26 2001 Bill Nottingham <notting@redhat.com>
- fix a case where the ia64 clock can go backwards (from <steiner@sgi.com>)

* Mon Feb 26 2001 Arjan van de Ven <arjanv@redhat.com>
- Added netdebug patch on DaveM's request
- Added support for the Epson 1240U usb scanner
- removed wavelan udelay patch (no longer needed for gcc 2.96-74)
- derace the waking of the usb storage thread
- merged to 2.4.2-ac3, bumped version to 0.1.15
- put in the new, experimental xircom_cb driver
- upgraded to tux 2.4.2-F8

* Fri Feb 23 2001 Michael K. Johnson <johnsonm@redhat.com>
- added preinstalls for smp and enterprise to modprobe loop like uniprocessor
- disabled 3c90x driver because it does not work correctly.

* Fri Feb 23 2001 Bill Nottingham <notting@redhat.com>
- just remove modules.* in %preun; catches anything new, and
  avoids errors if certain files aren't there

* Fri Feb 23 2001 Arjan van de Ven <arjanv@redhat.com>
- Updated 3c59x driver to version 1.1.14 from Andrew Morton
- enabled Hewlett-Packard 8200e/8210e CD-Writer Plus
- enabled Advanced routing (#29087)

* Tue Feb 22 2001 Matt Wilson <msw@redhat.com>
- updated module-info to the copy from anaconda CVS

* Thu Feb 22 2001 Arjan van de Ven <arjanv@redhat.com>
- added 3ware patch
- re-enabled 3ware again

* Thu Feb 22 2001 Michael K. Johnson <johnsonm@redhat.com>
- added linux-2.4.1-flush_tlb_export.patch
- updated to e100 1.5.5

* Wed Feb 21 2001 Doug Ledford <dledford@redhat.com>
- update Justin Gibbs' aic7xxx driver to version 6.1.4

* Wed Feb 21 2001 Bill Nottingham <notting@redhat.com>
- export a couple more symbols on ia64
- increase default size of swiotlb on ia64

* Wed Feb 21 2001 Michael K. Johnson <johnsonm@redhat.com>
- disable 3ware driver on SMP until a bugfix is found
- updated to tux2-2.4.1-P5 to fix dcache bug

* Wed Feb 21 2001 Arjan van de Ven <arjanv@redhat.com>
- Merged bugfixes from ac20:
  - non-PNP AWE32 fix
  - updates to various pcmcia network drivers
- Added "ideX=nodma" commandline option

* Tue Feb 20 2001 Arjan van de Ven <arjanv@redhat.com>
- Reordered several patches to the proper section
- Merged the following patches from ac17-18-19:
  - jgarzik's network driver cleanups
  - reiserfs tailpacking datacorruption
  - smbfs off-by-one fixes
  - USB 2.0, USB Hub device claim race, USB net recovery 
  - SO_SNDTIMEO bugs
- Fixed CIPE on SMP machines (#28386)
- new tulip driver
- new version of the Loop fixes (Al Viro)
- backed out vm-rebalance; be careful with ext2
  
* Mon Feb 19 2001 Bill Nottingham <notting@redhat.com>
- minor ia64 tweaks

* Mon Feb 19 2001 Michael K. Johnson <johnsonm@redhat.com>
- removed duplicate ksyms exports for alpha
- added brokenmptable patch from Ingo
- Turned on CONFIG_USB_MOUSE and CONFIG_USB_KBD because they
  are needed after all with some hardware and the conflicts with 
  CONFIG_USB_HID are non-fatal.

* Mon Feb 19 2001 Arjan van de Ven <arjanv@redhat.com>
- Merged tulip PNIC updates from 2.4.1-ac18
- removed extra DSCC4=m config option
- changed to the EUI64 format for IPv6
- enlarged printk buffer (#28288)
- upgraded to ac16, bump to 0.1.11

* Fri Feb 16 2001 Arjan van de Ven <arjanv@redhat.com>
- actually commited NFS patch
- updated intel e1000 to version 3.0.7
- reverted the kudzu change
- actually build the HP5300 module
- provisional WinChip patch
- made the 2.4 kernel conflict with isapnptools as that conflict
  breaks the actual PNP in the 2.4 kernel.


* Thu Feb 15 2001 Arjan van de Ven <arjanv@redhat.com>
- NFS memcmp bug
- changed requires kudzu >= 0.93 to conflicts kudzu <= 0.92
- made the kernel conflict with program too old according
  to Documentation/Changes

* Thu Feb 15 2001 Bill Nottingham <notting@redhat.com>
- change wvlan_cs Config.in description to something more appropriate

* Thu Feb 15 2001 Michael K. Johnson <johnsonm@redhat.com>
- Turned off CONFIG_USB_MOUSE and CONFIG_USB_KBD because they
  conflict with using CONFIG_USB_HID (hotplug loads both...)
- build toshiba module

* Thu Feb 15 2001 Karsten Hopp <karsten@redhat.de>
- search for all LUNs on CR3500 shared SCSI controller

* Wed Feb 14 2001 Doug Ledford <dledford@redhat.com>
- Add Justin Gibbs' aic7xxx driver version 6.1.1 as aic7xxx_new

* Wed Feb 14 2001 Michael K. Johnson <johnsonm@redhat.com>
- added quiet patch so that autorun and magicdev don't mangle logs

* Wed Feb 14 2001 Arjan van de Ven <arjanv@redhat.com>
- Made Cyrix CPU's work again
- Added ideprobe patch to avoid hotprobe lockups
- fixed tulip xircom phase 2
- ikd (kdb)
- remove *~ files (#18751)
- fix poll() on usb printers (#26909)
- fixed argument parsing for sym63c416 driver
- merged ac13 patch to prevent parport from corrupting the pci dev list
- fixed sbpcd (ac13)
- fixed usbhub (ac13, missing unlock_kernel)
- fixed vmalloc race (ac13)
- potential uhci slab interaction fix
- smbfs fixes (ac13)
- tmpfs nlink fix for perl (ac13)
- arcnet init fixes (ac13)


* Wed Feb 14 2001 Matt Wilson <msw@redhat.com>
- 0.1.8
- turn off tux

* Tue Feb 13 2001 Bill Nottingham <notting@redhat.com>
- fix typos in debugging patch

* Tue Feb 13 2001 Michael K. Johnson <johnsonm@redhat.com>
- turned off CONFIG_BLK_DEV_ALI15X3 for alpha
- updated to tux2-2.4.1-L4, merge with debugging and highmem patches
- added %debugging macro for turning debugging on and off
- updated to scsi-max-sec-2

* Tue Feb 13 2001 Matt Wilson <msw@redhat.com>
- 0.1.6
- turned off CONFIG_NETFILTER and CONFIG_FILTER in i386 BOOT config
- modified linux-2.4.1-ia64-010131-2.diff to use the new PCI_ROUTING_TABLE
  structure in acpiconf.c

* Tue Feb 13 2001 Arjan van de Ven <arjanv@redhat.com>
- Made "realmode poweroff" a commandline option disabled by default.
  (believed to fix #26261, #26760, #24198, #23322)
- disabled netfilter and such in the -BOOT option
- made the kernel slab patch a config-option disabled for BOOT
- ServerRAID 4.50

* Tue Feb 13 2001 Matt Wilson <msw@redhat.com>
- 0.1.5
- regenerated linux-2.4.1-ia64-010131-2.diff so it will patch
- specify ARCH= when building the common sparc/sparc64 headers

* Mon Feb 12 2001 Michael K. Johnson <johnsonm@redhat.com>
- added Jens Axboe's scsi-max-sec-1 as linux-2.4.1-axboe-scsi-max-sec.patch
- updated to new aacraid driver (depends on Jens's patch) plus Matt Domsch's fix
- added changeloop-fixes-2 from Al

* Mon Feb 12 2001 Arjan van de Ven <arjanv@redhat.com>
- upgraded to 2.4.1-ac10
- merged new e100/e1000 drivers

* Sat Feb 10 2001 Matt Wilson <msw@redhat.com>
- disable broken sparcaudio drivers on sun4[cdm]
- disable reiserfs on all sparc
- added linux-2.4.1ac8-nopci.patch to correct builds if not using CONFIG_PCI
- added linux-2.4.1ac8-zap_page_range.patch

* Fri Feb 09 2001 Michael K. Johnson <johnsonm@redhat.com>
- updated to Al's latest loop fixes

* Fri Feb 9 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to 2.4.1-ac8, changed version number to 0.1.1
- added Ingo's highmem patch
- added IRC netfilter addon for DCC over NAT
- new megaraid driver (1.14g)
- Fix for bug 26696 (compaq vs irq 13)

* Thu Feb  8 2001 Bill Nottingham <notting@redhat.com>
- sync up ia64 with David Mosberger's 20010131 patch
- add x86-compatibility ia64 bugfix patch from Don Dugger

* Thu Feb  8 2001 Matt Wilson <msw@redhat.com>
- added linux-2.4.1-i2o-lockup.patch for some bus/card combos

* Thu Feb  8 2001 Bill Nottingham <notting@redhat.com>
- don't buildprereq gcc-2.96-74 on ia64

* Thu Feb 8 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to 2.4.1-ac6, changed version number
- new broadcom driver
- serverworks workaround

* Wed Feb 7 2001 Arjan van de Ven <arjanv@redhat.com>
- corruption fix
- merged xircom_tulip into real tulip
- require gcc 2.96-74 or later for building
- merged aic7xxx from HEAD
- added DAC960 version 2.4.10

* Wed Feb 07 2001 Michael K. Johnson <johnsonm@redhat.com>
- use module_upgrade from kudzu package, prerequire kudzu >= 0.93

* Wed Feb  7 2001 Doug Ledford <dledford@redhat.com>
- fix the aic7xxx_new-6.1.0 patch :-(
- fix the aic7xxx_new-6.1.0 patch again :-(

* Wed Feb  7 2001 Matt Wilson <msw@redhat.com>
- added linux-2.4.1-i2o.patch.  This registers i2o block devices in
  /proc/partitions and fixes some other i2o bugs.

* Tue Feb 06 2001 Michael K. Johnson <johnsonm@redhat.com>
- require modutils 2.4.2 or greater

* Tue Feb  6 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Update devfsd to 1.3.11, fixes some glibc 2.2 issues

* Tue Feb  6 2001 Doug Ledford <dledford@redhat.com>
- update the aic7xxx driver to 5.2.2
- move the new Adaptec aic7xxx driver to aic7xxx_new

* Tue Feb  6 2001 Matt Wilson <msw@redhat.com>
- add a buildjensen macro, set it to 0 (as jensen seems broken)

* Mon Feb  5 2001 Matt Wilson <msw@redhat.com>
- 0.99.23
- make jensen subpackage on alpha (again, yuck)

* Mon Feb  5 2001 Matt Wilson <msw@redhat.com>
- 0.99.22
- turn on enterprise kernel
- set CONFIG_FILTER and CONFIG_NETFILTER to off in i386 BOOT kernel

* Mon Feb  5 2001 Arjan van de Ven <arjanv@redhat.com>
- Groundwork for the 2.4.1-ac2 merge
- turned of ACPI
 

* Mon Feb 5 2001 Arjan van de Ven <arjanv@redhat.com>
- added Matrox G450 patch
- updated from 2.4.1-ac1 to 2.4.1-ac2

* Fri Feb  2 2001 Matt Wilson <msw@redhat.com>
- tweaked the alpha boot kernel to be a little smaller
- moved the alpha header patch to if %%tux
- turn off tux
- added linux-2.4.0-alpha-header-conflict.patch
  (no more NFS root installs)

* Fri Feb 2 2001 Arjan van de Ven <arjanv@redhat.com>
- Socket DoS fix from Alexey/DaveM

* Thu Feb  1 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Add missing /etc/modules.devfs to devfsd package

* Thu Feb 01 2001 Michael K. Johnson <johnsonm@redhat.com>
- cciss 2.4.2
- integrated tested loop patches from Al

* Wed Jan 31 2001 Doug Ledford <dledford@redhat.com>
- added a fix for a PIII security hole

* Wed Jan 31 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.1-zap_page_range_fix.patch

* Wed Jan 31 2001 Michael K. Johnson <johnsonm@redhat.com>
- new tux patch tux2-2.4.0-final-S9

* Wed Jan 31 2001 Arjan van de Ven <arjanv@redhat.com>
- Fixed3c575 driver load typo-bug (23820)
- fixed athlon build for tux
- added provisional ide-floppy patch
- silenced the ide-cs driver a bit (resource management conflict between IDE
  and PCMCIA subsystems)
- made ia64 almost build

* Wed Jan 31 2001 Bill Nottingham <notting@redhat.com>
- include include/pcmcia in kernel-source so pcmcia drivers can build 

* Tue Jan 30 2001 Michael K. Johnson <johnsonm@redhat.com>
- temporarily disabled Al's loopback patches while he fixes them

* Tue Jan 30 2001 Arjan van de Ven <arjanv@redhat.com>
- Fixed i82365 driver (bug 24804)
- added "athlon" architecture
- Phase 1 of ide-cs fix
- maestro3 patch from Zach Brown

* Mon Jan 29 2001 Doug Ledford <dledford@redhat.com>
- Updated aic7xxx driver to 6.1.0
- Corrected a bug in the rhconfig.h file we install
- Corrected a bug in the build process in the spec file

* Mon Jan 29 2001 Michael K. Johnson <johnsonm@redhat.com>
- new tux2 patch tux2-2.4.0-final-R9
- integrated Al's loopback device fixes
- since enterprise kernel has only highmem-64GB support, limit to >= PIII

* Sun Jan 28 2001 Michael K. Johnson <johnsonm@redhat.com>
- integrated Linus's shared memory swap patch
- integrated Andrey's 1.36 eepro100 driver
- integrated block scheduler fix from pre11
- updated to new tux2 patch, now modular

* Fri Jan 26 2001 Michael K. Johnson <johnsonm@redhat.com>
- added Jens Axboe's loop patch (disabled, Al fixing it and changeloop both)

* Fri Jan 26 2001 Arjan van de Ven <arjanv@redhat.com>
- Fixed parport_cs unresolved symbol
- reverted new wvlan port, the old one _did_ work

* Fri Jan 26 2001 Doug Ledford <dledford@redhat.com>
- added the xmm patch to keep the system from touching non-existent mxcsr
  registers
- verified that the two linux-merge-*.awk scripts do indeed use the right
  symbol names so that they should work properly

* Thu Jan 25 2001 Bill Nottingham <notting@redhat.com>
- remove /lib/modules/<whatever>/modules.generic_string as well (#24991)

* Thu Jan 25 2001 Michael K. Johnson <johnsonm@redhat.com>
- integrated new tux2 patch
- require new mkinitrd for RAID modules

* Thu Jan 25 2001 Arjan van de Ven <arjanv@redhat.com>
- Added parport_cs port from pcmcia-cs package
- backed out to ac10
- new wvlan port, this one is reported to work even

* Wed Jan 24 2001 Erik Troan <ewt@redhat.com>
- updated RAID_AUTORUN patch

* Wed Jan 24 2001 Arjan van de Ven <arjanv@redhat.com>
- Fix for bug 24698 (incorrect "build" link)
- Updated to 2.4.0-ac11 (still pre9 based), bumped version to 0.99.11
- added patch to fix most warnings people will see
- changes wvlan.o to wvlan_cs.o

* Tue Jan 23 2001 Matt Wilson <msw@redhat.com>
- 2.4.0-0.99.10, ac10 base
- rebuild with modutils 2.4.2 in place

* Tue Jan 23 2001 Matt Wilson <msw@redhat.com>
- added RAID_AUTORUN ioctl to raid driver from Ingo
- fixed the autorun patch

* Tue Jan 23 2001 Benjamin LaHaise <bcrl@redhat.com>
- IDE DMA by default enabled
- add lm_sensors built as modules
- enable reiserfs

* Tue Jan 23 2001 Arjan van de Ven <arjanv@redhat.com>
- blacklisted IBM deskstar disks for UDMA on hpt366 controllers (dwmw2)
- added RAID5 corruption fix from 2.4.1-pre10
- added fix for FD problem from 2.4.1-pre10
- added DAC960 fix from 2.4.1-pre10 (Jens Axboe's patch)
- added fix wrong __init in io-apic.c from 2.4.1-pre10
- removed broadcom driver temporarily

* Mon Jan 22 2001 Matt Wilson <msw@redhat.com>
- uncomment rm -rf $RPM_BUILD_ROOT from %clean
- modified the drivers/usb/uhci.c patch of the ia64 patch to patch against ac10
- resynced kernel-2.4.0-i386-BOOT.config with available options
- added linux-2.4.0-tgafb-unregister-framebuffer.patch to pass correct
  value into unregister_framebuffer
- updated kernel-2.4.0-ia64-smp.config and kernel-2.4.0-ia64.config for
  available options

* Mon Jan 22 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.0-sysctl.patch
- added linux-2.4.0-map_user_kiobuf-fix.patch

* Mon Jan 22 2001 Matt Wilson <msw@redhat.com>
- increased ramdisk size of kernel-BOOT from 4096 to 4608

* Mon Jan 22 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to ac10, which already contains the waitpid patch

* Mon Jan 22 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.0-waitpid.patch to fix init/contextd SIGCHLD race

* Mon Jan 22 2001 Arjan van de Ven <arjanv@redhat.com>
- added first draft of wvlan driver
- touched the ide-cs thing. Please test

* Mon Jan 22 2001 Michael K. Johnson <johnsonm@redhat.com>
- turned on e1000 driver again
- e100 updated to 1.5.0 as linux-2.4.0-e100.patch

* Mon Jan 22 2001 Erik Troan <ewt@redhat.com>
- switched ide-cd back to a module in all x86 kernels

* Fri Jan 19 2001 Arjan van de Ven <arjanv@redhat.com>
- added Broadcom 5700 driver
- added patch to workaround gross misuse of ASSERT in IrDA

* Fri Jan 19 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added aacraid driver (broken so added as a non-building placeholder)
- Turn off modules on Alpha that are not building correctly
- Turn off e100 driver on IA64 because it doesn't build there
- Added linux-2.4.0-ieee1394-queuefix.patch for task queue changes
- Added linux-2.4.0-3x90x.patch 3c90x driver from 3com

* Fri Jan 19 2001 Arjan van de Ven <arjanv@redhat.com>
- updated megaraid to 1.14b
- made the non-smp kernel provide "kernel = 2.4"
- made the smp kernels provide "module-info"

* Thu Jan 18 2001 Philip Copeland <bryce@redhat.com>
- added in the SARD patch

* Thu Jan 18 2001 Erik Troan <ewt@redhat.com>
- switched idefloppy to build in
- updated e100, e1000 driver
- enabled natsemi module in i386 BOOT kernel

* Thu Jan 18 2001 Michael K. Johnson <johnsonm@redhat.com>
- new tux patch
- turned on CONFIG_IP_NF_IRC as module

* Wed Jan 17 2001 Matt Wilson <msw@redhat.com>
- fixed typo in linux-2.4.0-aic7xxx-6.0.8BETA.patch for !i386 !alpha

* Wed Jan 17 2001 Bill Nottingham <notting@redhat.com>
- update to cipe-1.4.5, make it one patch

* Wed Jan 17 2001 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.0-ac9

* Tue Jan 16 2001 Bill Nottingham <notting@redhat.com>
- fix the aic7xxx patches to not patch backup files
- fix the cipe makefile so that it builds

* Mon Jan 15 2001 Doug Ledford <dledford@redhat.com>
- move the current aic7xxx driver aic7xxx_old
- add Justin Gibbs' new aic7xxx driver
- add a fix so that the cs4281 module will build

* Fri Jan 12 2001 Karsten Hopp <karsten@redhat.de>
- added starfire mmio patch to allow reload of this module

* Fri Jan 12 2001 Philip Copeland <bryce@redhat.com>
- Added in hooks for the ipvs 0.1.2 production kits to ksyms.c
- Added in patch250 to the spec file referancing linux-2.4.0-ipvs.patch
- added subdir ipvs in kernel tree which holds ipvs module code
- ac4 typo fix

* Fri Jan 12 2001 Michael K. Johnson <johnsonm@redhat.com>
- made build symlink relative
- qla1x160src-3.23Beta as linux-2.4.0-qla1280.patch
- make oldconfig_nonint so that builds reliably fail when config files need mods

* Thu Jan 11 2001 Bill Nottingham <notting@redhat.com>
- turn off CONFIG_DISABLE_VHPT on ia64, it's broken
- fix cs4281 makefile oops
- add new patch to possibly fix broken CONFIG_DISABLE_VHPT

* Thu Jan 11 2001 Karsten Hopp <karsten@redhat.de>
- moved e1000-2.5.11.patch and the update to 2.5.14 into one patch

* Thu Jan 11 2001 Michael K. Johnson <johnsonm@redhat.com>
- Moved back to static IDE for now because a couple machines had problems.
- qla1x160src-3.22Beta as linux-2.4.0-qla1280.patch
- megaraid 1.13s as linux-2.4.0-megaraid.patch

* Wed Jan 10 2001 Matt Wilson <msw@redhat.com>
- add free_dma and request_dma prototype in asm-ia64/dma.h as
  Patch58: linux-2.4.0-ia64-free_dma.patch
- remove Patch54: linux-2.4.0-test11-ia64-ksyms.patch
- remove Patch55: linux-2.4.0-test12-ia64-idesym.patch

* Wed Jan 10 2001 Bill Nottingham <notting@redhat.com>
- sync ia64 (010109 patch)

* Wed Jan 10 2001 Matt Wilson <msw@redhat.com>
- merged alpha .config files back to the way they need to be
- turn alpha back on
 
* Wed Jan 10 2001 Michael K. Johnson <johnsonm@redhat.com>
- update to 2.4.0-ac4
- pcmcia moved to its own package
- update to new tux patch
- e820 reporting from Arjan
- Andi's RAID5 xor fix
- Ingo's Athlon APIC fix

* Mon Jan  8 2001 Bill Nottingham <notting@redhat.com>
- remove ksymoops/kernel-utils

* Fri Dec 29 2000 Bill Nottingham <notting@redhat.com>
- fix up prereqs

* Wed Dec 27 2000 Bill Nottingham <notting@redhat.com>
- something is horribly, horribly wrong with modular SCSI on ia64; turn it off
- rename source RPM back to 'kernel'

* Fri Dec 22 2000 Erik Troan <ewt@redhat.com>
- updated pcmcia config file for 2.4 cardbus support

* Thu Dec 21 2000 Erik Troan <ewt@redhat.com>
- turned HOTPLUG on for i386 BOOT kernel (PCMCIA doesn't build w/o it)

* Tue Dec 19 2000 Michael K. Johnson <johnsonm@redhat.com>
- Added linux-2.4.0-test11-vidfail.patch and enabled it for the x86 BOOT kernel
- More USB support in x86 BOOT kernel
- Require new mkinitrd for IDE modules
- SCSI entirely modular

* Fri Dec 15 2000 Bill Nottingham <notting@redhat.com>
- add patch to fix unresolved symbol on ia64 in ide-probe-mod

* Wed Dec 13 2000 Michael K. Johnson <johnsonm@redhat.com>
- CONFIG_PARPORT_PC_FIFO off, bad default at this time

* Tue Dec 12 2000 Matt Wilson <msw@redhat.com>
- switch to un-TUXified kernel
- turn on framebuffer in the BOOT kernel

* Tue Dec 12 2000 Michael K. Johnson <johnsonm@redhat.com>
- New RC of TUX-1.01 patch

* Fri Dec 08 2000 Michael K. Johnson <johnsonm@redhat.com>
- CONFIG_HAPPYMEAL turned on for all architectures

* Thu Dec  7 2000 Bill Nottingham <notting@redhat.com>
- update ia64 patch to the 1206 version
- update e100, e1000 drivers

* Wed Dec 06 2000 Michael K. Johnson <johnsonm@redhat.com>
- Require fileutils for ln use in %post scripts
- Modular IDE

* Tue Dec 05 2000 Michael K. Johnson <johnsonm@redhat.com>
- Remove apa1480 driver temporarily for TUX build

* Mon Dec  4 2000 Bill Nottingham <notting@redhat.com>
- add patch to fix SWIOTLB from Asit Mallick

* Sun Dec  3 2000 Bill Nottingham <notting@redhat.com>
- turn on usb-uhci as well as uhci
- update megaraid to 1.13beta

* Thu Nov 30 2000 Michael K. Johnson <johnsonm@redhat.com>
- TUX 1.01 RC

* Wed Nov 29 2000 Bill Nottingham <notting@redhat.com>
- fix ia64 semaphore symbol problems
- fix cipe symbol problems

* Wed Nov 29 2000 Michael K. Johnson <johnsonm@redhat.com>
- TUX 1.01 integrated with test11

* Tue Nov 28 2000 Bill Nottingham <notting@redhat.com>
- make ia64 patch patch cleanly with test11

* Mon Nov 27 2000 Bill Nottingham <notting@redhat.com>
- remove all modules.<foo>map files on package removal

* Fri Nov 24 2000 Bill Nottingham <notting@redhat.com>
- add patch to fix FAT32, patch for alignment of unwind data

* Mon Nov 20 2000 Bill Nottingham <notting@redhat.com>
- make nfs a module

* Thu Nov 16 2000 Bill Nottingham <notting@redhat.com>
- new ia64 patch from David Mosberger
- make ppp a module
- allow glibc to build for the moment

* Fri Nov 10 2000 Bill Nottingham <notting@redhat.com>
- fix alpha build

* Thu Nov  9 2000 Bill Nottingham <notting@redhat.com>
- add patch from Asit Mallick to fix ia64 VHPT disabling

* Wed Nov  8 2000 Bill Nottingham <notting@redhat.com>
- add ia64 module patch
 
* Wed Nov 08 2000 Erik Troan <ewt@redhat.com>
- updated to test10, builds on ix86
 
* Wed Nov  1 2000 Bill Nottingham <notting@redhat.com>
- build some stuff statically (bleah)
 
* Tue Oct 31 2000 Bill Nottingham <notting@redhat.com>
- new ia64 diff from David Mosberger

* Thu Oct 26 2000 Bill Nottingham <notting@redhat.com>
- turn off ptc.g, again (oops)

* Wed Oct 25 2000 Bill Nottingham <notting@redhat.com>
- EFI GUID partition support from Matt Domsch (Matt_Domsch@dell.com)

* Tue Oct 24 2000 Bill Nottingham <notting@redhat.com>
- qlogic 1x160 version 3.19beta
- qlogic 2x00 version 4.15beta
- e1000 v2.5.11
- e100 v1.3.14
- make netfilter build on ia64 (cringe)

* Mon Oct 23 2000 Bill Nottingham <notting@redhat.com>
- update to test9 final
- ia64 updates

* Fri Sep 29 2000 Bill Nottingham <notting@redhat.com>
- clean up requirements (kill devfsd, initscripts)

* Fri Sep 29 2000 Michael K. Johnson <johnsonm@redhat.com>
- updated to tux-2.4.0-test9-H8-nodebug

* Thu Sep 28 2000 Michael K. Johnson <johnsonm@redhat.com>
- updated to tux-2.4.0-test9-G9-nodebug

* Tue Sep 26 2000 Michael K. Johnson <johnsonm@redhat.com>
- updated to tux-2.4.0-test9-G4-nodebug and test9-pre7 kernel
- turned off qla2x00 because it does not know about new scsi init arch
- turned off cciss because of parse error

* Thu Sep 21 2000 Bill Nottingham <notting@redhat.com>
- revert the part of the ia64 patch that requires new modutils for now
- turn off e1000 on ix86/alpha configs

* Tue Sep 19 2000 Bill Nottingham <notting@redhat.com>
- merge in stuff from Matt Domsch
- upgrade ia64 patch from David Mosberger

* Tue Sep 19 2000 Matt_Domsch <Matt_Domsch@dell.com>
- kernel 2.4.0-0.28.4
- Upgraded acenic to v0.47

* Thu Sep 14 2000 Matt_Domsch <Matt_Domsch@dell.com>
- kernel 2.4.0-0.28.3
- Removed I2O again
- Added ia64-000913 patch

- kernel-2.4.0-0.28.2
- removed kern0906.patch
- added 2.4.0-test8-000908 IA-64 patch
- added 2.4.0-test8-ia64 irqfix patch (fixes bigsur infinite IRQ0s)
- enable i2o
- added ia64_iobase export to arch/ia64/kernel/ia64_ksyms.c

* Tue Sep 12 2000 Michael K. Johnson <johnsonm@redhat.com>
- qla2x00 driver rev 4.10
- moved some things from modules to static builds
- sym53c8xx 64-bit patch

* Tue Sep 12 2000 Bill Nottingham <notting@redhat.com>
- make iso9660 & eepro100 static for now
- new ia64 patches from David Mosberger

* Fri Sep  8 2000 Bill Nottingham <notting@redhat.com>
- make nfs & lockd static on ia64; bad things happen otherwise
- update to test8 (turn off sisfb, it doesn't build)

* Thu Sep  7 2000 Bill Nottingham <notting@redhat.com>
- big piles of ia64 updates
- add in e1000 driver, fix modular build
- update acenic to 0.46 for the non-tux case
- update megaraid to 1.10c
- update qla1280 to 3.16b
- build against test7-final (not test8-pre1) for now

* Tue Sep  5 2000 Florian La Roche <Florian.LaRoche@redhat.com>
- update to pcmcia-cs 3.1.20
- remove obsolete pcmcia-cs-3.1.3-3com.patch

* Thu Aug 31 2000 Michael K. Johnson <johnsonm@redhat.com>
- More work on TUX: new version, better integration, still incomplete
- updated to 2.4.0-test8-pre1
- temporarily disabled matrox maven driver because of ICE

* Thu Aug 24 2000 Michael K. Johnson <johnsonm@redhat.com>
- Added TUX (but currently commented out because of insufficient generality)
- Config files mention tux so that the SRPM will still build if you add
  the patch.  However, they will not build TUX in without changes.

* Wed Aug 16 2000 Michael K. Johnson <johnsonm@redhat.com>
- dropped pcmcia-cs copy -f fix in from 2.2

* Tue Aug 15 2000 Bill Nottingham <notting@redhat.com>
- update ia64 stuff

* Tue Aug 15 2000 Jakub Jelinek <jakub@redhat.com>
- update to test7-pre4
- fix emu10k1 build on alpha
- .config updates

* Mon Aug 14 2000 Jakub Jelinek <jakub@redhat.com>
- fix linux-merge-config.awk
- remove /usr/include/{linux,asm*} in kernel-headers %pre

* Thu Aug 10 2000 Bill Nottingham <notting@redhat.com>
- update to test6-final (vger patch is merged)

* Wed Aug  9 2000 Jakub Jelinek <jakub@redhat.com>
- update to test6/pre9
- apply vger patches
- make it build on sparc32

* Tue Aug  8 2000 Bill Nottingham <notting@redhat.com>
- make it build on ia64

* Tue Aug  8 2000 Jakub Jelinek <jakub@redhat.com>
- /usr/include/{linux,asm} are directories
- fix header merging
- update to test6/pre8

* Wed Aug  2 2000 Bill Nottingham <notting@redhat.com>
- add ia32 signal patch for ia64

* Tue Aug  1 2000 Bill Nottingham <notting@redhat.com>
- update to pre5/ia64-728 (argh)
- update qla2x00 scsi driver to 4.0 (from Qlogic)

* Wed Jul 26 2000 Bill Nottingham <notting@redhat.com>
- clean up the %posts some

* Wed Jul 26 2000 Jakub Jelinek <jakub@redhat.com>
- Rename kernel24 subpackages back
- parport fix from Tim Waugh
- make it build on Alpha (hopefully)

* Wed Jul 26 2000 Jakub Jelinek <jakub@redhat.com>
- kill some of the ugly hacks, replace them with other ugly
  hacks so that the package can be built as the main distribution
  kernel or an experimental one.
- fix the export memcpy/memset patch
- add enterprise kernel (64GB kernel) on i686

* Tue Jul 25 2000 Bill Nottingham <notting@redhat.com>
- ugly hacks to get just the headers out

* Tue Jul 25 2000 Jakub Jelinek <jakub@redhat.com>
- kill several unresolved symbols from modules

* Fri Jul 21 2000 Bill Nottingham <notting@redhat.com>
- more tweaks

* Thu Jul 20 2000 Jakub Jelinek <jakub@redhat.com>
- some more tweaks

* Tue Jul 18 2000 Jakub Jelinek <jakub@redhat.com>
- CIPE
- a couple of patchlets
- FHS tweaks

* Wed Jun 21 2000 Bill Nottingham <notting@redhat.com>
- update acenic, megaraid, qla1280 drivers
- minor kernel header tweak for userland

* Sat Jun 17 2000 Bill Nottingham <notting@redhat.com>
- bump up ramdisk size on ia64 & alpha
- compile more stuff into the kernel until modules work better

* Fri Jun 16 2000 Bill Nottingham <notting@redhat.com>
- add ia32 signal handling patch for ia64

* Thu Jun 15 2000 Jakub Jelinek <jakub@redhat.com>
- reenable changeloop patch

* Wed Jun 14 2000 Bill Nottingham <notting@redhat.com>
- merge in loopback fixes from -ac series

* Tue Jun 13 2000 Bill Nottingham <notting@redhat.com>
- ia64 updates (0609 patch)
- module config/versioning updates

* Mon Jun  5 2000 Bill Nottingham <notting@redhat.com>
- merge in the ia64 stuff
- move to /dev/shm

* Sat Jun  3 2000 Jakub Jelinek <jakub@redhat.com>
- fix rhconfig.h (from Bero)

* Mon May 29 2000 Jakub Jelinek <jakub@redhat.com>
- 2.4.0-test1
- changeloop patch
- fix BuildASM
- fix compilation with gcc 2.96
- fix devfsd compilation

* Sat May  6 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- pre7-6
- devfsd 1.3.8
- add even more confusion to the versioning hell ;)
  (so we can deal with pre-pre versions)

* Fri Apr 28 2000 Bill Nottingham <notting@redhat.com>
- update for ia64
- pre6-final
- don't apply abi patch until it stops imploding on boot

* Mon Apr 17 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 2.3.99pre6-pre3
- update ksymoops to 2.3.4
- update pcmcia to 3.1.14
- devfsd 1.3.4, devfs 162
- link ksymoops statically to get rid of the dependency on a particular
  version of binutils
- adapt abi patch to new kernel interfaces
- minor fixes to spec file
 
* Wed Mar 22 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 2.3.99pre3-7
- remove some fixes (they're now in the base version)

* Tue Mar 21 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Add /var/shm dir
- require initscripts >= 5.03 so we mount /var/shm
- 2.3.99pre3-3
- fix compilation of some buggy drivers
- fix build on sparc64

* Thu Mar 16 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 2.3.99pre2-3
- replace iBCS with abi, remove patches
- port abi to 2.3.99pre2-3
- fix packaging bug (ksymoops.8* was included in kernel-utils AND
  kernel-pcmcia-cs)
- add devfsd
- fix compilation on alpha (fix various kernel bugs and work
  around a compiler bug)
